class CapabilitiesController < RxModule::ApplicationController
  model_data_store(Capability)

  def create
    params = model_params
    capability = Capability.new(name: params[:name], display_name: params[:display_name], rank: params[:rank])
    job_process = JobProcess.find(params[:job_process_id])
    job_process.capabilities << capability
    if capability.save
      ActionCable.server.broadcast "everything", {
          model: JSON.parse(job_process.render_jbuilder_partial),
          class: 'JobProcess',
          action: :update
      }
      render json: capability
    else
      render json: capability.errors, status: :unprocessable_entity
    end
  end

  def destroy
    capability = Capability.find(params[:id])
    job_process = capability.job_process
    machines = capability.machines.map {|m| m}
    if capability.destroy
      ActionCable.server.broadcast "everything", {
        model: JSON.parse(job_process.render_jbuilder_partial),
        class: 'JobProcess',
        action: :update
      }
      machines.each do |machine|
        ActionCable.server.broadcast "everything", {
          model: JSON.parse(machine.render_jbuilder_partial),
          class: 'Machine',
          action: :update
        }
      end
      render json: capability
    else
      render json: capability.errors, status: :unprocessable_entity
    end
  end

  private

  def model_params
    params.fetch(:capabilities).permit( :name, :job_process_id, :display_name, :rank)
  end
end

