module RouterRoutes
  module Jobs
    extend ActiveSupport::Concern

    include RouterResponse

    def fetch
      params = router_fetch_params
      job = JobRequest.data_for_job_number(params[:jobNumber], params[:requestType])
      render json: job.full_client_payload, status: :ok
    end

    def update_location
      JobUpdateLocationJob.perform_later(update_location_params)
      send_router_response
    end

    def complete
      JobCompleteJob.perform_later(complete_params)
      send_router_response
    end

    def update_reject
      JobSetRejectJob.perform_later(set_reject_params)
      send_router_response
    end

    def update_process
      JobUpdateProcessJob.perform_later(update_processes_params)
      send_router_response
    end

    def schedule_process_state_change
      JobScheduleProcessStateChangeJob.perform_later(schedule_process_state_change_params)
      send_router_response
    end

    def post_job_states_to_rx_data
      JobPostJobStatesToRxDataJob.perform_later(post_job_state_to_rx_data_params)
      send_router_response
    end

    def set_inf
      params = inf_fetch_params
      job = Job.where(number: params[:jobNumber]).first
      machine = Component.where(name: params[:machine]).first.machine
      job.set_inf(machine)
      Rails::logger.info "set inf machine #{machine.component.name} for job #{job.number}"
      send_router_response
    end

    def execute_inf
      params = execute_inf_fetch_params
      job = Job.where(number: params[:jobNumber]).first
      if job&.inf_target_machine
        InfRequest.inf_for_job(job)
        Rails::logger.info "Inf request created for job #{job.number} for machine #{job.inf_target_machine.component.name}"
      else
        Rails::logger.info "Set inf was not executed before running execute inf for job #{job.number}. JobRequest not created."
      end
      send_router_response
    end

    private

    # PARAMS

    def add_timestamp_to_object(object)
      object.merge(timestamp_param)
    end

    def timestamp_param
      params.permit(:timestamp)
    end

    def fetch_data
      params.fetch(:data)
    end

    def router_fetch_params
      fetch_data.permit(:jobNumber, :requestType)
    end

    def update_location_params
      add_timestamp_to_object(fetch_data.permit(:jobNumber,:currentLocation => {}, :nextLocation => {}, locations: [:timestamp, :location => {}]))
    end

    def complete_params
      add_timestamp_to_object(fetch_data.permit(:jobNumber))
    end

    def set_reject_params
      add_timestamp_to_object(fetch_data.permit(:jobNumber, :isReject, :rejectData => {}))
    end

    def update_processes_params
      add_timestamp_to_object(fetch_data.permit(:jobNumber, processes: [:process, :machine, lensData: [:side, :state, :lastLocationReceivedAt, :lastStateChangeTimestamp, :lastComment, :isFromAuto, :isRework]]))
    end

    def schedule_process_state_change_params
      add_timestamp_to_object(fetch_data.permit(:jobNumber, :machine))
    end

    def post_job_state_to_rx_data_params
      add_timestamp_to_object(fetch_data.permit(:jobNumber, jobStates: [:searchParams => {}, :jobState => {}]))
    end

    def inf_fetch_params
      fetch_data.permit(:jobNumber, :machine)
    end

    def execute_inf_fetch_params
      fetch_data.permit(:jobNumber)
    end
  end
end
