class ConnectorsController < RxModule::ApplicationController
  model_data_store(Connector)

  def create
    params = model_params
    component = Component.find(params[:component_id])
    unless Setting.first[:connector_type] === 'OPCUA'
      #OpcuaConnector.new(name: params[:name], variable: params[:variable], connector_type: params[:connector_type], priority: params[:priority], action_delay: params[:action_delay], state: params[:state], control_action: params[:control_action])
      connector = MesConnector.new(name: params[:name], connector_type: params[:connector_type], path: params[:path])
      connector.component = component
    end
    if connector.save
      render json: connector
    else
      render json: connector.errors, status: :unprocessable_entity
    end
  end

  def update
    params = model_params
    connector = Connector.find(params[:id])
    node_need_removing = false
    node_id = connector.component[:id]
    connector_updated = false
    scanner_updated = false
    if Setting.first[:connection_type] === 'OPCUA'
      if connector[:component_id].nil?
        if connector[:name] != params[:name]
          connector[:name] = params[:name]
          node_need_removing = true
        end
        connector[:variable] = params[:variable]
        connector[:connector_type] = params[:connector_type]
        connector[:priority] = params[:priority]
        connector[:action_delay] = params[:action_delay]
      else
        if connector[:priority] != params[:priority]
          connector_updated = true
          connector[:priority] = params[:priority]
        end
        if connector[:action_delay] != params[:action_delay]
          connector_updated = true
          connector[:action_delay] = params[:action_delay]
        end
        #Scanner ref will not update on the fly. If its updated, restart the job_router
        connector[:rx_scanner_reference] = params[:rx_scanner_reference]
        connector[:opcua_scanner_reference] = params[:opcua_scanner_reference]
        if connector[:scanner_retry] != params[:scanner_retry]
          connector[:scanner_retry] = params[:scanner_retry]
          scanner_updated = true
        end

        if connector_updated
          JobRouter::Client.connectors_update([connector])
        end
      end
    else
      if connector[:name] != params[:name]
        connector[:name] = params[:name]
        node_need_removing = true
      end
      connector[:connector_type] = params[:connector_type]
      connector[:path] = params[:path]
    end

    if connector.save
      if scanner_updated
        device = connector.component.device
          ActionCable.server.broadcast "everything", {
          model: JSON.parse(device.render_jbuilder_partial),
          class: 'Device',
          action: :update
        }
      end
      if node_need_removing
        routing_graph = RoutingGraph.first
        routing_graph.remove_node(node_id)
      end
      render json: connector
    else
      render json: connector.errors, status: :unprocessable_entity
    end
  end

  def destroy
    connector = Connector.find(params[:id])
    if connector.destroy
      routing_graph = RoutingGraph.first
      routing_graph.remove_node(connector.component[:id])
      render json: connector
    else
      render json: connector.errors, status: :unprocessable_entity
    end
  end

  def update_state
    params = model_params
    connector = Connector.find(params[:id])
    connector[:state] = params[:state]
    if connector.save
      JobRouter::Client.connectors_update([connector])
      render json: connector
    else
      render json: connector.errors, status: :unprocessable_entity
    end
  end

  def control_action
    params = model_params
    connector = Connector.find(params[:id])
    if Setting.first[:connection_type] == 'MES'
      component = connector.component
      connectors = component.connectors.where(connector_type: 'input')
      mes_connectors= []
      Connector.transaction do
        connectors.each do |mes_connector|
          mes_connector[:control_action] = params[:control_action]
          if mes_connector.save
            mes_connectors.push mes_connector
          end
        end
      end
      render json: mes_connectors
    else
      connector[:control_action] = params[:control_action]
      if connector.save
      render json: connector
    else
      render json: connector.errors, status: :unprocessable_entity
    end
    end
  end

  private

  def model_params
    params.fetch(:connector).permit( :id, :name, :variable, :connector_type, :priority, :path, :action_delay, :component_id, :rx_scanner_reference, :opcua_scanner_reference, :scanner_retry, :state, :control_action)
  end
end

