class DeviceRoutingCommandsController < RxModule::ApplicationController
  model_data_store(DeviceRoutingCommand)

  def create
    params = model_params
    routing_command = DeviceRoutingCommand.new(command: params[:command], parameter: params[:parameter])
    device_type = DeviceType.find(params[:device_type_id])
    routing_command.device_type = device_type
    connector_names_array = params[:connector_names].split(', ')
    connector_names_array.each_with_index do |connector_name, index|
      connector = device_type.get_unique_opcua_connectors.select {|connector| connector[:name] == connector_name}
      if connector.nil?
        connector = OpcuaConnector.new(name: connector_name)
        if index == 0
          connector[:connector_type] = 'input'
        elsif connector_names_array.length == (index+1)
          connector[:connector_type] = 'output'
        else
          connector[:connector_type] = 'other'
        end
      end
      connector_command = ConnectorCommand.new(rank: index)
      connector_command.opcua_connector = connector
      routing_command.connector_commands << connector_command
    end

    unless params[:extra_requirements].blank?
      require 'json'
      extra_requirements = JSON.parse(params[:extra_requirements]) #[{ "target":{"type":"next", "connector":"trunk-in"}, "options":{"ignoreOnLoopingEnabled":true}}]
      extra_requirements.each do |extra_requirement|
        routing_command.command_requirements.new(target: extra_requirement['target'].to_json, options: extra_requirement['options'].to_json)
      end
    end

    if routing_command.save
      render json: routing_command
    else
      render status: :unprocessable_entity
    end
  end

  def to_json(*args)
    render_jbuilder_partial
  end

  private

  def model_params
    params.fetch(:routing_command).permit( :id, :command, :parameter, :device_type_id, :connector_names, :extra_requirements)
  end
end

