class DeviceTypesController < RxModule::ApplicationController
  model_data_store(DeviceType)

  def to_json(*args)
    render_jbuilder_partial
  end

  private

  def opcua_device_keys(hash)
      hash.slice(:name, :device_type)
  end

  def model_params
    params.fetch(:device_type).permit( :name, :all_in_one, :root_node_id, :delay_on_command_complete, :routing_retry_delay)
  end

  def get_fv_device_types_json
    [{
      deviceType: 'HT1',
      allInOne: false,
      routingRetryDelay: 4,
      delayOnCommandComplete: 500,
      connectors: [
          {name: 'trunk-in', variable: 'S1', type: 'input', priority: 0, actionDelay: 250},
          {name: 'trunk-transfer', variable: 'S2', type: 'other'},
          {name: 'trunk-out', variable: 'S3', type: 'output'},
          {name: 'feed-in', variable: 'S4', type: 'input', priority: 1, actionDelay: 250},
          {name: 'feed-transfer', variable: 'S5', type: 'other'},
          {name: 'feed-out',  variable: 'S6', type: 'output'}
      ],
      routingCommands: [
          {
              command: 'CT', param: '0', path: ['trunk-in', 'trunk-transfer', 'trunk-out'],
              extraRequirements: [{target: {type: 'next', connector: 'trunk-in'}, options: {ignoreOnLoopingEnabled: true}}]
          },
          { command: 'CT', param: '1', path: ['trunk-in', 'trunk-transfer', 'feed-transfer', 'feed-out']},
          { command: 'CF', param: '1', path: ['feed-in', 'feed-transfer', 'feed-out']},
          { command: 'CF', param: '0', path: ['feed-in', 'feed-transfer', 'trunk-transfer', 'trunk-out']}
      ],
      timers:
            [{variable: 'DP1', time: 250},
            {variable: 'DP3', time: 250},
            {variable: 'T1', time: 250},
            {variable: 'T2', time: 250},
            {variable: 'T3', time: 250},
            {variable: 'T4', time: 250},
            {variable: 'T5', time: 250},
            {variable: 'T6', time: 250},
            {variable: 'T7', time: 250},
            {variable: 'T8', time: 250},
            {variable: 'T9', time: 250},
            {variable: 'T10', time: 250},
            {variable: 'T11', time: 250}]
    },
    {
        deviceType: 'SC',
        allInOne: true,
        routingRetryDelay: 4,
        delayOnCommandComplete: 1000,
        connectors: [
            {name: 'trunk', variable: 'S1', type: 'input', priority: 1, actionDelay: 250}
        ],
        routingCommands: [
            { command: 'CT', param: '0', path: ['trunk']}
        ],
        timers: [
            {variable: 'DP1', time: 250}
        ]
    }]
  end

  def get_basic1_device_types_json
    [
        {
            deviceType: 'HT1',
            allInOne: false,
            routingRetryDelay: 4,
            delayOnCommandComplete: 500,
            connectors: [
                {name: 'trunk-in', variable: 'S1', type: 'input', priority: 0, actionDelay: 250},
                {name: 'trunk-transfer', variable: 'S2', type: 'other'},
                {name: 'trunk-out', variable: 'S3', type: 'output'},
                {name: 'feed-in', variable: 'S4', type: 'input', priority: 1, actionDelay: 250},
                {name: 'feed-transfer', variable: 'S5', type: 'other'},
                {name: 'feed-out',  variable: 'S6', type: 'output'}
            ],
            routingCommands: [
                {
                    command: 'CT', param: '0', path: ['trunk-in', 'trunk-transfer', 'trunk-out'],
                    extraRequirements: [{target: {type: 'next', connector: 'trunk-in'}, options: {ignoreOnLoopingEnabled: true}}]
                    },
                    { command: 'CT', param: '1', path: ['trunk-in', 'trunk-transfer', 'feed-transfer', 'feed-out']},
                    { command: 'CF', param: '1', path: ['feed-in', 'feed-transfer', 'feed-out']},
                    { command: 'CF', param: '0', path: ['feed-in', 'feed-transfer', 'trunk-transfer', 'trunk-out']}
            ],
            timers:
                [{variable: 'DP1', time: 250},
                {variable: 'DP3', time: 250},
                {variable: 'T1', time: 250},
                {variable: 'T2', time: 250},
                {variable: 'T3', time: 250},
                {variable: 'T4', time: 250},
                {variable: 'T5', time: 250},
                {variable: 'T6', time: 250},
                {variable: 'T7', time: 250},
                {variable: 'T8', time: 250},
                {variable: 'T9', time: 250},
                {variable: 'T10', time: 250},
                {variable: 'T11', time: 250}]
        }
    ]
  end

  def get_tristar_device_types_json
    [{
        deviceType: 'HT1',
        allInOne: false,
        routingRetryDelay: 4,
        delayOnCommandComplete: 500,
        connectors: [
            {name: 'trunk-in', variable: 'S1', type: 'input'},
            {name: 'trunk-transfer', variable: 'S2', type: 'other'},
            {name: 'trunk-out', variable: 'S3', type: 'output'},
            {name: 'feed-in', variable: 'S4', type: 'input'},
            {name: 'feed-transfer', variable: 'S5', type: 'other'},
            {name: 'feed-out',  variable: 'S6', type: 'output'}
        ],
        routingCommands: [
            {
                command: 'CT', param: '0',
                path: ['trunk-in', 'trunk-transfer', 'trunk-out'],
                extraRequirements: [
                    {target: {type: 'next', connector: 'trunk-in'}, options: {ignoreOnLoopingEnabled: true}}
                ]
            },
            {
                command: 'CT', param: '1',
                path: ['trunk-in', 'trunk-transfer', 'feed-transfer', 'feed-out'],
            },
            {
                command: 'CF', param: '1',
                path: ['feed-in', 'feed-transfer', 'feed-out'],
            },
            {
                command: 'CF', param: '0',
                path: ['feed-in', 'feed-transfer', 'trunk-transfer', 'trunk-out'],
            }
        ],
        timers:
            [{variable: 'DP1', time: 250},
            {variable: 'DP3', time: 250},
            {variable: 'T1', time: 250},
            {variable: 'T2', time: 250},
            {variable: 'T3', time: 250},
            {variable: 'T4', time: 250},
            {variable: 'T5', time: 250},
            {variable: 'T6', time: 250},
            {variable: 'T7', time: 250},
            {variable: 'T8', time: 250},
            {variable: 'T9', time: 250},
            {variable: 'T10', time: 250},
            {variable: 'T11', time: 250}]
    },
    {
        deviceType: 'HT11',
        allInOne: false,
        routingRetryDelay: 4,
        delayOnCommandComplete: 500,
        connectors: [
            {name: 'trunk-in', variable: 'S1', type: 'input'},
            {name: 'trunk-transfer', variable: 'S2', type: 'other'},
            {name: 'trunk-out', variable: 'S3', type: 'output'},
            {name: 'feed-in', variable: 'S4', type: 'input'},
            {name: 'feed-transfer', variable: 'S5', type: 'other'},
            {name: 'feed-out',  variable: 'S6', type: 'output'},
            {name: 'kickout',  variable: 'S7', type: 'output'}
        ],
        routingCommands: [
            {
                command: 'CT', param: '0',
                path: ['trunk-in', 'trunk-transfer', 'trunk-out'],
                extraRequirements: [
                    {target: {type: 'next', connector: 'trunk-in'}, options: {ignoreOnLoopingEnabled: true}}
                ]
            },
            {
                command: 'CT', param: '1',
                path: ['trunk-in', 'trunk-transfer', 'feed-transfer', 'feed-out'],
            },
            {
                command: 'CT', param: '2',
                path: ['trunk-in', 'trunk-transfer', 'feed-transfer', 'kickout'],
            },
            {
                command: 'CF', param: '1',
                path: ['feed-in', 'feed-transfer', 'feed-out'],
            },
            {
                command: 'CF', param: '0',
                path: ['feed-in', 'feed-transfer', 'trunk-transfer', 'trunk-out'],
            },
            {
                command: 'CF', param: '2',
                path: ['feed-in', 'feed-transfer', 'kickout'],
            }
        ],
        timers: [
            {variable: 'DP1', time: 250},
            {variable: 'DP3', time: 250},
            {variable: 'T1', time: 250},
            {variable: 'T2', time: 250},
            {variable: 'T3', time: 250},
            {variable: 'T4', time: 250},
            {variable: 'T5', time: 250},
            {variable: 'T6', time: 250},
            {variable: 'T7', time: 250},
            {variable: 'T8', time: 250},
            {variable: 'T9', time: 250},
            {variable: 'T10', time: 250},
            {variable: 'T11', time: 250},
        ],
    },
    {
        deviceType: 'HTT2',
        allInOne: false,
        routingRetryDelay: 4,
        delayOnCommandComplete: 500,
        connectors: [
            {name: 'trunk-in', variable: 'S1', type: 'input'},
            {name: 'trunk-transfer', variable: 'S2', type: 'other'},
            {name: 'trunk-out', variable: 'S3', type: 'output'},
            {name: 'feed-in', variable: 'S4', type: 'input'},
            {name: 'feed-transfer1', variable: 'S5', type: 'other'},
            {name: 'feed-out1',  variable: 'S6', type: 'output'},
            {name: 'feed-transfer2', variable: 'S8', type: 'other'},
            {name: 'feed-out2',  variable: 'S9', type: 'output'}
        ],
        routingCommands: [
            {
                command: 'CT', param: '0',
                path: ['trunk-in', 'trunk-transfer', 'trunk-out'],
                extraRequirements: [
                    {target: {type: 'next', connector: 'trunk-in'}, options: {ignoreOnLoopingEnabled: true}}
                ]
            },
            {
                command: 'CT', param: '1',
                path: ['trunk-in', 'trunk-transfer', 'feed-transfer1', 'feed-out1']
            },
            {
                command: 'CT', param: '2',
                path: ['trunk-in', 'trunk-transfer', 'feed-transfer1', 'feed-transfer2', 'feed-out2']
            },
            {
                command: 'CF', param: '1',
                path: ['feed-in', 'feed-transfer1', 'feed-out1']
            },
            {
                command: 'CF', param: '0',
                path: ['feed-in', 'feed-transfer1', 'trunk-transfer', 'trunk-out']
            },
            {
                command: 'CF', param: '2',
                path: ['feed-in', 'feed-transfer1', 'feed-transfer2', 'feed-out2']
            },
        ],
        timers: [
            {variable: 'DP1', time: 250},
            {variable: 'DP3', time: 250},
            {variable: 'T1', time: 250},
            {variable: 'T2', time: 250},
            {variable: 'T3', time: 250},
            {variable: 'T4', time: 250},
            {variable: 'T5', time: 250},
            {variable: 'T6', time: 250},
            {variable: 'T7', time: 250},
            {variable: 'T8', time: 250},
            {variable: 'T9', time: 250},
            {variable: 'T10', time: 250},
            {variable: 'T11', time: 250},
        ],
    }]
  end
end

