class FetchedJobsController < RxModule::ApplicationController
  protect_with('search_job_data', 'SearchJobData', [RxModule::Authorization.verb("search", "Search", :search)])

  def search
    job_number = params[:id]

    return render json: {error: "Invalid job number"}, status: :unprocessable_entity if job_number.blank?

    begin
      process_data = ProcessFetcher.fetch_for_job_number(job_number)

      if process_data.job_active
        render json: {
          job_number: process_data.job_number,
          tags: process_data.tags,
          processes: process_data.processes,
          source: process_data.source
        }
      else
        render json: {error: "Job is inactive."}, status: :unprocessable_entity
      end
    rescue ProcessRequest::JobDoesNotExist
      render json: {error: "Job is archived or does not exist."}, status: :not_found
    rescue ProcessRequest::FailedToFetchFromSource
      render json: {error: "Failed to fetch from tag source."}, status: :internal_server_error
    rescue => err
      render json: {error: err}, status: :unprocessable_entity
    end

    # Force the Job Process cache to flush if the router isn't on, other wise settings change would not be testable
    JobProcessCalculator.instance.clear_cache! unless JobRouter::Client.connected?
  end

  private

  def model_params
    params.fetch(:fetched_job).permit( :job_number)
  end
end