class JobRouterControlsController < RxModule::ApplicationController
  model_data_store(JobRouterControl, {create: false, read: true, update: false, delete: false, index: true}, {create: false, read: true, update: false, delete: false, index: true})
  protect_with('JobRouterControl', "JobRouterControl", [RxModule::Authorization.verb('start_router', 'Start Router', :start)])

  def start
    return render json: {error: 'The router is already online.'}, status: :unprocessable_entity if JobRouter::Client.connected?

    JobRouterControl.first.update(status: 'startup')
    JobRouter::Client.broadcast_startup_state('Verifying System Connections', 0)

    unless Setting.configured?
      JobRouterControl.first.update(status: 'offline')
      return render json: {error: 'Settings not configured.'}, status: :unprocessable_entity
    end

    unless JobRouterControl.vitals_online?
      JobRouterControl.first.update(status: 'offline')
      return render json: {error: system_is_offline}, status: :unprocessable_entity
    end

    begin
      JobRouter::Client.init(0)
    rescue => err
      return render json: {error: 'Something went wrong while starting the Router.', details: err}, status: :internal_server_error
    end

    @model = JobRouter::Client.info
    render :show
  end

  def stop
    return render json: {error: 'The router is already offline.'}, status: :unprocessable_entity unless JobRouter::Client.connected?

    resp = JobRouter::Client.send_stop_connection
    unless resp
      return render json: {status: 'Something went wrong while stopping the router.'}, status: :internal_server_error
    end

    @model = JobRouter::Client.info
    render :show
  end

  private

  def system_is_offline
    router_info = JobRouter::Client.info

    if Setting.lms_tag_source?
      return 'Cannot reach one or more LMS client.' unless LmsConfig.all_job_lms_online?
    end

    if Setting.rx_data_tag_source?
      return 'Cannot reach Rx-Data.' unless router_info.rx_data_online
    end

    'Something went wrong while trying to reach other systems.'
  end
end