class RequiredProcessesController < RxModule::ApplicationController
  before_action :block_index_all, only: [:index]

  def self.set_target_before
    super + [:complete, :complete_both, :reset, :finish_up_to, :reset_down_to, :rework_up_to]
  end

  model_data_store(RequiredProcess)

  def create
    params = model_params
    job = Job.find(params[:job_id])
    job_process = JobProcess.find(params[:job_process_id])
    required_process = RequiredProcess.new(side: params[:side])
    required_process.job_process = job_process
    required_process.job = job
    required_process.set_state(RequiredProcess.notstarted, RequiredProcess.source_manual)

    if job.is_rejected?
      job.un_reject
    end
    JobRouter::Client.job_set_processes(job)

    job.job_histories.create(event_type: 'process_added', location: job[:location], connector: job[:connector], state: job[:state], active: true)
    ActionCable.server.broadcast "everything", {
      model: JSON.parse(job.render_jbuilder_partial),
      class: job.class.name,
      action: :update
    }
    render json: {status: 'success'}
  end

  def update
    id = params[:id]
    params = model_params
    required_process = RequiredProcess.find(id)
    job_process = required_process.job_process
    job = required_process.job
    other_side = required_process[:side] == 'left' ? 'right' : 'left'
    other_side_changed= false
    required_process_other_side = job.required_processes.find_by(job_process_id: job_process[:id], side: other_side)
    required_process[:force_to_machine] = params[:force_to_machine]
    required_process[:last_state_change_timestamp] = Time.now.in_time_zone(ENV['TZ']).to_i
    unless required_process_other_side.nil?
      required_process_other_side[:force_to_machine] = params[:force_to_machine]
      required_process_other_side[:last_state_change_timestamp] = Time.now.in_time_zone(ENV['TZ']).to_i
      other_side_changed = true
    end
    required_process.capabilities.destroy_all
    unless params[:capability_ids].nil?
      params[:capability_ids].each do |capability_id|
        capability = Capability.find(capability_id)
        required_process.capabilities << capability
      end
    end
    if required_process.save
      if other_side_changed
        required_process_other_side.save
      end
      if job.is_rejected?
        job.un_reject
      end
      JobRouter::Client.job_set_processes(job)

      job.job_histories.create(event_type:  'Process_changed', location: job[:location], connector: job[:connector], state: job[:state], active: true)
      render json: required_process
    else
      render status: :unprocessable_entity
    end
  end

  def destroy
    id = params[:id]
    required_process = RequiredProcess.find(id)
    job = required_process.job
    if required_process.destroy
      if job.is_rejected?
        job.un_reject
      end
      JobRouter::Client.job_set_processes(job)

      job.job_histories.create(event_type: 'process_delete', location: job[:location], connector: job[:connector], state: job[:state], active: true)
      render json: {status: 'success'}
    else
      render json: required_process.errors, status: :unprocessable_entity
    end
  end

  def complete
    @model.job.manual_change do
      @model.is_rework = false
      @model.set_state(RequiredProcess.finished, RequiredProcess.source_manual)
    end
    render json: @model
  end

  def complete_both
    job_process = @model.job_process
    job = @model.job
    required_processes = job.required_processes.where(job_process_id: job_process[:id])

    updated_processes = @model.job.manual_change do
      updated_processes = []
      required_processes.each do |rp|
        rp.set_state(RequiredProcess.finished, RequiredProcess.source_manual)
        updated_processes << rp
      end
      updated_processes
    end

    render json: updated_processes.as_json
  end

  def reset
    @model.job.manual_change do
      @model.is_rework = false
      @model.set_state(RequiredProcess.notstarted, RequiredProcess.source_manual)
    end
    render json: @model
  end

  def finish_up_to
    job = @model.job
    job_process = @model.job_process
    required_processes_to_finish = job.required_processes.joins(:job_process).where(["job_processes.rank <= ? and side = ?", job_process[:rank], @model[:side]])

    count = @model.job.manual_change do
      count = 0
      RequiredProcess.transaction do
        required_processes_to_finish.each do |required_process_to_finish|
          if required_process_to_finish[:state] != 'FINISHED' || required_process_to_finish.is_rework
            required_process_to_finish.is_rework = false
            required_process_to_finish.set_state(RequiredProcess.finished, RequiredProcess.source_manual)
            count += 1
          end
        end
      end
      count
    end

    render json: {status: "#{count} processes finished"}
  end

  def reset_down_to
    job = @model.job
    job_process = @model.job_process
    required_processes_to_reset = job.required_processes.joins(:job_process).where("job_processes.rank >= ? and side = ?", job_process[:rank], @model[:side])

    count = @model.job.manual_change do
      count = 0
      RequiredProcess.transaction do
        required_processes_to_reset.each do |required_process_to_reset|
          if required_process_to_reset.state != 'NOTSTARTED' || required_process_to_reset.is_rework
            required_process_to_reset.is_rework = false
            required_process_to_reset.set_state(RequiredProcess.notstarted, RequiredProcess.source_manual)
            count += 1
          end
        end
      end
      count
    end
    render json: {status: "#{count} processes restarted"}
  end

  def rework_up_to
    job = @model.job
    job_process = @model.job_process
    required_processes_to_rework = job.required_processes.joins(:job_process).where(["job_processes.rank <= ? and side = ?", job_process[:rank], @model[:side]])
    count = @model.job.manual_change do
      count = 0
      RequiredProcess.transaction do
        required_processes_to_rework.each do |required_process_to_rework|
          unless required_process_to_rework.is_rework || required_process_to_rework.opposite_is_rework?
            required_process_to_rework.is_rework = true
            #required_process_to_rework.state =
            required_process_to_rework.required_process_state_histories.build(state: RequiredProcess.rework, source: RequiredProcess.source_manual, job_state_timestamp: nil, comment: nil)

            required_process_to_rework.set_state(RequiredProcess.notstarted, nil , nil, nil, false)

            required_process_to_rework.save
            count += 1
          end
        end
      end
      count
    end
    render json: {status: "#{count} set to be reworked"}
  end

  def to_json(*args)
    render_jbuilder_partial
  end

  private

  def model_params
    params.fetch(:required_process).permit( :ids, :side, :job_id, :job_process_id, :completed, :force_to_machine, :capability_ids => [])
  end
end