import React from "react";
import {Grid, Select} from "@material-ui/core";
import {CheckboxField, FormProps, GridItem, ModelSelect, SelectField} from "@rx-suite/ui";
import {Model} from "@rx-suite/data";
import {observer} from "mobx-react-lite";
import {CapabilityStore} from "../stores/machine/CapabilityStore";
import {JobProcessModel} from "../stores/machine/JobProcessStore";
import {SystemSettingModel, SystemSettingStore} from "@rx-suite/stores";

interface RequiredProcessCheckboxFactoryProps {
    checkBoxOnChange: (side: number, jobProcessName: string) => void,
    checked: any,
    capabilitiesSelected: any,
    selectOnChange: (e:any, value: [], side: number, jobProcessName: string) => void,
    jobProcesses: Model[]
}

export const RequiredProcessCheckboxFactory: React.FunctionComponent<RequiredProcessCheckboxFactoryProps> = observer(({checkBoxOnChange, checked, capabilitiesSelected, selectOnChange, jobProcesses}) => {

    const capabilities = CapabilityStore.getAll();
    const systemSettingModel = SystemSettingStore.selectedModel as SystemSettingModel;
    const displayRightLensFirst = systemSettingModel?.displayRightLensFirst();

    const selectFieldValues = React.useCallback((jobProcess) => {
        const arr = [];
        jobProcess.capability_ids.forEach((capability_id) => {
            const capability = capabilities.find((capability) => capability.id === capability_id)
            if(!capability) {
                return;
            }
            arr.push({label: capability.resolvedName, value: capability.id});
        })
        return arr;
    },[checked, capabilities, jobProcesses])

    const noLeftSide = displayRightLensFirst ? Object.entries(checked[1]).length > 0 : Object.entries(checked[0]).length > 0;
    const noRightSide = displayRightLensFirst ? Object.entries(checked[0]).length > 0 : Object.entries(checked[1]).length > 0;

    const checkboxes = (jobProcess: JobProcessModel, side: string) => {
        let checked_sided;
        let box_side;
        let capabilities_side;

        if(side === 'left') {
            checked_sided = checked[0];
            box_side = 0;
            capabilities_side = capabilitiesSelected[0];
        } else {
            checked_sided = checked[1];
            box_side = 1;
            capabilities_side = capabilitiesSelected[1];
        }

        return (
            <div>
                <Grid item>
                    <CheckboxField onChange={(e) => checkBoxOnChange(e, box_side, jobProcess.name)} checked={!!checked_sided[jobProcess.name]} label={jobProcess.resolvedName}/>
                </Grid>
                {!!checked_sided[jobProcess.name] &&
                    selectFieldValues(jobProcess).length > 0 &&
                <Grid item>
                    <SelectField
                        options={selectFieldValues(jobProcess)}
                        onChange={(e, value) => selectOnChange(e, value, box_side, jobProcess.name)}
                        multiple={true}
                        value={capabilities_side[jobProcess.name]}
                    />
                </Grid>}
            </div>
        )
    }

    return (jobProcesses.map((jobProcess) => {
        return <Grid item xs={12}>
            <Grid container>
                {noLeftSide &&
                <Grid item xs={6}>
                    <Grid container direction='column'>
                        {displayRightLensFirst ?
                            checkboxes(jobProcess, 'right') :
                            checkboxes(jobProcess, 'left')
                        }
                    </Grid>
                </Grid>}
                {noRightSide &&
                <Grid item xs={6}>
                    <Grid container direction='column'>
                        {displayRightLensFirst ?
                            checkboxes(jobProcess, 'left') :
                            checkboxes(jobProcess, 'right')
                        }
                    </Grid>
                </Grid>}
            </Grid>
            <hr style={{color: 'rgb(0,0,0,50)', backgroundColor: 'black', height: 1, border: 0}}/>
        </Grid>
    }))
})