import React from "react";
import {FormProps} from "@rx-suite/ui";
import { t } from "@lingui/macro";
import ReactTable from "react-table";
import {Model} from "@rx-suite/data";
import {SystemSettingModel, SystemSettingStore} from "@rx-suite/stores";
import {ArrowDropDown, ArrowRight, SubdirectoryArrowRight} from "@material-ui/icons";

export const RequiredProcessStateHistoryTable: React.FunctionComponent<FormProps> = ({ model }) => {
    const columns = React.useMemo(() => {return [{Header: t`Required process state history`, columns: [
        {
            expander: true,
            Header: () => null,
            Expander: ({ isExpanded, ...rest }) => {
                if(rest.original.state === 'ABORTED') {
                    return(
                        <div>
                            {isExpanded ? <ArrowDropDown/> : <ArrowRight/>}
                        </div>
                    )
                } else {
                    return null
                }
            },
        },
        {Header: t`State`, accessor: 'state', filterable: false, sortable: false},
        {Header: t`Source`, accessor: 'source', filterable: false, sortable: false},
        {Header: t`Timestamp`, accessor: d => d, id: 'timestamp', Cell: (cellInfo: { value: Model }) => {
            const systemSettingModel = SystemSettingStore.selectedModel as SystemSettingModel;
            let time = '';
            if(cellInfo.value.job_state_timestamp === null) {
                time = cellInfo.value.created_at as string
            } else {
                time = cellInfo.value.job_state_timestamp as string;
            }
            return systemSettingModel.printTimeDate(new Date(time));
            }}
        ]}]}, [])

    const sortMethod = (a:string, b:string) => {
        const timeA = a.job_state_timestamp ? a.job_state_timestamp : a.created_at;
        const timeB = b.job_state_timestamp ? b.job_state_timestamp : b.created_at;
        return new Date(timeA) - new Date(timeB);
    }

    return (
        <ReactTable
            data={model.required_process_state_histories}
            columns={columns}
            minRows={0}
            defaultPageSize={10}
            defaultSorted={[{id: 'timestamp', desc: true}]}
            defaultSortMethod={sortMethod}
            SubComponent={(row) => {
                if(!row.original.comment || row.original.state != 'ABORTED'){
                    return null;
                }
                return (<div style={{paddingLeft: '15px', display: 'flex', alignItems: 'center'}}><SubdirectoryArrowRight /><span>{row.original.comment}</span></div>)
            }}
        />
    )
}