import React from "react";
import {FormProps, SelectField} from "@rx-suite/ui";
import { t } from "@lingui/macro";
import {useSnackbar} from "notistack";
import {observer} from "mobx-react-lite";

export const SelectConnectorControlAction: React.FunctionComponent<FormProps> = observer(({ model }) => {
    if(model.connector_type !== 'input'){
        return null;
    }

    const {enqueueSnackbar} = useSnackbar();

    const getControlActions = () => {
        return [
            {label:t`none`, value: 'none'},
            {label:t`fetch new job data`, value: 'fetch_new_job_data'},
            {label:t`hold started processes`, value: 'hold_started_processes'},
            //TODO: These are temporary until 'hold started' can be configured to retry count
            {label:t`hold started (5 times)`, value: 'hold_started_5'},
            {label:t`hold started (10 times)`, value: 'hold_started_10'},
            {label:t`hold started (20 times)`, value: 'hold_started_20'},
            {label:t`hold started (30 times)`, value: 'hold_started_30'},
            {label:t`hold started (40 times)`, value: 'hold_started_40'},
            {label:t`hold started (50 times)`, value: 'hold_started_50'},
            //////
            {label:t`ignore process capabilities`, value: 'ignore_process_capabilities'},
            {label:t`complete previous processes`, value: 'complete_previous_processes'},
            {label:t`hold rejects`, value: 'hold_rejects'},

            //////
            {label:t`Split 1:1`, value: '1_1_split'}, // Used at Pioneer
            {label:t`setProcessUpTo`, value: 'set_process_up_to'}, //used at Pioneer to force a job in next process cooling
            //TODO: the following actions are temporary until we add that control actions are multiple
            {label:t`hold process + ignore capability`, value: 'hold_started_and_ignore_capability'},
            {label:t`fetch + ignore capability`, value: 'fetch_and_ignore_capability'},
            {label:t`fetch only unknown + ignore capability`, value: 'fetch_unknown_and_ignore_capability'}, // Used at Pionneer
            {label:t`complete previous + hold rejects`, value: 'complete_previous_hold_reject'},
            {label:t`fetch + complete previous`, value: 'fetch_complete_previous'},
            {label:t`fetch only unknown + restart up to`, value: 'fetch_unknown_restart'}, // used VSP
            {label:t`fetch only unknown + restart up to + split`, value: 'fetch_unknown_restart_split'}, // used at bell; fetch jobs, complete previous process and split 1:1
            {label:t`fetch only unknown + hold 10`, value: 'fetch_unknown_hold_started_10'}, // used at bell; start of loops to only fetch unknown but also hold 10 on started
            {label:t`fetch only unknown + hold 10 + complete up to`, value: 'fetch_unknown_hold_started_10_complete_up_to'}, // used at bell; start of loops to only fetch unknown but also hold 10 on started
            {label:t`fetch only unknown + unreject + complete up to`, value: 'fetch_unknown_unreject_complete_up_to'}, // used at plastic plus

            {label:t`fetch only unknown + set up to`, value: 'fetch_unknown_set_up_to'} // nikon
        ]
    }

    const handleControlActionOnChange = React.useCallback(async (field:string, value:string) => {
        model.nestedAssignment(field, value);
        model.viewModel.submit();
        try {
            const resp = await fetch(`/api/connectors/${model.id}/control_action`, {
                method: "POST",
                headers: {'Content-Type': 'application/json'},
                body: JSON.stringify({connector: model})
            }).then(resp => resp.json())
            .then(data => {
                enqueueSnackbar(`${t`Connector successfully updated`}`, {variant: "success"})
            })
        } catch (err) {
            console.error(err);
            enqueueSnackbar({err}, {variant: "error"});
        }
    }, []);

    const hint_message = () => {
        if(!(model.connector_type === 'input')) {
            return {title: 'Input Disabled', text: 'Only inputs can have control actions'}
        }
        return undefined
    }

    return (
        <SelectField
            onChange={(name, value) => handleControlActionOnChange('control_action', value)}
            value={model.viewModel.control_action}
            options={getControlActions()}
            hint={hint_message()}
        />
    )
});