import * as React from "react";
import {observer} from "mobx-react-lite";
import {TabPanel, TabPanelProps} from "../../generic/TabPanel";
import {ModelInput, ModelSelect} from "@rx-suite/ui";
import {ConnectorModel} from "../../../stores/Device/ConnectorStore";
import {t, Trans} from "@lingui/macro";

type OpcuaConnectorRoutingLogicTabProps = {
    model: ConnectorModel
} & TabPanelProps

export const OpcuaConnectorRoutingLogicTab: React.FunctionComponent<OpcuaConnectorRoutingLogicTabProps> = observer((props) => {
    const {value, index, model} = props;
    const notInDeviceTypeEdit = !!model.component_id;

    const connectorTypeOptions = () => {
        return [
            {label: 'input', value: 'input'},
            {label: 'output', value: 'output'},
            {label: 'other', value: 'other'}
        ]
    }

    return (
        <TabPanel value={value} index={index}>
            <ModelInput name={'variable'} label={t`OPCUA Variable`} disabled={notInDeviceTypeEdit}/>
            <ModelSelect name={'connector_type'} label={t`Type`} options={connectorTypeOptions()} disabled={notInDeviceTypeEdit}/>
            {model.viewModel.connector_type === 'input' &&
                <React.Fragment>
                    <ModelInput name={'priority'} type={'number'} inputProps={{max: '1', min: '0', step: '0.001'}}/>
                    <ModelInput name={'action_delay'}/>
                </React.Fragment>
            }
        </TabPanel>
    )
})