import React from "react";
import {observer} from "mobx-react-lite";
import {FormProps, ModelInput, ModelProvider, ModelSelect} from "@rx-suite/ui";
import {Button, Dialog, DialogActions, DialogContent, DialogTitle} from "@material-ui/core";
import {CapabilitiesModel} from "../../stores/machine/CapabilityStore";
import { t } from "@lingui/macro";
import {Model} from "@rx-suite/data";
import {RoutingCommandModel} from "../../stores/Device/RoutingCommandStore";
import {ConnectorModel} from "../../stores/Device/ConnectorStore";
import {DeviceModel} from "../../stores/Device/DeviceStore";
import {JobProcessModel} from "../../stores/machine/JobProcessStore";

interface ExtraRequirementDialogProps extends FormProps{
    open: boolean,
    handleSubmit: (model:Model) => void,
    handleClose: () => void,
    routingCommandModels: RoutingCommandModel[],
    connectors: ConnectorModel[],
    devices: DeviceModel[],
    jobProcesses: JobProcessModel[]
}

export const DeviceExtraRequirementDialog: React.FunctionComponent<ExtraRequirementDialogProps> = observer(({model, open, handleSubmit, handleClose, routingCommandModels, devices, connectors, jobProcesses}) => {

    const routingCommandOptions = () => {
        return routingCommandModels.map((routingCommandModel) => {
            return {label: routingCommandModel.command + ' ' + routingCommandModel.parameter, value: routingCommandModel.id}
        })
    }

    const deviceOptions = () => {
        return devices.map((device) => {
            return {label: device.name, value: device.id}
        })
    }

    const connectorOptions = () => {
        const nodePicked = model.viewModel.node_id;
        const deviceModel = devices.find((device) => {
            return device.id === nodePicked
        })

        if (!deviceModel)
            return [];

        const availableConnectors = connectors.filter((connector) => {
            return (connector.component_id === deviceModel.component_id) && (connector.connector_type !== 'other')
        })
        return availableConnectors.map((connector) => {
            return {label: connector.name, value: connector.id}
        })
    }

    const jobProcessOptions = () => {
        const mappedProcesses = jobProcesses.map((jobProcess) => {
            return {label: jobProcess.name, value: jobProcess.id}
        })
        mappedProcesses.push({label: t`Any process`, value: null})
        return mappedProcesses
    }

    return (
        <div>
            <ModelProvider value={model}>
                <Dialog open={open} onClose={handleClose} aria-labelledby="form-dialog-title">
                    <DialogTitle id="form-dialog-title">Add Extra Requirement</DialogTitle>
                    <DialogContent>
                        <div style={{'display': 'inline'}}>
                            <ModelSelect name={'device_routing_command_id'} options={routingCommandOptions()}/>
                            <ModelSelect name={'node_id'} options={deviceOptions()}/>
                            {model.viewModel.node_id !== 0 &&
                            <ModelSelect name={'connector_id'} options={connectorOptions()}/>}
                            <ModelSelect name={'job_process_id'} options={jobProcessOptions()}/>
                        </div>
                        <DialogActions>
                            <Button onClick={handleClose} color={"secondary"}>
                                close
                            </Button>
                            <Button onClick={e => handleSubmit(model)} color={"secondary"}>
                                Submit
                            </Button>
                        </DialogActions>
                    </DialogContent>
                </Dialog>
            </ModelProvider>
        </div>
    )
});
