import {FormProps, ModelForm, ModelInput, ModelProvider, ModelSelect} from "@rx-suite/ui";
import {Model} from "@rx-suite/data";
import React from "react";
import {observer} from "mobx-react-lite";
import {Button, Dialog, DialogActions, DialogContent, DialogTitle} from "@material-ui/core";
import { t } from "@lingui/macro";

interface RoutingCommandDialogProps extends FormProps{
    open: boolean,
    handleSubmit: (model:Model) => void,
    handleClose: () => void
}

export const MesConnectorDialogComponent: React.FunctionComponent<RoutingCommandDialogProps> = observer(({model, open, handleSubmit, handleClose}) => {

    return (
        <div>
            <ModelProvider value={model}>
                <Dialog open={open} onClose={handleClose} aria-labelledby="form-dialog-title" maxWidth={"md"} fullWidth={true}>
                    <DialogTitle id="form-dialog-title">Add Connector</DialogTitle>
                    <DialogContent>
                        <ModelInput name={'name'}/>
                        <ModelSelect name={'connector_type'} options={[{label: t`Input`, value: 'input'}, {label: t`Output`, value: 'output'}]} required={true}/>
                        <ModelInput name={'path'} required={true}/>
                        <DialogActions>
                            <Button onClick={handleClose} color={"secondary"}>
                                close
                            </Button>
                            <Button disabled={!model.viewModel.path || !model.viewModel.connector_type || !model.viewModel.isValid} onClick={e => handleSubmit(model)} color={"secondary"}>
                                Submit
                            </Button>
                        </DialogActions>
                    </DialogContent>
                </Dialog>
            </ModelProvider>
        </div>
    )
});
