import React from "react";
import {observer} from "mobx-react-lite";
import {DeviceModel} from "../../../stores/Device/DeviceStore";
import {CheckboxField, Conditional, ModelInput} from "@rx-suite/ui";
import {t} from "@lingui/macro";

type DeviceDataTrackingTabProps = {
    device: DeviceModel
}

export const DeviceDataTrackingTab: React.FunctionComponent<DeviceDataTrackingTabProps> = observer(({device}) => {

    const [sendJobStateEnabled, setSendJobStateEnabled] = React.useState<boolean>(device.send_job_state_as !== null);

    const handleChangeMarkDeadJobs = (event: any) => {
        if(!event.target.checked){
            device.viewModel.send_job_state_as = null;
            device.viewModel.job_state_process = null;
            setSendJobStateEnabled(false);
        }else{
            setSendJobStateEnabled(true);
        }
    }

    return (
        <React.Fragment>
            <CheckboxField
                label={t`Send Job State when jobs arrive at this decision point`}
                checked={sendJobStateEnabled}
                onChange={handleChangeMarkDeadJobs}
                hint={
                    {
                        title: t`Send Job State when job arrive at this decision point`,
                        text: t`When a job arrives at this decision point, a job state will be recorded. This can be used to record throughput on segments of the line, such as launch volume.`
                    }
                }
            />
            <Conditional condition={sendJobStateEnabled}>
                <ModelInput name={'send_job_state_as'}
                            hint={
                                {
                                    title: t`Send Job State As`,
                                    text: t`This will be used as the SN of the machine when the job state is sent.`
                                }
                            }
                            error={device.viewModel.send_job_state_as === null || device.viewModel.send_job_state_as.trim() === ''}
                />
                <ModelInput name={'job_state_process'}
                            hint={
                                {
                                    title: t`Job State Process`,
                                    text: t`This will be as the process of the machine when the job state is sent`
                                }
                            }
                            error={device.viewModel.job_state_process === null || device.viewModel.job_state_process.trim() === ''}
                />
            </Conditional>

        </React.Fragment>
    )
})