import React, {useEffect} from "react";
import {observer} from "mobx-react-lite";
import {t} from "@lingui/macro";
import ReactTable from "react-table";
import {Model} from "@rx-suite/data";
import {makeColumn, ModelTableDefaultActions} from "@rx-suite/ui";
import {useSnackbar} from "notistack";
import {RSDButton} from "../../../router_state_dependant_controls/RSDButton";
import {DeviceModel} from "../../../../stores/Device/DeviceStore";
import {ConnectorModel, ConnectorStore} from "../../../../stores/Device/ConnectorStore";
import {MesConnectorDialogComponent} from "../../MesConnectorDialogComponent";
import {SelectConnectorControlAction} from "../../../connectors/SelectConnectorControlAction";
import {SelectConnectorState} from "../../../connectors/SelectConnectorState";

type MesConnectorTabProps = {
    device: DeviceModel
}

export const MesConnectorTab: React.FunctionComponent<MesConnectorTabProps> = observer(({device}) => {
    const {enqueueSnackbar} = useSnackbar();

    const [addConnectorOpen, setAddConnectorOpen] = React.useState(false);
    const [connectorModels, setConnectorModels] = React.useState<ConnectorModel[]>([]);

    useEffect(() => {
        const resp = ConnectorStore.getByIds(device.connector_ids);
        resp.then((data) => {
          setConnectorModels(data);
        });
    }, [device.connector_ids]);

    const connectorModel = ConnectorStore.createModel();
    const connectorColumns = React.useMemo(() => {
        return [{
            Header: t`Connectors`, columns: [
                makeColumn('name', t`Name`, 'string'),
                makeColumn('connector_type', t`Type`, 'string'),
                {
                    Header: t`State`, accessor: d => d, id: 'state', Cell: (cellInfo: { value: Model }) => {
                        return <SelectConnectorState model={cellInfo.value}/>
                    }
                },
                {
                    Header: t`Control action`,
                    accessor: d => d,
                    id: 'control_action',
                    style: {textAlign: "center"},
                    minWidth: 125,
                    Cell: (cellInfo: { value: Model }) => {
                        return <SelectConnectorControlAction model={cellInfo.value}/>
                    }
                },
                {
                    accessor: d => d,
                    id: '_actions',
                    style: {textAlign: "right"},
                    minWidth: 125,
                    Cell: (cellInfo: { value: Model }) => {
                        if (!cellInfo.value || !cellInfo.value.getId) {
                            return null;
                        }
                        return <div>
                            <ModelTableDefaultActions store={ConnectorStore} model={cellInfo.value}/>
                        </div>
                    }
                }]
        }]
    }, [])

    const handleAddConnectorClickOpen = () => {
        setAddConnectorOpen(true);
    }

    const handleAddConnectorClose = () => {
        setAddConnectorOpen(false);
    }

    const handleAddConnectorSubmit = (submitModel: Model) => {
        submitModel.viewModel.component_id = device.component_id;
        submitModel.viewModel.submit();
        submitModel.commit().then(function(resp:any){
            enqueueSnackbar(t`Routing command successfully created`, {variant: "success"})
            setAddConnectorOpen(false);
        });
    }

    return (
        <React.Fragment>
            <RSDButton label={'Add Connector'} model={device} variant={'outlined'} handleOnClick={handleAddConnectorClickOpen}/>
            <br/>
            <ReactTable
                data={connectorModels}
                columns={connectorColumns}
                minRows={0}
                defaultPageSize={10}
                style={{width: '100%'}}
                defaultSorted={[{ id: 'variable', desc: false}]}/>
            {open && <MesConnectorDialogComponent model={connectorModel} open={addConnectorOpen} handleSubmit={handleAddConnectorSubmit} handleClose={handleAddConnectorClose}/>}
        </React.Fragment>
    )
})