import React from "react";
import {observer} from "mobx-react-lite";
import {t} from "@lingui/macro";
import ReactTable from "react-table";
import {Model} from "@rx-suite/data";
import {ModelTableDefaultActions} from "@rx-suite/ui";
import {ConnectorModel, ConnectorStore} from "../../../../stores/Device/ConnectorStore";
import {SelectConnectorState} from "../../../connectors/SelectConnectorState";
import {SelectConnectorControlAction} from "../../../connectors/SelectConnectorControlAction";

type OpcuaConnectorTabProps = {
    connectors: ConnectorModel[]
}

export const OpcuaConnectorTab: React.FunctionComponent<OpcuaConnectorTabProps> = observer(({connectors}) => {
    const connectorColumns = [
            {Header: t`Connectors`, columns: [
                {Header: t`Name`, accessor: 'name'},
                {Header: t`Variable`, accessor: 'variable'},
                {Header: t`Type`, accessor: 'connector_type'},
                {Header: t`Priority`, accessor: 'priority'},
                {Header: t`Action Delay`, accessor: 'action_delay'},
                {Header: t`Control action`, accessor: d => d, id: 'control_action', style: {textAlign: "center"}, minWidth: 125, Cell: (cellInfo: {value: Model }) => {
                        return <SelectConnectorControlAction model={cellInfo.value}/>
                    }},
                {Header: t`State`, accessor: d => d, id: 'state', Cell: (cellInfo: {value: Model }) => {
                        return <SelectConnectorState model={cellInfo.value}/>
                    }},
                {accessor: d => d, id: '_actions', style: {textAlign: "right"}, minWidth: 125, Cell: (cellInfo: { value: Model }) => {
                        if (!cellInfo.value || !cellInfo.value.getId) {
                            return null;
                        }
                        return <div>
                            <ModelTableDefaultActions store={ConnectorStore} model={cellInfo.value}/>
                        </div>}
                }
            ]
         }
    ]

    return(
        <React.Fragment>
            <ReactTable
                data={connectors}
                columns={connectorColumns}
                minRows={0}
                defaultPageSize={10}
                style={{width: '100%'}}
                defaultSorted={[{ id: 'variable', desc: false}]}
            />
        </React.Fragment>
    )
})