import React, {useEffect} from "react";
import {observer} from "mobx-react-lite";
import {t} from "@lingui/macro";
import ReactTable from "react-table";
import {Model} from "@rx-suite/data";
import {ModelTableDefaultActions} from "@rx-suite/ui";
import {DeviceModel} from "../../../../stores/Device/DeviceStore";

import {DeviceTimerModel, DeviceTimerStore} from "../../../../stores/Device/DeviceTimerStore";

type OpcuaConstantsTabProps = {
    device: DeviceModel
}

export const OpcuaConstantsTab: React.FunctionComponent<OpcuaConstantsTabProps> = observer(({device}) => {
    const [deviceTimerModels, setDeviceTimerModels] = React.useState<DeviceTimerModel[]>([]);

    useEffect(() => {
        const resp = DeviceTimerStore.getByIds(device.device_timer_ids);
        resp.then((data) => {
            setDeviceTimerModels(data);
        })
    }, [device.device_timer_ids])

    const timerColumns = [
        {Header: t`Timers`, columns: [
            {Header: t`Variable`, accessor: 'variable'},
            {Header: t`Time (milliseconds)`, accessor: 'time'},
            {Header: t`Description`, accessor: 'description'},
            {accessor: d => d, id: '_actions', style: {textAlign: "right"}, minWidth: 125, Cell: (cellInfo: { value: Model }) => {
                    if (!cellInfo.value || !cellInfo.value.getId) {
                        return null;
                    }
                    return <div>
                        <ModelTableDefaultActions store={DeviceTimerStore} model={cellInfo.value}/>
                    </div>}}
            ]
        }
    ]

    return(
        <React.Fragment>
            <ReactTable
                data={deviceTimerModels}
                columns={timerColumns}
                minRows={0}
                defaultPageSize={10}
                style={{width: '100%'}}
            />
        </React.Fragment>
    )
})