import React from "react";
import {observer} from "mobx-react-lite";
import {DeviceModel} from "../../../../stores/Device/DeviceStore";
import {DeviceRoutingCommandDeviceModel, DeviceRoutingCommandDeviceStore} from "../../../../stores/Device/DeviceRoutingCommandDeviceStore";
import {makeColumn, ModelTable} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {EnabledSwitch} from "../../../machines/CapabilitiyEnabledSwitch";

type OpcuaRoutingCommandTabProps = {
    device: DeviceModel
}

export const OpcuaRoutingCommandTab: React.FunctionComponent<OpcuaRoutingCommandTabProps> = observer(({device}) => {
    const columns = React.useMemo(() => {
        return [
            makeColumn("device_routing_command.command", t`Command`, 'string'),
            makeColumn("device_routing_command.parameter", t`Parameter`, 'string'),
           {
                Header: t`Enabled`,
                accessor: d => d,
                id: 'enabled',
                Cell: (cellInfo: { value: DeviceRoutingCommandDeviceModel }) => {
                    return <EnabledSwitch model={cellInfo.value} success={t`Device Routing Command Toggled Successfully`} failure={t`Device Routing Command Failed to Toggle`}/>
                }
            }
        ]
    }, [DeviceRoutingCommandDeviceStore.isLoading])

    return (
        <React.Fragment>
            <ModelTable store={DeviceRoutingCommandDeviceStore}
                        columns={columns}
                        defaultFiltered={[{id: 'id', value: device.device_routing_command_device_ids}]}
                        showCreateButton={false}
                        minRows={device.device_routing_command_device_ids.length}
                        noLinkColumns={['device_routing_command.command', 'device_routing_command.parameter', 'enabled']}
                        suppressActionColumn
                        suppressWrapper
                        suppressUserDefaults
            />
        </React.Fragment>
    )
})
