import React, {useEffect} from "react";
import {observer} from "mobx-react-lite";
import {t} from "@lingui/macro";
import ReactTable from "react-table";
import {Model} from "@rx-suite/data";
import {ModelTableDefaultActions} from "@rx-suite/ui";
import {DeviceModel, DeviceStore} from "../../../../stores/Device/DeviceStore";
import {Button} from "@material-ui/core";
import {DeviceExtraRequirementDialog} from "../../DeviceExtraRequirementDialog";
import {JobProcessStore} from "../../../../stores/machine/JobProcessStore";
import {RoutingCommandModel, RoutingCommandStore} from "../../../../stores/Device/RoutingCommandStore";
import {ExtraRequirementModel, ExtraRequirementStore} from "../../../../stores/Device/ExtraRequirementStore";
import {useSnackbar} from "notistack";
import {ConnectorStore} from "../../../../stores/Device/ConnectorStore";

type OpcuaRoutingRuleTabProps = {
    device: DeviceModel
}

export const OpcuaRoutingRuleTab: React.FunctionComponent<OpcuaRoutingRuleTabProps> = observer(({device}) => {
    const {enqueueSnackbar} = useSnackbar();

    const allConnectors = ConnectorStore.getAll();
    const allDevices = DeviceStore.getAll();
    const allJobProcesses = JobProcessStore.getAll();

    const [extraRequirementModels, setExtraRequirementModels] = React.useState<ExtraRequirementModel[]>([])
    const [routingCommandModels, setRoutingCommandModels] = React.useState<RoutingCommandModel[]>([]);

    useEffect(() => {
        const resp = RoutingCommandStore.getByIds(device.device_routing_command_ids);
        resp.then((data) => {
            setRoutingCommandModels(data);
        })

    }, [device.device_routing_command_ids])

    const [open, setOpen] = React.useState(false);

    let extraRequirementModel = ExtraRequirementStore.createModel();

    useEffect(() => {
        const resp = ExtraRequirementStore.getByIds(device.extra_requirement_ids);
        resp.then((data) => {
            setExtraRequirementModels(data);
        })

    }, [device.extra_requirement_ids])

    const ExtraRequirementColumns = [
        {Header: t`Extra Requirements`, columns: [
            {Header: t`Id`, accessor: 'id'},
            {Header: t`Routing command`, accessor: 'device_routing_command_name'},
            {Header: t`Node`, accessor: 'node_name'},
            {Header: t`Connector`, accessor: 'connector_name'},
            {Header: t`Job process`, accessor: 'job_process_name'},
            {accessor: d => d, id: '_actions', style: {textAlign: "right"}, minWidth: 125, Cell: (cellInfo: { value: Model }) => {
                    if (!cellInfo.value || !cellInfo.value.getId) {
                        return null;
                    }
                    return <div>
                        <ModelTableDefaultActions store={ExtraRequirementStore} model={cellInfo.value}/>
                    </div>}
            }
            ]
        }
    ]

    const handleClickOpen = () => {
        setOpen(true);
    }

    const handleClose = () => {
        setOpen(false);
    }

    const handleSubmit = (submitModel: Model) => {
        submitModel.viewModel.device_id = device.id;
        submitModel.viewModel.submit();
        submitModel.commit().then(function(resp:any){
            enqueueSnackbar(`${t`Extra requirement successfully created`}`, {variant: "success"})
            setOpen(false);
        });
    }
    return(
        <React.Fragment>
            <div style={{width: '100%'}}>
                <Button variant="outlined" color="secondary" onClick={handleClickOpen}>
                    {t`Add a Routing Rule`}
                </Button>
                <br/>
                <ReactTable
                    data={extraRequirementModels ? extraRequirementModels : []}
                    columns={ExtraRequirementColumns}
                    minRows={0}
                    defaultPageSize={10}
                />
                {open && <DeviceExtraRequirementDialog model={extraRequirementModel} open={open} handleSubmit={handleSubmit} handleClose={handleClose} routingCommandModels={routingCommandModels} devices={allDevices} connectors={allConnectors} jobProcesses={allJobProcesses}/>}
            </div>
        </React.Fragment>
    )
})