import React from "react";
import {observer} from "mobx-react-lite";
import {t} from "@lingui/macro";
import ReactTable from "react-table";
import {Model} from "@rx-suite/data";
import {ModelTableDefaultActions} from "@rx-suite/ui";
import {ConnectorModel, ConnectorStore} from "../../../../stores/Device/ConnectorStore";
import {ScannerModel, ScannerStore} from "../../../../stores/ScannerStore";
import {SettingStore} from "../../../../stores/SettingStore";

type OpcuaScannersTabProps = {
    connectors: ConnectorModel[]
}

export const OpcuaScannersTab: React.FunctionComponent<OpcuaScannersTabProps> = observer(({connectors}) => {
    const settings = SettingStore.selectedModel;
    const scannerModels = settings?.use_rx_scanners ? ScannerStore.getAll() as ScannerModel[] : [];

    const connectorColumns = [
            {Header: t`Scanners`, columns: [
                {Header: t`Connector`, accessor: 'name'},
                {Header: t`Scanner Tag (OPCUA)`, accessor: 'opcua_scanner_reference'},
                {Header: t`Retry Attempts`, accessor: 'scanner_retry'},
                {accessor: d => d, id: '_actions', style: {textAlign: "right"}, Cell: (cellInfo: { value: Model }) => {
                        if (!cellInfo.value || !cellInfo.value.getId) {
                            return null;
                        }
                        return <div>
                            <ModelTableDefaultActions store={ConnectorStore} model={cellInfo.value}/>
                        </div>}
                }
            ]
         }
    ]

    if(settings?.use_rx_scanners){
        connectorColumns[0].columns.splice(1, 0,{Header: t`Name (Rx-Scanner)`, accessor: d => d, id: 'rx_scanner_reference', Cell: (cellInfo: {value: Model }) => {
                const scanner = scannerModels.find(scanner=>scanner.id == cellInfo.value.rx_scanner_reference)
                if(!scanner){
                    return '';
                }
                return scanner.name;
            }}
        )
    }

    return(
        <React.Fragment>
            <ReactTable
                data={connectors}
                columns={connectorColumns}
                minRows={0}
                defaultPageSize={10}
                style={{width: '100%'}}
                defaultSorted={[{ id: 'variable', desc: false}]}
            />
        </React.Fragment>
    )
})