import * as React from 'react';
import {observer} from "mobx-react-lite";
import {t} from '@lingui/macro';
import {SystemSettingModel, SystemSettingStore} from "@rx-suite/stores";
import ReactTable, {Column} from "react-table";

// TODO: Same component as in Rx-Link, maybe make generic component?

export const DcsTagsTable: React.FunctionComponent<DcsTagsTableProps> = observer(({tagData}) => {
    const systemSettingModel = SystemSettingStore.selectedModel as SystemSettingModel;
    const displayRightLensFirst = systemSettingModel?.displayRightLensFirst();

    const tableData = React.useMemo<DcsTagsTableRow[]>(()=> {
        if(!tagData){
            return [];
        }

        const tags = {} as any;

        for(let side of ['left', 'right']){
            const sideData = tagData[side];

            if(!sideData){
                continue;
            }

            for(let tag in sideData){
                if(!tags[tag]){
                    tags[tag] = {left: null, right: null};
                }

                tags[tag][side] = sideData[tag];
            }
        }

        return Object.keys(tags).map((tag) => {
           return {
               tag: tag,
               left: tags[tag].left,
               right: tags[tag].right
           }
        });
    }, [tagData])

    const leftColumn = {
        Header: t`Left`,
        accessor: 'left'
    };

    const rightColumn = {
        Header: t`Right`,
        accessor: 'right'
    };

    const columns = [
        {
            Header: t`Tag`,
            accessor: 'tag',
            filterable: true
        },
        displayRightLensFirst ? rightColumn : leftColumn,
        displayRightLensFirst ? leftColumn : rightColumn
    ] as Column[];

    return <ReactTable
        data={tableData}
        columns={columns}
        showPagination={false}
        // provide all of the data to the table,
        // without this, the table could show 30 rows,
        // but only fill 20 rows with data
        defaultPageSize={tableData.length}
        minRows={tableData.length <= 0 ? 10 : tableData.length} // if empty, pad the table with 10 rows
        sortable={false}
    />;
});

export type TagData = {
    [name: string]: TagHash | null;
}

type TagHash = {
    [name: string]: string;
}

type DcsTagsTableProps = {
    tagData: TagData | null;
}

type DcsTagsTableRow = {
    tag: string
    left: string | null
    right: string | null
}
