import React from "react";
import {FormProps, ModelProvider} from "@rx-suite/ui";
import {TagStore} from "../../stores/TagStore";
import {Button} from "@material-ui/core";
import {TagDialogComponent} from "../TagDialogComponent";
import {observer} from "mobx-react-lite";
import {TagQueryEditor} from "./TagQueryEditor";
import {useModalHandler} from "../../hooks/useModalHandler";

interface TagConditionProps extends FormProps {
    target: string,
    setStateCB: (tree: any, config: any) => void
}

export const TagConditionComponent: React.FunctionComponent<TagConditionProps> = observer(({ model , target, setStateCB}) => {
    const [addTagDialogOpen, handleCloseAddTag, handleOpenAddTag] = useModalHandler();

    let newTagModel = TagStore.createModel();

    return(
        <div>
            <Button variant="outlined" color="secondary" onClick={handleOpenAddTag}>Add Tag</Button>
            <ModelProvider value={newTagModel}>
                <TagDialogComponent model={newTagModel} open={addTagDialogOpen} handleClose={handleCloseAddTag}/>
            </ModelProvider>
            <TagQueryEditor target={target} setStateCB={setStateCB} model={model}/>
        </div>
    )
});