import * as React from "react";
import {observer} from "mobx-react-lite";
import {t} from "@lingui/macro";
import {ModelTableDefaultActions, useModelContext} from "@rx-suite/ui";
import {RSDButton} from "../../router_state_dependant_controls/RSDButton";
import {CapabilityDialogComponent} from "../../machines/CapabilityDialogComponent";
import ReactTable from "react-table";
import {Model} from "@rx-suite/data";
import {useEffect} from "react";
import {CapabilityStore} from "../../../stores/machine/CapabilityStore";
import {useSnackbar} from "notistack";

type JobProcessCapabilitiesTabProps = { }

export const JobProcessCapabilitiesTab: React.FunctionComponent<JobProcessCapabilitiesTabProps> = observer(() => {
    const model = useModelContext();

    const {enqueueSnackbar} = useSnackbar();

    const [capabilityModels, setCapabilityModels] = React.useState<Model[]>([])

    useEffect(() => {
        const resp = CapabilityStore.getByIds(model.capability_ids);
        resp.then((data) => {
            setCapabilityModels(data);
        });
    }, [model.capability_ids])

    const [open, setOpen] = React.useState(false);

    let capabilityModel = CapabilityStore.createModel();

    const handleClickOpen = () => {
        setOpen(true);
    }

    const handleClose = () => {
        setOpen(false);
    }

    const handleSubmit = (submitModel: Model) => {
        submitModel.viewModel.job_process_id = model.id;
        submitModel.viewModel.submit();
        submitModel.commit().then(function(resp:any){
            enqueueSnackbar(`${t`Capability successfully created`}`, {variant: "success"})
            setOpen(false);
        });
    }

    const columns = React.useMemo(() => {
        const cols = [
            {Header: t`Name`, accessor: 'name'},
            {Header: t`Display Name`, accessor: 'display_name'},
            {
                accessor: d => d,
                id: '_actions',
                style: {textAlign: "right"},
                Cell: (cellInfo: { value: Model }) => {
                    if (!cellInfo.value || !cellInfo.value.getId) {
                        return null;
                    }
                    return <>
                        <ModelTableDefaultActions store={CapabilityStore} model={cellInfo.value} />
                    </>
                }
            }
        ]

        if(model.viewModel.requireCapabilityRank){
            cols.splice(cols.length-1, 0,{Header: t`Rank`, accessor: 'rank'});
        }

        return [
            {
                Header: t`Capabilities`,
                columns: cols
            }
        ]
    }, [capabilityModels, model.viewModel.requireCapabilityRank]);


    return (
        <React.Fragment>
            <RSDButton label={'Add Capability'} model={model} variant="outlined" handleOnClick={handleClickOpen}/>
            <ReactTable
                data={capabilityModels}
                columns={columns}
                minRows={0}
                defaultPageSize={10}
            />
            {open &&
                <CapabilityDialogComponent
                    model={capabilityModel}
                    process={model}
                    open={open}
                    handleSubmit={handleSubmit}
                    handleClose={handleClose}/>
            }
        </React.Fragment>
    );
});
