import * as React from "react";
import {observer} from "mobx-react-lite";
import {t} from "@lingui/macro";
import {SettingStore} from "../../../stores/SettingStore";
import {Conditional, IfTrue, ModelCheckbox, ModelInput, ModelSelect} from "@rx-suite/ui";
import {HintList} from "../../generic/HintList";

type JobProcessOtherSettingsTab = { }

export const JobProcessOtherSettingsTab: React.FunctionComponent<JobProcessOtherSettingsTab> = observer(() => {
    const settings = SettingStore.selectedModel;

    const capabilityResolveOptions = [
        {label: 'Require All', value: 'require_all'},
        {label: 'Require Highest Rank', value: 'highest_rank'}
    ];

    const capabilityResolveHints = [
        {title: 'Require All', text: 'All the capabilities that pass the condition will be required'},
        {title: 'Require Highest Rank', text: 'Only the highest ranked capability between both eyes will be required.'}
    ]

    return (
        <React.Fragment>
            <ModelSelect
                name={'capability_resolve_mode'}
                options={capabilityResolveOptions}
                hint={
                        {
                            title: 'Resolve Capabilities',
                            children: <HintList
                                            primaryText={t`Determines how capabilities are calculated for a given job.`}
                                            items={capabilityResolveHints}
                                        />
                        }
                    }
            />
            <ModelCheckbox
                name={'do_not_reject_started'}
                label={'Do not Reject in Started'}
            />
            <Conditional condition={!!settings && settings.use_inf}>
                <IfTrue>
                    <ModelInput
                        name={'inf_target_tag'}
                        hint={
                            {
                                title: 'INF Target Tag',
                                text: 'When Job INF is requested, this tag is used to match the LMS JOBRTE data to this process.'
                            }
                        }
                    />
                </IfTrue>
            </Conditional>
        </React.Fragment>
    );
});
