import React from "react";
import {t, Trans} from "@lingui/macro";
import {Button, CircularProgress, makeStyles} from "@material-ui/core";
import {useSnackbar} from "notistack";
import {LmsConfigModel} from "../../stores/LmsConfigStore";

type RouterControlButtonsProps = {
    lmsConfig: LmsConfigModel
};

const useStyles = makeStyles((theme) => ({
    actionButton: {
        margin: theme.spacing(1),
    }
}));

export const LmsReinitializeButton: React.FunctionComponent<RouterControlButtonsProps> = ({ lmsConfig }) => {
    const {enqueueSnackbar} = useSnackbar();
    const [isReinitialising, setIsReinitialising] = React.useState(false);

    const buttonOnClick = async (config: LmsConfigModel) => {
        setIsReinitialising(true)
        const resp = await config.reinitializeConnection();
        if(resp.status === 200) {
            enqueueSnackbar(`${t`LMS successfully initialised.`}`, {variant: "success"});
        } else {
            enqueueSnackbar(`${t`Failed to initialise LMS connection.`}`, {variant: "error"});
        }
        setIsReinitialising(false)
    }

    return (
        <Button type='submit' color='secondary' variant='contained' onClick={() => buttonOnClick(lmsConfig)} size={'small'} disabled={isReinitialising}>
            {isReinitialising && <CircularProgress size={22} />}
            {!isReinitialising && (lmsConfig.online ?  <Trans>Reinitialise</Trans> :  <Trans>Initialise</Trans>)}
        </Button>
    )
};