import * as React from "react";
import {observer} from "mobx-react-lite";
import {createStyles, Divider, Grid, LinearProgress, Theme, Typography} from "@material-ui/core";
import {makeStyles} from "@material-ui/core/styles";
import {LmsConfigModel, LmsConfigStore} from "../../stores/LmsConfigStore";
import {SystemStatusLabel} from "./SystemStatusLabel";
import {t, Trans} from "@lingui/macro";
import {grey} from "@material-ui/core/colors";
import {LmsReinitializeButton} from "./LmsReinitializeButton";
import {Conditional, IfFalse, IfTrue} from "@rx-suite/ui";
import {DcsConnectionModel, DcsConnectionStore} from "@rx-suite/stores";

const useStyles = makeStyles((theme: Theme) =>
    createStyles({
        systemNameWrapper: {
            width: '400px',
            marginRight: theme.spacing(3)
        },
        lmsStatuses: {
            marginLeft: theme.spacing(2),
        },
        loader: {
          width: '20%'
        },
        loaderText: {
            fontSize: '1rem',
            color: grey[500]
        }
    })
);

export const LmsSystemStatusLabel: React.FunctionComponent = observer(() => {
    const classes = useStyles();

    const lmsConfigs = LmsConfigStore.getAll();
    const dcsConnections = DcsConnectionStore.getAll();

    const getSystemStatus = () => {
        return lmsConfigs.filter((config) => config.isJobLms).map((config) => {
            const connection = dcsConnections.find(c => c.id === config.external_dcs_id) as DcsConnectionModel;
            if(!connection){
                return {
                    name: t`Invalid LMS Configuration`,
                    status: 'offline',
                    config: null
                }
            }

            return {
                name: connection.resolved_name,
                status: config.online ? 'online' : 'offline',
                config: config
            }
        });
    };

    const systems = getSystemStatus();

    return (
        <Grid container direction={'column'}>
            <Grid item>
                <Typography variant={'h5'} className={classes.systemNameWrapper}><Trans>LMS</Trans></Typography>
            </Grid>
            <Grid container item direction={'column'} className={classes.lmsStatuses}>
                <Conditional condition={LmsConfigStore.isLoading || DcsConnectionStore.isLoading}>
                    <IfTrue>
                        <div>
                            <Typography variant={'h6'}><Trans>Checking LMS status...</Trans></Typography>
                            <LinearProgress className={classes.loader} color={'secondary'}/>
                        </div>
                    </IfTrue>
                    <IfFalse>
                        <Conditional condition={systems.length === 0}>
                            <IfTrue>
                                <Typography variant={'caption'} color={'error'}>
                                    <Trans>No LMS Configuration found</Trans>
                                </Typography>
                            </IfTrue>
                            <IfFalse>
                                <Grid container flexDirection={'column'}>
                                    {
                                        systems.map((system, i) => {
                                            return (
                                                <Grid key={i} item container justifyContent="space-evenly" style={{flexWrap: 'nowrap'}}>
                                                    <SystemStatusLabel systemName={system.name} state={system.status} systemNameVariant={'h6'}/>
                                                    {system.config && <Grid item>
                                                            <LmsReinitializeButton lmsConfig={system.config}/>
                                                        </Grid>
                                                    }
                                                </Grid>
                                            )
                                        })
                                    }
                                </Grid>
                            </IfFalse>
                        </Conditional>
                    </IfFalse>
                </Conditional>
            </Grid>
        </Grid>
    );
});
