import React, {SyntheticEvent} from "react";
import {Trans} from "@lingui/macro";
import {Button, makeStyles} from "@material-ui/core";
import {useSnackbar} from "notistack";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import {faPlay, faHandPaper} from "@rx-suite/pro-solid-svg-icons";
import {JobRouterControlModel} from "../../stores/JobRouterControlStore";

type RouterControlButtonsProps = {
    router: JobRouterControlModel;
    disable: boolean;
};

const useStyles = makeStyles((theme) => ({
    actionButton: {
        margin: theme.spacing(1),
    }
}));

export const RouterControlButtons: React.FunctionComponent<RouterControlButtonsProps> = ({ router, disable }) => {
    const {enqueueSnackbar} = useSnackbar();
    const [actionStarted, setActionStarted] = React.useState(false);
    const classes = useStyles();

    const handleControlAction = React.useCallback(async (action: ()=>Promise<any>, actionName: string) => {
        setActionStarted(true);
        const resp = await action();

        const content = await resp.json();

        if(!resp.ok){
            if(content.details){
                console.error(content.details);
            }

            const error = content.error ? content.error : "Unknown Error";
            enqueueSnackbar(<>{error}</>, {variant: "error"});
        }else{
            enqueueSnackbar(<Trans>Successfully {actionName} the Router.</Trans>, {variant: "success"});
        }

        setActionStarted(false);
    }, []);

    const handleStart = async (e: SyntheticEvent) => await handleControlAction(router.start, 'started');
    const handleStop = async (e: SyntheticEvent) => await handleControlAction(router.stop, 'stopped');

    return (
        <div>
            <Button variant="contained" color="secondary" onClick={handleStart} className={classes.actionButton} disabled={disable || router.is_online || actionStarted} startIcon={<FontAwesomeIcon icon={faPlay}/>}>
                <Trans>Start Router</Trans>
            </Button>
            <Button variant="contained" color="secondary" onClick={handleStop} className={classes.actionButton} disabled={router.is_offline || actionStarted} startIcon={<FontAwesomeIcon icon={faHandPaper}/>}>
                <Trans>Stop Router</Trans>
            </Button>
        </div>
    )
};