import * as React from "react";
import {observer} from "mobx-react-lite";
import {createStyles, Grid, Theme, Typography} from "@material-ui/core";
import {makeStyles} from "@material-ui/core/styles";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import {green, grey, orange, red} from "@material-ui/core/colors";
import {faCheckCircle, faDotCircle, faExclamationCircle, faTimesCircle} from "@rx-suite/pro-solid-svg-icons";

type SystemStatusLabelProps = {
    systemName: string;
    state: string; //'online' | 'standby' | 'offline',
    systemNameVariant?: string;
}

const useStyles = makeStyles((theme: Theme) =>
    createStyles({
        systemNameWrapper: {
            minWidth: '400px',
            marginRight: theme.spacing(3)
        },
        subWrapper: {
            minWidth: '400px',
            marginRight: theme.spacing(2)
        },
        icon: {
            marginRight: theme.spacing(1)
        },
        statusLabel: {
            color: grey[600]
        },
    })
);

export const SystemStatusLabel: React.FunctionComponent<SystemStatusLabelProps> = observer((props) => {
    const {systemName, state, systemNameVariant} = props;

    const classes = useStyles();

    const color = () => {
        if(state === 'standby' || state === 'starting'){
            return orange[500];
        }else if(state === 'online'){
            return green[500];
        }
        return red[500];
    }

    const icon = () => {
        if(state === 'standby'){
            return faExclamationCircle;
        }else if(state === 'online'){
            return faCheckCircle;
        }
        else if(state === 'starting'){
            return faDotCircle
        }
        return faTimesCircle;
    }

    return (
        <Grid container item>
            <Grid item className={systemNameVariant ? classes.subWrapper : classes.systemNameWrapper}>
                <Typography variant={systemNameVariant || 'h5'} display='inline' >{systemName}</Typography>
            </Grid>
            <Grid item>
                <FontAwesomeIcon icon={icon()} color={color()} className={classes.icon}/>
                <Typography variant={'h5'} display='inline' className={classes.statusLabel}>{state}</Typography>
            </Grid>
        </Grid>
    );
});
