import * as React from "react";
import {observer} from "mobx-react-lite";
import {TabPanel, TabPanelProps} from "../generic/TabPanel";
import {createStyles, Grid, LinearProgress, Theme, Typography} from "@material-ui/core";
import {makeStyles} from "@material-ui/core/styles";
import {JobRouterControlModel, JobRouterControlStore} from "../../stores/JobRouterControlStore";
import {SystemStatusLabel} from "./SystemStatusLabel";
import {grey} from "@material-ui/core/colors";
import moment, {Moment} from "moment";
import {Trans} from "@lingui/macro";
import {LmsConfigStore} from "../../stores/LmsConfigStore";
import {LmsSystemStatusLabel} from "./LmsSystemStatusLabel";
import {SettingStore} from "../../stores/SettingStore";
import {DelayedJobQueueStore} from "../../stores/DelayedJobQueueStore";

const useStyles = makeStyles((theme: Theme) =>
    createStyles({
        updatedAtLabel: {
            color: grey[500],
            fontSize: '0.75rem',
            paddingLeft: '8px'
        }
    })
);

function getDateTimeString(date: Moment): string {
    return date.format('HH:mm:ss (DD/MM/YYYY)')
}

export const SystemStatusTab: React.FunctionComponent<TabPanelProps> = observer((props) => {
    const {value, index} = props;

    const classes = useStyles();

    const setting = SettingStore.selectedModel;
    const delayedJobsQueue = DelayedJobQueueStore.selectedModel;
    const router = JobRouterControlStore.selectedModel;

    if(!router){
        return <LinearProgress/>
    }

    let router_status = router.status
    if(router_status === 'startup') router_status = 'starting'
    if(router_status === 'ready') router_status = 'online'

    let delayedJobsStatus = 'online'
    if(delayedJobsQueue && setting) {
        if (delayedJobsQueue?.count >= setting?.max_allowed_delayed_jobs/2) delayedJobsStatus = 'standby'
        if(delayedJobsQueue?.count >= setting?.max_allowed_delayed_jobs) delayedJobsStatus = 'offline'
    }

    return (
        <TabPanel value={value} index={index}>
            <SystemStatusLabel systemName={'Router'} state={router_status}/>{router.is_standby &&
                <Typography color={'error'}>
                    <Trans>{router.last_server_message}</Trans>
                </Typography>
            }
            {setting?.using_rx_data && <SystemStatusLabel systemName={'Rx-Data'} state={router.rx_data_online ? 'online' : 'offline'}/>}
            {setting?.use_rx_scanners && <SystemStatusLabel systemName={'Rx-Scanners'} state={router.rx_scanners_online? 'online' : 'offline'}/>}
            {setting?.tagSourceIsLms && <LmsSystemStatusLabel/>}
            <Typography variant={'h6'} className={classes.updatedAtLabel} display='inline'>Updated At: {getDateTimeString(moment(router.updated_at))}</Typography>
            {delayedJobsQueue && <SystemStatusLabel systemName={'Delayed Jobs Queue'} state={delayedJobsStatus}/>}
            {delayedJobsQueue &&
                <Typography variant={'h6'} className={classes.updatedAtLabel}>Delayed Job Current Count: {delayedJobsQueue.count} Updated At: {getDateTimeString(moment(delayedJobsQueue.updated_at))}</Typography>}
        </TabPanel>
    );
});
