import React from "react";
import {useSnackbar} from "notistack";
import {createStyles, Switch, Theme} from "@material-ui/core";
import { t } from "@lingui/macro";
import {CapabilityMachineModel} from "../../stores/machine/CapabilityMachineStore";
import {makeStyles} from "@material-ui/core/styles";
import {Model} from "@rx-suite/data";
import {observer} from "mobx-react-lite";

interface EnabledSwitchProps {
    model: Model;
    success: string;
    failure: string
}

const useStyles = makeStyles((theme: Theme) =>
    createStyles({
        switch: {
            "& .MuiIconButton-root" : {
                padding: '9px',
            }
        }
    })
);

export const EnabledSwitch: React.FunctionComponent<EnabledSwitchProps> = observer(({ model , success, failure}) => {
    const {enqueueSnackbar} = useSnackbar();
    const classes = useStyles()

    const handleChange = React.useCallback( async () => {
        const resp = await model.toggle();
        if(resp.status === 200) {
            enqueueSnackbar(success, {variant: "success"});
        } else {
            enqueueSnackbar(failure, {variant: "error"});
        }
    }, [])

    return (
        <Switch className={classes.switch} checked={model.enabled} color={'secondary'} onChange={handleChange}/>
    )
})