import React from "react";
import {observer} from "mobx-react-lite";
import {ButtonField, FormProps, ModelInput, ModelProvider, ModelSelect} from "@rx-suite/ui";
import {Grid} from "@material-ui/core";
import {CapabilitiesModel} from "../../stores/machine/CapabilityStore";

interface CapabilityProps extends FormProps{
    id: number
    capabilities: CapabilitiesModel[]
    deleteOnClickCB: (id: number) => void
}

export const CapabilityComponent: React.FunctionComponent<CapabilityProps> = observer(({model, id, capabilities, deleteOnClickCB}) => {

    const getCapabilitiesOptions = () => {
        return capabilities.map((capability: CapabilitiesModel, index: number) => ({label: capability.name, value:capability.getId()}))
    };

    const deleteOnClick = () => {
        deleteOnClickCB(id);
    };

    return(
        <ModelProvider value={model}>
            <Grid item xs={12}>
                <Grid container style={{ width: "100%" }} spacing={0}>
                    <Grid item xs={4}>
                        <ModelSelect name={'id'} options={getCapabilitiesOptions()} />
                    </Grid>
                    <Grid item xs={1}>
                        <ButtonField text={'X'} size={"small"} onClick={deleteOnClick}/>
                    </Grid>
                </Grid>
            </Grid>
        </ModelProvider>
    )
});
