import {observer} from "mobx-react-lite";
import React, {useEffect} from "react";
import {Model} from "@rx-suite/data";
import { t } from "@lingui/macro";
import {useSnackbar} from "notistack";
import {MachineCapabilityDialogComponent} from "./MachineCapabilityDialogComponent";
import {EnabledSwitch} from "./CapabilitiyEnabledSwitch";
import {RSDButton} from "../router_state_dependant_controls/RSDButton";
import {MachineModel} from "../../stores/machine/MachineStore";
import {makeColumn, ModelTable} from "@rx-suite/ui";
import {CapabilityMachineStore} from "../../stores/machine/CapabilityMachineStore";

interface MachineCapabilityProps {
    machine: MachineModel;
    choices: Model[];
}

export const MachineCapabilityComponent: React.FunctionComponent<MachineCapabilityProps> = observer(({machine, choices}) => {
    const {enqueueSnackbar} = useSnackbar();

    const [capabilityDialogOpen, setCapabilityDialogOpen] = React.useState(false);

    const columns = React.useMemo(() => {
        return [
            {
                Header: t`Capabilities`,
                columns: [
                    makeColumn('capability_name', t`Name`, 'string'),
                    {
                        Header: t`Enabled`,
                        accessor: d => d,
                        id: 'enabled',
                        Cell: (cellInfo: { value: Model }) => {
                            return <EnabledSwitch model={cellInfo.value} success={`${t`Capability Toggled`}`} failure={`${t`Failed to Toggle Capability`}`}/>
                        }
                    },
                ]
            }]
    }, [CapabilityMachineStore.models]);

    const openCapabilityDialog = () => {
        setCapabilityDialogOpen(true);
    }

    const closeCapabilityDialog = () => {
        setCapabilityDialogOpen(false);
    }

    const handleAddCapability = (submitModel: Model) => {
        submitModel.viewModel.submit();
        submitModel.commit().then(function (resp: any) {
            enqueueSnackbar(`${t`Capabilities Updated`}`, {variant: "success"})
            closeCapabilityDialog();
        });
    }

    return (
        <div>
            <RSDButton label={'Set Capabilities'} model={machine} variant={'outlined'} handleOnClick={openCapabilityDialog}/>
            <br/>
            <ModelTable store={CapabilityMachineStore}
                        columns={columns}
                        defaultFiltered={[{id: 'id', value: machine.capability_machines.map(c=>c.id)}]}
                        showCreateButton={false}
                        noLinkColumns={['capability_name', 'enabled']}
                        suppressActionColumn
                        suppressWrapper
                        suppressUserDefaults
            />
            {open &&
            <MachineCapabilityDialogComponent model={machine}
                                        open={capabilityDialogOpen}
                                        handleSubmit={handleAddCapability}
                                        handleClose={closeCapabilityDialog}
                                        choices={choices}/>}
        </div>
    )
})