import React from "react";
import {observer} from "mobx-react-lite";
import {FormProps, ModelProvider, ModelSelect} from "@rx-suite/ui";
import {Button, Dialog, DialogActions, DialogContent, DialogTitle} from "@material-ui/core";
import {Model} from "@rx-suite/data";
import {CapabilitiesModel} from "../../stores/machine/CapabilityStore";
import {JobRouterControlStore} from "../../stores/JobRouterControlStore";

interface CapabilityDialogProps extends FormProps{
    open: boolean,
    handleSubmit: (model:Model) => void,
    handleClose: () => void
    choices: Model[]
}

export const MachineCapabilityDialogComponent: React.FunctionComponent<CapabilityDialogProps> = observer(({model, open, handleSubmit, handleClose, choices}) => {
    const routerInfo = JobRouterControlStore.selectedModel;

    const getCapabilityValues = () => {
        const possibleCapabilities = getPossibleCapabilitiesOptions();
        const selected = [];
        for(let i =0; i < possibleCapabilities.length; i++) {
            if (model.viewModel.capability_ids.find((capability_id) => {
                return (capability_id === possibleCapabilities[i].value)
            }))
            {
                selected.push(possibleCapabilities[i].value);
            }
        }
        return selected
    }

    const getPossibleCapabilitiesOptions = () => {
        return choices.map((capability: CapabilitiesModel) => ({label: capability.name, value: capability.id}))
    }

    return (
        <div>
            <ModelProvider value={model}>
                <Dialog open={open} onClose={handleClose} aria-labelledby="form-dialog-title">
                    {routerInfo?.is_offline && <DialogTitle id="form-dialog-title">Set Capabilities</DialogTitle>}
                    <DialogContent>
                        <ModelSelect name={'capability_ids'} options={getPossibleCapabilitiesOptions()} values={getCapabilityValues()} multiple={true}/>
                        <DialogActions>
                            <Button onClick={handleClose} color={"secondary"}>
                                close
                            </Button>
                            <Button onClick={e => handleSubmit(model)} color={"secondary"}>
                                Submit
                            </Button>
                        </DialogActions>
                    </DialogContent>
                </Dialog>
            </ModelProvider>
        </div>
    )
});
