import {observer} from "mobx-react-lite";
import {Button} from "@material-ui/core";
import ReactTable from "react-table";
import {MesMachineStateDialogComponent} from "./MesMachineStateDialogComponent";
import React, {useEffect} from "react";
import {Model} from "@rx-suite/data";
import {formatters, FormProps, makeColumn, ModelTableDefaultActions} from "@rx-suite/ui";
import { t } from "@lingui/macro";
import {MesMachineStateModel, MesMachineStateStore} from "../../stores/machine/MesMachineStateStore";
import {useSnackbar} from "notistack";

export const MachineStateComponent: React.FunctionComponent<FormProps> = observer(({model}) => {

    const {enqueueSnackbar} = useSnackbar();

    const [machineStateOpen, setMachineStateOpen] = React.useState(false);
    const [machineStateModels, setMachineStateModels] = React.useState<MesMachineStateModel[]>([])

    useEffect(() => {
        const resp = MesMachineStateStore.getByIds(model.mes_machine_state_ids);
        resp.then((data) => {
            setMachineStateModels(data);
        });
    }, [model.mes_machine_state_ids])
    const mesMachineStateModel = MesMachineStateStore.createModel();

    const columns = React.useMemo(() => {
        return [
            {
                Header: t`Machine States`,
                columns: [
                    makeColumn('name', t`Name`, 'string'),
                    makeColumn('online', t`Online state?`, "string", formatters.boolean('true', 'false')),
                    {
                        accessor: d => d,
                        id: '_actions',
                        style: {textAlign: "right"},
                        Cell: (cellInfo: { value: Model }) => {
                            if (!cellInfo.value || !cellInfo.value.getId) {
                                return null;
                            }
                            return <>
                                <ModelTableDefaultActions store={MesMachineStateStore} model={cellInfo.value}/>
                            </>
                        }
                    }
                ]
            }]
    }, []);

    const handleMachineStateClickOpen = () => {
        setMachineStateOpen(true);
    }

    const handleMachineStateClose = () => {
        setMachineStateOpen(false);
    }

    const handleMachineStateSubmit = (submitModel: Model) => {
        submitModel.viewModel.mes_machine_id = model.id;
        submitModel.viewModel.submit();
        submitModel.commit().then(function (resp: any) {
            enqueueSnackbar(`${t`Routing command successfully created`}`, {variant: "success"})
            setMachineStateOpen(false);
        });
    }

    if (!model.sn) {
        return null;
    }

    return (
        <div>
            <Button variant="outlined" color="secondary" onClick={handleMachineStateClickOpen}>
                Add machine state
            </Button>
            <br/>
            <ReactTable
                data={machineStateModels}
                columns={columns}
                minRows={0}
                defaultPageSize={5}
            />
            {open &&
            <MesMachineStateDialogComponent model={mesMachineStateModel} open={machineStateOpen}
                                            handleSubmit={handleMachineStateSubmit}
                                            handleClose={handleMachineStateClose}/>}
        </div>
    )
})