import React from "react";
import {observer} from "mobx-react-lite";
import {CheckboxField, FormProps, ModelForm, ModelInput, ModelProvider} from "@rx-suite/ui";
import {Button, Dialog, DialogActions, DialogContent, DialogTitle} from "@material-ui/core";
import {Model} from "@rx-suite/data";

interface CapabilityDialogProps extends FormProps{
    open: boolean,
    handleSubmit: (model:Model) => void,
    handleClose: () => void
}

export const MesMachineStateDialogComponent: React.FunctionComponent<CapabilityDialogProps> = observer(({model, open, handleSubmit, handleClose}) => {

    const handleCheckBoxChange = React.useCallback(async (field:string, value:string) => {
        model.nestedAssignment('online', value);
    }, []);

    return (
        <div>
            <ModelProvider value={model}>
                <Dialog open={open} onClose={handleClose} aria-labelledby="form-dialog-title">
                    <DialogTitle id="form-dialog-title">Add machine state</DialogTitle>
                    <DialogContent>
                        <ModelInput name={'name'}/>
                        <CheckboxField label={'Online state?'} onChange={handleCheckBoxChange} checked={model.viewModel.online}/>
                        <DialogActions>
                            <Button onClick={handleClose} color={"secondary"}>
                                close
                            </Button>
                            <Button onClick={e => handleSubmit(model)} color={"secondary"}>
                                Submit
                            </Button>
                        </DialogActions>
                    </DialogContent>
                </Dialog>
            </ModelProvider>
        </div>
    )
});
