import React from "react";
import {FormProps, SelectField} from "@rx-suite/ui";
import { t } from "@lingui/macro";
import {useSnackbar} from "notistack";
import {observer} from "mobx-react-lite";

export const MesSelectMachineState: React.FunctionComponent<FormProps> = observer(({ model }) => {
    const {enqueueSnackbar} = useSnackbar();
    const getForcedStateOptions = () => {
        return [
            {label:'none', value: 'none'},
            {label:'online', value: 'online'},
            {label:'offline', value: 'offline'}
        ]
    }
    const getVirtualForcedStateOptions = () => {
        const forcedStates = getForcedStateOptions();
        return forcedStates.slice(1);
    }

    const handleStateOnChange = React.useCallback(async (field:string, value:string) => {
        model.nestedAssignment(field, value);
        model.viewModel.submit();
        try {
            const resp = await fetch(`/api/machines/${model.id}/update_state`, {
                method: "POST",
                headers: {'Content-Type': 'application/json'},
                body: JSON.stringify({machine: model})
            }).then(resp => resp.json())
            .then(data => {
                enqueueSnackbar(`${t`Machine successfully updated` as string}`, {variant: "success"})
            })
        } catch (err) {
            console.error(err);
            enqueueSnackbar({err}, {variant: "error"});
        }
    }, [model]);

    return (
        <SelectField
            label={t`Forced state`}
            onChange={(name, value) => handleStateOnChange('forced_state', value)}
            value={model.viewModel.forced_state}
            options={model.virtual ? getVirtualForcedStateOptions() : getForcedStateOptions()}
        />
    )
});