import * as React from "react";
import {observer} from "mobx-react-lite";
import {MachineModel} from "../../../../stores/machine/MachineStore";
import {CheckboxField, ModelSelect} from "@rx-suite/ui";
import {t, Trans} from "@lingui/macro";
import {LmsConfigStore} from "../../../../stores/LmsConfigStore";
import {TabPanel} from "../../../generic/TabPanel";
import {Grid, Typography} from "@material-ui/core";
import {SettingStore} from "../../../../stores/SettingStore";

type MachineJobInfSelectorProps = {
    model: MachineModel
}

export const MachineJobInfSelector: React.FunctionComponent<MachineJobInfSelectorProps> = observer((props) => {
    const {model} = props;
    const [useInf, setUseInf] = React.useState<boolean>(!!model.lms_config_id);

    LmsConfigStore.getAll();
    const settings = SettingStore.selectedModel;

    const lmsConfigModels = LmsConfigStore.models.filter((model) => model.lms_type === 'inf');

    const infLmsOptions = React.useCallback(() => {
        const l = lmsConfigModels.map((model) => {
            return {label: `${model.name} - ${model.ip}:${model.port}`, value: model.getId()}
        })
        l.push({label: t`None`, value: null})
        return l
    }, [lmsConfigModels])

    const handleCheckboxChange = () => {
        setUseInf(!useInf);

        if(!useInf){
            model.viewModel.lms_config_id = null;
        }
    }

    if(!settings?.inf_enabled){
        return null;
    }

    return (
        <div>
            <CheckboxField label={t`Get Job Finished State from LMS`} onChange={handleCheckboxChange} checked={useInf} />
            {useInf && <ModelSelect label={t`LMS for Job INF`} name={'lms_config_id'} options={infLmsOptions()}/>}
        </div>
    );
});
