import * as React from "react";
import {observer} from "mobx-react-lite";
import {TabPanel, TabPanelProps} from "../../../generic/TabPanel";
import {MachineModel} from "../../../../stores/machine/MachineStore";
import {MachineCapabilityComponent} from "../../MachineCababilityComponent";
import {CapabilityStore} from "../../../../stores/machine/CapabilityStore";
import {Grid, makeStyles, Typography} from "@material-ui/core";
import {Trans} from "@lingui/macro";
import {Warning} from "@material-ui/icons";
import {useEffect} from "react";
import {CapabilityMachineStore} from "../../../../stores/machine/CapabilityMachineStore";

type MachineCapabilitiesSettingsTabProps = {
    model: MachineModel
} & TabPanelProps

const useStyles = makeStyles((theme) => ({
    warning: {
        marginRight: '5px'
    },
}));

export const MachineCapabilitiesSettingsTab: React.FunctionComponent<MachineCapabilitiesSettingsTabProps> = observer((props) => {
    const {model, value, index} = props;
    const classes = useStyles();

    const capabilities = CapabilityStore.getAll();

    useEffect(() => {
        CapabilityMachineStore.fetchParams.limit = 5;  // Load a default of 5 capabilities row
    }, []);

    const getPossibleCapabilitiesOptions = () => {
        return capabilities.filter((capability) => {return capability.job_process_id === model.viewModel.job_process_id})
    }

    let content =   <Grid container alignItems="center">
                         <Warning className={classes.warning}/><Typography variant={'h6'}><Trans>Please select a process before selecting capabilities</Trans></Typography>
                    </Grid>

    if(model.viewModel.job_process_id){
        content = <MachineCapabilityComponent machine={model} choices={getPossibleCapabilitiesOptions()}/>
    }

    return (
        <TabPanel value={value} index={index}>
            {content}
        </TabPanel>
    );
});
