import * as React from "react";
import {observer} from "mobx-react-lite";
import {TabPanel, TabPanelProps} from "../../../generic/TabPanel";
import {MachineModel} from "../../../../stores/machine/MachineStore";
import {MachineJobInfSelector} from "../mes/MachineJobInfSelector";
import {ModelCheckbox} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {JobRouterControlStore} from "../../../../stores/JobRouterControlStore";

type MachineOtherSettingsTabTabProps = {
    model: MachineModel
} & TabPanelProps

export const MachineOtherSettingsTab: React.FunctionComponent<MachineOtherSettingsTabTabProps> = observer((props) => {
    const {model, value, index} = props;

    const router = JobRouterControlStore.selectedModel;

    return (
        <TabPanel value={value} index={index}>
            <ModelCheckbox name={'allow_job_start'} label={t`Allow Jobs to Start at this Machine?`} disabled={router?.is_online} hint={{title: 'Allow Job Start', text: 'When enabled, jobs can start at this machine without visiting the conveyor start point.'}} />
            <br/>
            <ModelCheckbox name={'restart_jobs'} label={t`Restart jobs?`} disabled={router?.is_online} hint={{title: 'Restart Jobs', text: t`Machine will restart jobs whose processes that are higher rank then its own are either started, finished, or aborted`}}/>
            <MachineJobInfSelector model={model}/>
        </TabPanel>
    );
});
