import * as React from "react";
import {observer} from "mobx-react-lite";
import {TabPanel, TabPanelProps} from "../../../generic/TabPanel";
import {RSDModelSelect} from "../../../router_state_dependant_controls/RSDModelSelect";
import {MachineModel} from "../../../../stores/machine/MachineStore";
import {JobProcessModel, JobProcessStore} from "../../../../stores/machine/JobProcessStore";
import {MachineJobStateBookingSelector} from "../mes/MachineJobStateBookingSelector";
import {MachineTargetRejectSelector} from "../mes/MachineTargetRejectSelector";
import {MachineForceDurationInput} from "./MachineForceDurationInput";

type MachineProcessSettingsTabProps = {
    model: MachineModel
} & TabPanelProps

export const MachineProcessSettingsTab: React.FunctionComponent<MachineProcessSettingsTabProps> = observer((props) => {
    const {model, value, index} = props;

    const jobProcesses = JobProcessStore.getAll();

    const getJobProcessOptions = () => {
        return jobProcesses.map((process: JobProcessModel) => ({label: process.name, value:process.id}))
    };

    return (
        <TabPanel value={value} index={index}>
            <RSDModelSelect name={'job_process_id'} model={model} options={getJobProcessOptions()}/>
            <MachineJobStateBookingSelector model={model}/>
            <MachineForceDurationInput model={model}/>
            <MachineTargetRejectSelector model={model}/>
        </TabPanel>
    );
});
