import React from "react";
import {FormProps} from "@rx-suite/ui";
import {IconButton} from "@material-ui/core";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import {faCheck} from "@rx-suite/pro-solid-svg-icons";
import { t } from "@lingui/macro";
import {useSnackbar} from "notistack";
import {Model} from "@rx-suite/data";

type FinishUpToRequiredProcessButtonProps = {
    model: Model,
    setJobFinderKey: (a:number) => void
}

export const FinishUpToRequiredProcessButton: React.FunctionComponent<FinishUpToRequiredProcessButtonProps> = ({ model, setJobFinderKey, ...props }) => {

    const {enqueueSnackbar} = useSnackbar();

    const handleOnClick = async (e:any) => {
        let error ="";
        try {
            const resp = await fetch(`/api/required_processes/${model.id}/finish_up_to`, {method: "POST"})
                .then(resp => resp.json())
                .then(data => {
                    console.log(data);
                    enqueueSnackbar(`${t`Status`}: ${data.status}`, {variant: "success"});
                    setJobFinderKey(Math.random());
                });
        } catch (err) {
            error = err;
            console.error(error);
            enqueueSnackbar({error}, {variant: "error"});
        }
    };

    const isDisabled = () => {
        return model?.viewModel.state === 'FINISHED';
    }

    return (
        <IconButton onClick={handleOnClick} disabled={isDisabled()} style={isDisabled() ? {filter: 'grayscale(80%)'} : undefined} {...props}>
            <FontAwesomeIcon icon={faCheck} color={'rgb(60,183,29)'}/>
        </IconButton>
    )
}