import React from "react";
import {RequiredProcessModel} from "../../stores/RequiredProcessStore";
import { observer } from "mobx-react-lite";
import {useSnackbar} from "notistack";
import {IconButton, IconButtonProps} from "@material-ui/core";
import {t} from "@lingui/macro";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";

type RequiredProcessButtonProps = {
    model: RequiredProcessModel,
    setJobFinderKey: (a:number) => void,
    postAction: string,
    isDisabled: boolean,
    icon: any,
    iconColor: string
}& IconButtonProps

export const RequiredProcessButton: React.FunctionComponent<RequiredProcessButtonProps> = observer((props) => {
    const {enqueueSnackbar} = useSnackbar();

    const {model, setJobFinderKey, postAction, isDisabled, icon, iconColor} = props;

    const handleOnClick = async (e:any) => {
        let error ="";
        try {
            const resp = await fetch(`/api/required_processes/${model.id}/${postAction}`, {method: "POST"})
                .then(resp => resp.json())
                .then(data => {
                    console.log(data);
                    enqueueSnackbar(`${t`Status`}: ${data.status}`, {variant: "success"});
                    setJobFinderKey(Math.random());
                });
        } catch (err) {
            error = err;
            console.error(error);
            enqueueSnackbar({error}, {variant: "error"});
        }
    };

    return (
        <IconButton onClick={handleOnClick} disabled={isDisabled} style={isDisabled ? {filter: 'grayscale(80%)'} : undefined} {...props}>
            <FontAwesomeIcon icon={icon} color={iconColor}/>
        </IconButton>
    )
})
