import React from "react";
import {RequiredProcessModel} from "../../stores/RequiredProcessStore";
import {RequiredProcessButton} from "./RequiredProcessButton";
import {faCheck, faRecycle, faTrafficCone} from "@rx-suite/pro-solid-svg-icons";
import {SettingStore} from "../../stores/SettingStore";
import {Conditional, IfTrue} from "@rx-suite/ui";

type RequiredProcessButtonsProps = {
    model: RequiredProcessModel,
    setJobFinderKey: (a:number) => void
}

export const RequiredProcessButtons: React.FunctionComponent<RequiredProcessButtonsProps> = ({ model, setJobFinderKey }) => {
    const setting = SettingStore.selectedModel;

    const colors = {
        finishUpTo: 'rgb(60,183,29)',
        resetDownTo: 'rgb(232,150,44)',
        reworkUpTo: 'rgb(243,100,100)'
    }

    const icons = {
        finishUpTo: faCheck,
        resetDownTo: faRecycle,
        reworkUpTo: faTrafficCone
    }

    const actions = {
        finishUpTo: 'finish_up_to',
        resetDownTo: 'reset_down_to',
        reworkUpTo: 'rework_up_to'
    }

    const finishUpToDisabled = () => {
        return model?.opposite_process?.is_rework;
    }

    const resetDownToDisabled = () => {
        return model?.opposite_process?.is_rework;
    }

    const reworkUpToDisabled = () => {
        return model?.viewModel.is_rework || model?.opposite_process?.is_rework;
    }

    return (
        <React.Fragment>
            <RequiredProcessButton
                model={model}
                setJobFinderKey={setJobFinderKey}
                postAction={actions.finishUpTo}
                isDisabled={finishUpToDisabled()}
                icon={icons.finishUpTo}
                iconColor={colors.finishUpTo}
            />
            <RequiredProcessButton
                model={model}
                setJobFinderKey={setJobFinderKey}
                postAction={actions.resetDownTo}
                isDisabled={resetDownToDisabled()}
                icon={icons.resetDownTo}
                iconColor={colors.resetDownTo}
            />
            <Conditional condition={setting.job_rework_enabled}>
                <IfTrue>
                    <RequiredProcessButton
                        model={model}
                        setJobFinderKey={setJobFinderKey}
                        postAction={actions.reworkUpTo}
                        isDisabled={reworkUpToDisabled()}
                        icon={icons.reworkUpTo}
                        iconColor={colors.reworkUpTo}
                    />
                </IfTrue>
            </Conditional>
        </React.Fragment>
    )
};