import React from "react";
import {Model} from "@rx-suite/data";
import {useSnackbar} from "notistack";
import {t} from "@lingui/macro";
import {IconButton, IconButtonProps} from "@material-ui/core";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import {faTrafficCone} from "@rx-suite/pro-solid-svg-icons";
import {observer} from "mobx-react-lite";
import {RequiredProcessModel} from "../../stores/RequiredProcessStore";

type ReworkUpToProcessButtonProps = {
    model: RequiredProcessModel,
    setJobFinderKey: (a:number) => void
} & IconButtonProps

export const ReworkUpToProcessButton: React.FunctionComponent<ReworkUpToProcessButtonProps> = observer(({ model, setJobFinderKey, ...props }) => {
    const {enqueueSnackbar} = useSnackbar();

    const handleOnClick = async (e:any) => {
        let error ="";
        try {
            const resp = await fetch(`/api/required_processes/${model.id}/rework_up_to`, {method: "POST"})
                .then(resp => resp.json())
                .then(data => {
                    console.log(data);
                    enqueueSnackbar(`${t`Status`}: ${data.status}`, {variant: "success"});
                    setJobFinderKey(Math.random());
                });
        } catch (err) {
            error = err;
            console.error(error);
            enqueueSnackbar({error}, {variant: "error"});
        }
    };

    const isDisabled = () => {
        return model?.viewModel.is_rework || model?.opposite_process?.is_rework;
    }

    return (
        <IconButton onClick={handleOnClick} disabled={isDisabled()} style={isDisabled() ? {filter: 'grayscale(80%)'} : undefined} {...props}>
            <FontAwesomeIcon icon={faTrafficCone} color={'rgb(243,100,100)'}/>
        </IconButton>
    )
})
