import {ModelInput, useReadonlyContext} from "@rx-suite/ui";
import React from "react";
import {observer} from "mobx-react-lite";
import {JobRouterControlStore} from "../../stores/JobRouterControlStore";
import {RSDToolTip} from "./RSDToolTip";
import {Model} from "@rx-suite/data";

type ModelInputProps = {
    label?: string,
    name: string,
    model: Model,
    forceDisable?: boolean
}

export const RSDModelInput: React.FunctionComponent<ModelInputProps> = observer(({label, name, model, forceDisable}) => {
    const router = JobRouterControlStore.selectedModel
    const readOnly = useReadonlyContext();

    // The field is disabled by order of priority:
    // - If force disable is set, always use that
    // - Otherwise, if the model is new, don't disable the field
    // - Otherwise, if the router is online, disable the field
    let disable = false
    let showTip = false
    if(router?.is_online){ disable = true; showTip = true }
    if(model.isNew) { disable = false; }
    if(forceDisable) { disable = true}
    if(readOnly) { disable = true }

    if(label){
        return (
            <ModelInput label={label} name={name} disabled={disable} hint={RSDToolTip(disable && showTip)}/>
        )
    }

    return (
        <ModelInput name={name} disabled={disable} hint={RSDToolTip(disable && showTip)}/>
    )
});
