import {ModelSelect} from "@rx-suite/ui";
import React from "react";
import {observer} from "mobx-react-lite";
import {JobRouterControlStore} from "../../stores/JobRouterControlStore";
import {RSDToolTip} from "./RSDToolTip";
import {Model} from "@rx-suite/data";

type RSDModelSelectProps = {
    name: string,
    model: Model,
    options: {label: string, value: string|number}[]
    multiple?: boolean
}

export const RSDModelSelect: React.FunctionComponent<RSDModelSelectProps> = observer(({name, model, options, multiple}) => {
    const router = JobRouterControlStore.selectedModel

    // The field is disabled by order of priority:
    // - If the model is new, don't disable the field
    // - Otherwise, if the router is online, disable the field
    let disable = false
    if(router?.is_online){ disable = true }
    if(model.isNew) { disable = false }

    return (
        <ModelSelect name={name} options={options} disabled={disable} hint={RSDToolTip(disable)} multiple={multiple}/>
    )
})
