import * as React from "react";
import {observer} from "mobx-react-lite";
import {SettingStore} from "../../stores/SettingStore";
import {TabPanel, TabPanelProps} from "../generic/TabPanel";
import {Conditional, ModelCheckbox, ModelInput} from "@rx-suite/ui";
import { t } from "@lingui/macro"
import {InfDataLmsTable} from "./LmsConfig/InfDataLmsTable";
import {LinearProgress} from "@material-ui/core";

type infSettingsTabProps = {
    disable: boolean;
} & TabPanelProps

export const InfSettingsTab: React.FunctionComponent<infSettingsTabProps> = observer((props) => {
    const {value, index, disable} = props;
    const settings = SettingStore.selectedModel;

    if(!settings){
        return <LinearProgress/>
    }

    return (
        <TabPanel value={value} index={index}>
            <div>
                <ModelCheckbox label={t`Use Job INF Data?`}
                               name={'inf_enabled'}
                               hint={
                                        {
                                            title: 'Job INF Data',
                                            text: 'When enabled, machines can be set to request INF data from an LMS to decide if a job should be aborted.'
                                        }
                                }
                />
            </div>
            <Conditional condition={settings.viewModel.inf_enabled}>
                <ModelInput label={t`Reject Job After X Failed Attempts`} name={'inf_max_attempts'} disabled={disable}/>
                <ModelInput label={t`Time between INF Attempts (seconds)`} name={'inf_time_between_attempts'} disabled={disable}/>
                <InfDataLmsTable/>
            </Conditional>
        </TabPanel>
    )
})