import {makeColumn, ModelTable} from "@rx-suite/ui";
import {LmsConfigModel, LmsConfigStore} from "../../../stores/LmsConfigStore";
import {Box, Button, createStyles, IconButton, Theme} from "@material-ui/core";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import {faPen} from "@rx-suite/pro-solid-svg-icons";
import {LmsConfigEditDialog} from "./LmsConfigEditDialog";
import * as React from "react";
import {observer} from "mobx-react-lite";
import {makeStyles} from "@material-ui/core/styles";
import {t, Trans} from "@lingui/macro";
import {SettingStore} from "../../../stores/SettingStore";
import {DcsConnectionModel, DcsConnectionStore} from "@rx-suite/stores";
import {Column} from "react-table";
import {useLmsConnectionNameColumn} from "../../../hooks/table_columns/useLmsConnectionNameColumn";

const useStyles = makeStyles((theme: Theme) =>
    createStyles({
        button: {
            padding: theme.spacing(1)
        }
    })
);

export const InfDataLmsTable: React.FunctionComponent = observer(() => {
    const classes = useStyles();

    const dcsModels = DcsConnectionStore.getAll() as DcsConnectionModel[];

    const [dialogOpen, setDialogOpen] = React.useState<boolean>(false);
    const [configModel, setConfigModel] = React.useState<null|LmsConfigModel>(null);

    const editConfig =  React.useCallback((model: LmsConfigModel) => {
        setConfigModel(model);
        setDialogOpen(true);
    },[]);

    const handleClickOpen = React.useCallback(() => {
        const model = LmsConfigStore.createModel();
        model.viewModel.lms_type = 'inf';
        setConfigModel(model);
        setDialogOpen(true);
    }, []);

    const columns = React.useMemo(() => {
        return [
            useLmsConnectionNameColumn()
        ]
    }, [dcsModels]);

    return (
        <div>
            <Box mt={1.5}>
                <Button variant="outlined" color="secondary" onClick={handleClickOpen}>
                    <Trans>Add INF Data LMS</Trans>
                </Button>
            </Box>
            <ModelTable store={LmsConfigStore}
                        columns={columns}
                        minRows={5}
                        showCreateButton={false}
                        defaultFiltered={[{id: 'lms_type', value: 1}]}
                        replacementActions={
                            {
                                Edit: (a) =>
                                    <IconButton onClick={() => editConfig(a.model as LmsConfigModel)} size={"small"} className={classes.button}>
                                        <FontAwesomeIcon icon={faPen}/>
                                    </IconButton>,
                                Read: () => null
                            }
                        }
                        suppressWrapper
            />
            {configModel && <LmsConfigEditDialog model={configModel as LmsConfigModel} open={dialogOpen} setOpen={setDialogOpen}/>}
        </div>
    )
})