import React, {useCallback} from "react";
import {observer} from "mobx-react-lite";
import {FormProps, ModelDcsSelect} from "@rx-suite/ui";
import {
    Button,
    Dialog,
    DialogActions,
    DialogContent,
    DialogTitle,
} from "@material-ui/core";
import {t} from "@lingui/macro";
import {ModelProvider} from "@rx-suite/ui";
import {LmsUsageRuleSettings} from "./LmsUsageRuleSettings";
import {LmsConfigModel} from "../../../stores/LmsConfigStore";
import {LmsLegacySettings} from "./LmsLegacySettings";
import {useSnackbar} from "notistack";

type LmsConfigDialogProps = {
    model: LmsConfigModel;
    open: boolean;
    setOpen: React.Dispatch<React.SetStateAction<boolean>>
} & Omit<FormProps, 'model'>

export const LmsConfigEditDialog:  React.FunctionComponent<LmsConfigDialogProps> = observer(({model, open, setOpen}) => {
    const {enqueueSnackbar} = useSnackbar();

    const handleSubmit = React.useCallback((submitModel: LmsConfigModel) => {
        submitModel.viewModel.submit();
        submitModel.commit().then(function(resp:any){
            enqueueSnackbar(`${t`LMS changes successful`}`, {variant: "success"})
            setOpen(false);
        });
    }, [model]);

    const handleClose = React.useCallback(() => {
        setOpen(false);
    }, [])

    return (
        <Dialog open={open} onClose={handleClose} aria-labelledby="form-dialog-title" fullWidth={true} maxWidth={'md'}>
            <DialogTitle id="form-dialog-title">{t`Edit LMS Configuration`}</DialogTitle>
            <DialogContent>
                <ModelProvider value={model}>
                    <ModelDcsSelect name={'external_dcs_id'}/>
                    <LmsUsageRuleSettings model={model}/>
                    <LmsLegacySettings model={model}/>
                </ModelProvider>
                <DialogActions>
                    <Button onClick={handleClose} color={"secondary"}>Close</Button>
                    <Button disabled={!model.viewModel.isValid} onClick={e => handleSubmit(model)} color={"secondary"}>Submit</Button>
                </DialogActions>
            </DialogContent>
        </Dialog>
    )
})
