import * as React from "react";
import {observer} from "mobx-react-lite";
import {t, Trans} from "@lingui/macro";
import {ModelCheckbox, ModelInput} from "@rx-suite/ui";
import {Box, createStyles, Divider, Theme, Typography} from "@material-ui/core";
import {makeStyles} from "@material-ui/core/styles";
import {LmsConfigModel} from "../../../stores/LmsConfigStore";

type LmsLegacySettingsProps = {
    model: LmsConfigModel
}

const useStyles = makeStyles((theme: Theme) =>
    createStyles({
        divider: {
            marginTop: theme.spacing(1),
            marginBottom: theme.spacing(1)
        },
        bold: {
            fontWeight: 'bold'
        },
        button: {
            padding: theme.spacing(1)
        }
    })
);

export const LmsLegacySettings: React.FunctionComponent<LmsLegacySettingsProps> = observer(({model}) => {
    const classes = useStyles();

    if(!model.isUsingLegacyConnection || model.isNew){
        return null
    }

    return (
        <React.Fragment>
            <Box mt={1}>
                <Divider/>
                <Typography variant={'subtitle1'}><Trans>Legacy Connection</Trans></Typography>
                <ModelInput disabled name={'name'} label={t`Name (optional)`}/>
                <ModelInput disabled name={'ip'}/>
                <ModelInput disabled name={'port'}/>
                <ModelInput disabled name={'device_type'} hint={{title: 'Device Type', children:
                        <div>
                            <div><Trans>Value of the Device Type (DEV) field in the LMS initializer.</Trans></div>
                            <br/>
                            <div><Trans><span className={classes.bold}>Recommended Value: DNL</span></Trans></div>
                        </div>
                }}/>
                <ModelInput disabled name={'delay_on_socket_open'} label={'Delay on Socket Open (seconds)'} hint={{title: "Delay on Socket Open", text: "When greater than 0, the system will wait at least X seconds before sending the first INI message after opening the TCP/IP socket."}}/>
                <ModelInput disabled name={'max_open_connections'} hint={{title: t`Maximum Opened Connection`, children:
                        <div>
                            <div><Trans>The maximum amount of connection that will be tried when calling the LMS. Set to 0 for no maximum.</Trans></div>
                            <br/>
                            <div><Trans><span className={classes.bold}>Warning:</span> Enabling this setting will force close connections if there is no answer from the LMS. This may cause the LMS system to crash.</Trans></div>
                        </div>
                }}
                />
                <ModelCheckbox disabled name={'hold_connection'} label={'Hold Connection Open'}/>
            </Box>
        </React.Fragment>
    )
});
