import React from "react";
import {observer} from "mobx-react-lite";
import {Conditional, FormProps, IfFalse, IfTrue, ModelInput} from "@rx-suite/ui";
import {createStyles, LinearProgress, Theme, Typography} from "@material-ui/core";
import {SettingStore} from "../../../stores/SettingStore";
import {makeStyles} from "@material-ui/core/styles";
import {grey} from "@material-ui/core/colors";
import {LmsConfigModel} from "../../../stores/LmsConfigStore";
import {t, Trans} from "@lingui/macro";

interface LmsUsageRuleSettingsProps extends FormProps{
    model: LmsConfigModel,
}

const useStyles = makeStyles((theme: Theme) =>
    createStyles({
        tipLabel: {
            color: grey[500],
            fontSize: '0.75rem'
        }
    })
);

export const LmsUsageRuleSettings:  React.FunctionComponent<LmsUsageRuleSettingsProps> = observer(({model}) => {
    const settings = SettingStore.selectedModel
    const classes = useStyles();


    if(!model.isJobLms){
        return null;
    }

    if(!settings){
        return <LinearProgress/>;
    }

    return (
        <React.Fragment>
            <Typography variant={'subtitle1'}><Trans>Usage Rule</Trans></Typography>
            <Conditional condition={settings.viewModel.lms_rule_mode === 'priority_based'}>
                <IfTrue>
                    <ModelInput name={'priority'}/>
                </IfTrue>
                <IfFalse>
                    <ModelInput name={'length_left_bound'}/>
                    <ModelInput name={'length_right_bound'}/>
                    <Typography variant={'h5'} className={classes.tipLabel} display='inline'><Trans>Note: Do not specify a maximum length to match any number exceeding the minimum length.</Trans></Typography>
                </IfFalse>
            </Conditional>
        </React.Fragment>
    )
})
