import * as React from "react";
import {observer} from "mobx-react-lite";
import {t} from "@lingui/macro";
import {SettingModel} from "../../stores/SettingStore";
import {TabPanel, TabPanelProps} from "../generic/TabPanel";
import {ModelCheckbox, ModelInput, ModelSelect} from "@rx-suite/ui";

type PLCConnectionSettingsTabProps = {
    settings: SettingModel;
    disable: boolean;
} & TabPanelProps

const mopRequestFormat = () => {
    return [
        {label: 'JSON', value: 'JSON'},
        {label: 'XML', value: 'XML'}
    ]
}

export const PLCConnectionTab: React.FunctionComponent<PLCConnectionSettingsTabProps> = observer((props) => {
    const {value, index, settings} = props;

    // Note: we don't need to use the viewModel value for connection type as it cannot be changed.

    let content = null;
    if(settings.connection_type == 'OPCUA'){
       content =    <div>
                        <ModelInput name={'variant'} disabled={true}/>
                        <ModelInput name={'opcua_server_url'}/>
                        {settings.variant === 'ncc' && <ModelInput label={"Device Root Node Id"} name={'device_root_path'} hint={{title: 'Device Root Node Id', text: 'The address of the immediate OPC UA node that contains all other devices. Ex: ns=2;s=MES.PLC1.SLMES'}}/>}
                        {settings.routing_level !== 'basic' && <ModelCheckbox label={t`Use Scanners from Rx-Scanners?`} name={'use_rx_scanners'}/>}
                    </div>
    }else if(settings.connection_type == 'MES'){
        content =   <div>
                        <ModelSelect name={'data_format'} label='MOP Request Format' options={mopRequestFormat()}/>
                    </div>
    }

    return (
        <TabPanel value={value} index={index}>
            <ModelInput name={'connection_type'} disabled={true}/>
            {content}
        </TabPanel>
    );
});
