import React from "react";
import {Conditional, FormProps, IfTrue, ModelForm, ModelInput} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {t} from "@lingui/macro";
import {TagConditionComponent} from "../../components/job_processes/TagConditionComponent";
import {RSDModelInput} from "../../components/router_state_dependant_controls/RSDModelInput";
import {Utils as QbUtils} from "react-awesome-query-builder";
import {TagConditionStore} from "../../stores/TagConditionStore";
import {useSnackbar} from "notistack";
import {Box, Typography} from "@material-ui/core";
import {JobProcessModel, JobProcessStore} from "../../stores/machine/JobProcessStore";
import {CapabilitiesModel} from "../../stores/machine/CapabilityStore";

type CapabilityFormProps = {
    model: CapabilitiesModel;
} & Omit<FormProps, 'model'>


export const CapabilityForm: React.FunctionComponent<CapabilityFormProps> = observer(({model}) => {
    const {enqueueSnackbar} = useSnackbar();

    const process = JobProcessStore.get(model.job_process_id);

    const setStateCB = (newTree, newConfig) => {
        model.viewModel.condition = QbUtils.jsonLogicFormat(newTree, newConfig);
        model.viewModel.submit();
    }

    const afterSubmit = () => {
        const newStateConditionModel = TagConditionStore.createModel();
        newStateConditionModel.viewModel.condition = model.viewModel.condition;
        newStateConditionModel.viewModel.capability_id = model.id;
        newStateConditionModel.viewModel.submit();
        newStateConditionModel.commit().then(function(resp:any){
            enqueueSnackbar(`${t`Condition successfully created`}`, {variant: "success"})
        });
    }

    return(
        <ModelForm model={model} readOnly={model.name === 'accepted' || model.name === 'rejected'} afterSubmit={afterSubmit} suppressMakeCopy suppressImportExport>
            <RSDModelInput name={'name'} model={model} forceDisable={model.name === 'accepted' || model.name === 'rejected'}/>
            <ModelInput name={'display_name'} hint={{title: t`Display Name Usage`, text: t`This will be displayed instead of the name.`}}/>
            <Conditional condition={!!process && process.requireCapabilityRank}>
                <IfTrue>
                    <ModelInput name={'rank'}/>
                </IfTrue>
            </Conditional>
            <Box mt={1} mb={1}>
                <Typography variant={'h6'}>Capability Condition</Typography>
            </Box>
            <TagConditionComponent model={model} target={'capability'} setStateCB={setStateCB}/>
        </ModelForm>
    )
});