import React, {useEffect} from "react";
import {FormProps, InputField, ModelForm, ModelInput} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {Tab, Tabs} from "@material-ui/core";
import {t, Trans} from "@lingui/macro";
import {OpcuaConnectorRoutingLogicTab} from "../../../components/connectors/tabs/OpcuaConnectorRoutingLogicTab";
import {OpcuaConnectorScannerTab} from "../../../components/connectors/tabs/OpcuaConnectorScannerTab";
import {ConnectorModel} from "../../../stores/Device/ConnectorStore";
import {Alert} from "@material-ui/lab";

export const OpcuaConnectorForm: React.FunctionComponent<FormProps> = observer(({model}) => {
    const notInDeviceTypeEdit = !!model.component_id;

    const [currentTab, setCurrentTab] = React.useState(0);
    const handleChange = (event: any, newValue: React.SetStateAction<number>) => {
        setCurrentTab(newValue);
    };

    const connector = model as ConnectorModel;

    return(
        <ModelForm model={model} suppressImportExport suppressMakeCopy>
            {notInDeviceTypeEdit && <Alert severity="info"><Trans>Some inputs of this form have been automatically populated according to the device type and cannot be edited.</Trans></Alert>}
            {notInDeviceTypeEdit && <ModelInput name={'device_name'} label={t`Device`} disabled={true}/>}
            <ModelInput name={'name'} label={t`Connector Name`} disabled={notInDeviceTypeEdit}/>
            <Tabs value={currentTab} onChange={handleChange} indicatorColor="primary"  textColor="primary" variant="scrollable">
                <Tab label={t`Routing Logic`} key={0}/>
                {notInDeviceTypeEdit && <Tab label={t`Scanner`} key={1}/>}
            </Tabs>
            <OpcuaConnectorRoutingLogicTab index={0} value={currentTab} model={connector}/>
            {notInDeviceTypeEdit && <OpcuaConnectorScannerTab  index={1} value={currentTab} model={connector}/>}
        </ModelForm>
    )
});