import React, {useEffect} from "react";
import {
    Conditional,
    FormProps,
    ModelForm,
    ModelInput, SelectField,
} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {t} from "@lingui/macro";
import {DeviceTypeModel, DeviceTypeStore} from "../../../stores/Device/DeviceTypeStore";
import {DeviceModel} from "../../../stores/Device/DeviceStore";
import {RSDModelInput} from "../../../components/router_state_dependant_controls/RSDModelInput";
import {OpcuaConnectorTab} from "../../../components/devices/form_tabs/opcua/OpcuaConnectorTab";
import {OpcuaConstantsTab} from "../../../components/devices/form_tabs/opcua/OpcuaConstantsTab";
import {OpcuaRoutingRuleTab} from "../../../components/devices/form_tabs/opcua/OpcuaRoutingRuleTab";
import {OpcuaScannersTab} from "../../../components/devices/form_tabs/opcua/OpcuaScannersTab";
import {ConnectorModel, ConnectorStore} from "../../../stores/Device/ConnectorStore";
import {OpcuaRoutingCommandTab} from "../../../components/devices/form_tabs/opcua/OpcuaRoutingCommandTab";
import {TabsContainer} from "../../../components/generic/TabsContainer";
import {DeviceDataTrackingTab} from "../../../components/devices/form_tabs/DeviceDataTrackingTab";

export const OpcuaDeviceForm: React.FunctionComponent<FormProps> = observer(({model}) => {
    const [connectorModels, setConnectorModels] = React.useState<ConnectorModel[]>([]);

    useEffect(() => {
        const resp = ConnectorStore.getByIds(model.connector_ids);
        resp.then((data) => {
            setConnectorModels(data);
        });
    }, [model.connector_ids]);

    const deviceTypes = DeviceTypeStore.getAll();

    const getDeviceTypeOptions = () => {
        return deviceTypes.map((deviceType: DeviceTypeModel) => {
            return {label: deviceType.name, value: deviceType.id}})
    };

    const handleDeviceTypeSelect = (e:any, x:any) => {
        const deviceType = deviceTypes.find((deviceType) => deviceType.id === x);
        model.nestedAssignment("device_type_id", x);
        if (deviceType)
        {
            model.nestedAssignment("name", deviceType.name);
            model.nestedAssignment("delay_on_command_complete", deviceType.delay_on_command_complete);
            model.nestedAssignment("routing_retry_delay", deviceType.routing_retry_delay);
        }
    };



    return(
        <ModelForm model={model} suppressImportExport suppressMakeCopy>
            <SelectField
                label={t`Device type`}
                onChange={handleDeviceTypeSelect}
                value={model.viewModel.device_type_id}
                options={getDeviceTypeOptions()}
                disabled={!model.isNew}
            />
            <RSDModelInput name={'name'} model={model}/>
            <ModelInput name={'routing_retry_delay'}/>
            <ModelInput name={'delay_on_command_complete'}/>
            <Conditional condition={!model.isNew}>
                <TabsContainer tabs={
                    [
                        {
                            label: t`Connectors`,
                            component: <OpcuaConnectorTab connectors={connectorModels}/>,
                            defaultTab: true
                        },
                        {
                            label: t`Scanners`,
                            component: <OpcuaScannersTab connectors={connectorModels.filter(connector=>connector.connector_type=='input')}/>,
                        },
                        {
                            label: t`Timers & Constants`,
                            component: <OpcuaConstantsTab device={model as DeviceModel}/>
                        },
                        {
                            label: t`Routing Commands`,
                            component: <OpcuaRoutingCommandTab device={model as DeviceModel}/>
                        },
                        {
                            label: t`Special Routing Rules`,
                            component: <OpcuaRoutingRuleTab device={model as DeviceModel}/>
                        },
                        {
                            label: t`Data Tracking`,
                            component: <DeviceDataTrackingTab device={model as DeviceModel}/>,
                        }
                    ]
                }
                />
            </Conditional>
        </ModelForm>
    )
});