import React, {useEffect} from "react";
import {ButtonField, FormProps, PaddedPaper} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import { t } from "@lingui/macro";
import {useSnackbar} from "notistack";
import {routerStore} from "@rx-suite/data";
import {RxAppModel, RxAppStore} from "@rx-suite/stores";
import {JobFinderScannerField} from "../../components/jobs/jobFinderScannerField";

export const JobFinderForm: React.FunctionComponent<FormProps> = observer(({model}) => {

    const {enqueueSnackbar} = useSnackbar();

    const appModel = RxAppStore.selectedModel as RxAppModel;
    const [jobNumber, setJobNumber] = React.useState<string>('');
    const [scannedJobNumber, setScannedJobNumber] = React.useState<string>('');
    const [key, setKey] = React.useState(Math.random());

    useEffect(() => {
        window.addEventListener("keypress", (event) => {
            setKey(Math.random());
        })
    }, []);

    useEffect(() => {
        setKey(Math.random());
    }, [appModel.drawerOpen]);

    const handleJobFinder = async () => {
        let error ="";
        try {
            const number = scannedJobNumber !== '' ? scannedJobNumber : jobNumber
            if(number === '')  {
                enqueueSnackbar(`${t`Cant search for a job without a number`}`, {variant: "error"});
                return
            }
            const resp = await fetch(`/api/jobs/search/${number}`, {method: "GET"})
                .then(resp => resp.json())
                .then(data => {
                    console.log(data);
                    setScannedJobNumber('');
                    setJobNumber('');
                    if(data['status'] === 'success') {
                        routerStore.history.push(`/job_workstation/jobs/${data['id']}/edit`);
                        enqueueSnackbar(`${t`Status`}: ${data.status}`, {variant: "success"});
                    } else {
                        routerStore.history.push(`/job_workstation`);
                        enqueueSnackbar(`${t`Job doesn't exist`}`, {variant: "error"});
                    }
                });
        } catch (err) {
            error = err;
            console.error(error);
            enqueueSnackbar({error}, {variant: "error"});
        }
    }

    const onChange = (e: any) => {
        setJobNumber(e.target.value);
    }

    const onEnterKey = async () => {
        await handleJobFinder();
    }

    const onComplete = async (code: string) => {
        setScannedJobNumber(code);
    }

    return (
        <PaddedPaper>
            <JobFinderScannerField jobNumber={jobNumber} onChange={onChange} onEnterKey={onEnterKey} onComplete={onComplete} key={key}/>
            <ButtonField text={'Submit'} onClick={handleJobFinder} buttonType={'submit'} color={'secondary'}/>
        </PaddedPaper>
    )
})