import React from "react";
import {Conditional, FormProps, IfFalse, IfTrue, ModelForm, ModelInput} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {t, Trans} from "@lingui/macro"
import {useSnackbar} from "notistack";
import {RSDModelInput} from "../../components/router_state_dependant_controls/RSDModelInput";
import {TagConditionStore} from "../../stores/TagConditionStore";
import {Alert} from "@material-ui/lab";
import {JobProcessCapabilitiesTab} from "../../components/job_processes/form/JobProcessCapabilitiesTab";
import {JobProcessConditionsTab} from "../../components/job_processes/form/JobProcessConditionsTab";
import {JobProcessOtherSettingsTab} from "../../components/job_processes/form/JobProcessOtherSettingsTab";
import {JobProcessModel} from "../../stores/machine/JobProcessStore";
import {TabsContainer} from "../../components/generic/TabsContainer";
import {Box} from "@material-ui/core";

type JobProcessFormProps = {
    model: JobProcessModel
} & Omit<FormProps, 'model'>

export const JobProcessForm: React.FunctionComponent<JobProcessFormProps> = observer(({model}) => {
    const {enqueueSnackbar} = useSnackbar();

    const afterSubmit = () => {
        if(model.viewModel.condition) {
            const newStateConditionModel = TagConditionStore.createModel();
            newStateConditionModel.viewModel.condition = model.viewModel.condition;
            newStateConditionModel.viewModel.job_process_id = model.id;
            newStateConditionModel.viewModel.submit();
            newStateConditionModel.commit().then(function(resp:any){
                enqueueSnackbar(`${t`Condition successfully created`}`, {variant: "success"})
            });
        }
    }

    return(
        <ModelForm model={model} afterSubmit={afterSubmit} suppressMakeCopy={true} suppressImportExport={true} readOnly={model.is_control_process}>
            <Conditional condition={model.is_control_process}>
                <IfTrue>
                    <Alert severity="info"><Trans>This is a system generated process and cannot be edited.</Trans></Alert>
                </IfTrue>
            </Conditional>
            <RSDModelInput model={model} name={'name'}/>
            <RSDModelInput model={model} name={'rank'}/>
            <ModelInput name={'display_name'} hint={{title: t`Display Name`, text: t`This name will be displayed instead of the process name.`}}/>
            <Conditional condition={model.isNew || model.is_control_process}>
                <IfFalse>
                    <Box mt={2}>
                        <TabsContainer tabs={
                                [
                                    {
                                        label: t`Capabilities`,
                                        component: <JobProcessCapabilitiesTab/>,
                                        defaultTab: true
                                    },
                                    {
                                        label: t`Process Condition`,
                                        component:  <JobProcessConditionsTab/>
                                    },
                                    {
                                        label: t`Other`,
                                        component: <JobProcessOtherSettingsTab/>
                                    }
                                ]
                            }
                        />
                    </Box>
                </IfFalse>
            </Conditional>
        </ModelForm>
    )
});