import * as React from 'react';
import {BreadModel, makeColumn, ModelTableDeleteButton} from "@rx-suite/ui";
import { t } from "@lingui/macro"
import {JobProcessForm} from "./JobProcessForm";
import {JobProcessStore} from "../../stores/machine/JobProcessStore";
import {JobRouterControlStore} from "../../stores/JobRouterControlStore";
import {observer} from "mobx-react-lite";
import {SettingStore} from "../../stores/SettingStore";

export const JobProcessesBreadModel = observer(() => {
    const routerInfo = JobRouterControlStore.selectedModel;
    const settings = SettingStore.selectedModel;
    const columns = React.useMemo(() => {
        const columns = [
            makeColumn('rank', t`Rank`, "string"),
            makeColumn('name', t`Process name`, "string"),
            makeColumn('display_name', t`Display name`, "string"),
        ]
        if(settings?.inf_enabled) {
            columns.push(makeColumn('inf_target_tag', t`INF Target Tag`, 'string'));
        }
        return columns;
    }, [settings]);

    return (
        <BreadModel store={JobProcessStore}
                    Form={JobProcessForm}
                    columns={columns}
                    tableProps={{
                        showCreateButton: routerInfo?.is_offline,
                        defaultSorted: [{id: 'rank', desc: false}],
                        replacementActions: {
                            Delete: (row) => {
                                if (row.model.is_control_process) {
                                    return null;
                                }
                                return <ModelTableDeleteButton store={row.store} model={row.model}/>
                            }
                        }
                    }}
        />)
});