import {Conditional, FormProps, PaddedPaper} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {Box, Divider, LinearProgress, Tab, Tabs, Typography} from "@material-ui/core";
import {t, Trans} from "@lingui/macro";
import {SettingStore} from "../../stores/SettingStore";
import React from "react";
import {routerClient} from "../../stores/RouterClient";
import {JobRouterControlStore} from "../../stores/JobRouterControlStore";
import {RouterControlButtons} from "../../components/job_router_controls/RouterControlButtons";
import {SystemStatusTab} from "../../components/job_router_controls/SystemStatusTab";
import {LmsConfigModel, LmsConfigStore} from "../../stores/LmsConfigStore";
import {Alert} from "@material-ui/lab";

interface JobRouterControlsProps {}

export const JobRouterControls: React.FunctionComponent<JobRouterControlsProps> = observer(({}) => {
    const router = JobRouterControlStore.selectedModel;
    const settings = SettingStore.selectedModel;
    const lmsConnections = LmsConfigStore.getAll();

    const [currentTab, setCurrentTab] = React.useState(0);
    const handleChange = (event: any, newValue: React.SetStateAction<number>) => {
        setCurrentTab(newValue);
    };

    const isUsingLegacyLMS = React.useMemo(() => {
        return lmsConnections.some((config: LmsConfigModel) => config.isUsingLegacyConnection);
    }, [lmsConnections]);


    if (!settings || !router) {
        return <LinearProgress color={'secondary'}/>
    }

    const routerLastBroadcast = routerClient.last_broadcast;
    const routerLastProgress = routerClient.startup_progress;

    return(
            <PaddedPaper>
                <Conditional condition={isUsingLegacyLMS}>
                    <Box mb={1}>
                        <Alert severity='warning' mb={1}>
                            <Trans>One or more LMS is using a legacy connection. Please contact support to have it updated.</Trans>
                        </Alert>
                    </Box>
                </Conditional>
                <RouterControlButtons router={router} disable={isUsingLegacyLMS}/>
                {router.is_startup &&
                <div>
                    <Typography variant={'h6'} display={'inline'}>
                        <Trans>
                            Router Starting... this may take a few minutes.
                        </Trans>
                    </Typography>
                    <LinearProgress variant="determinate" value={routerLastProgress} />
                    <Typography variant={'caption'}>{routerLastBroadcast}</Typography>
                </div>
                }
                <Divider/>
                <Tabs value={currentTab} onChange={handleChange} indicatorColor="primary" textColor="primary" variant="scrollable">
                    <Tab label={t`System Status`} key={0}/>
                </Tabs>
                <SystemStatusTab index={0} value={currentTab}/>
            </PaddedPaper>
    )
});