import * as React from 'react';
import {BreadModel, formatters, makeColumn} from "@rx-suite/ui";
import { t } from "@lingui/macro";
import {JobStore} from "../../stores/JobStore";
import {JobForm} from "./JobForm";
import {CheckCircle, RadioButtonUnchecked} from "@material-ui/icons";
import {green, red} from "@material-ui/core/colors";
import {JobButtons} from "../../components/jobs/JobButtons";
import {routerStore} from "@rx-suite/data";

export const JobsBreadModel = () => {
    //This is for when we access the breadModel from the root path, we still end up at the correct path
    if(routerStore.history.location.pathname === '/') {
        routerStore.history.push('/job_workstation/jobs');
    }

    const columns = React.useMemo(() => {
        return [
            makeColumn('number', t`Job number`, "string"),
            makeColumn('is_routing', t`Is Routing?`, "boolean",
                formatters.boolean(
                    <CheckCircle style={{color: green[500]}}/>,
                    <RadioButtonUnchecked style={{color: red[500]}}/>)),
            makeColumn('last_known_location', t`Last Known Location`, "string"),
            makeColumn('last_known_connector', t`Last Known Connector`, "string"),
            makeColumn('next_expected_location', t`Next Expected Location`, "string"),
            makeColumn('reject_reason', t`Reject Reason`, 'string')
        ]
    }, []);
    return (
        <BreadModel store={JobStore} Form={JobForm} columns={columns} tableProps={{ defaultPageSize: 100, customActions: (jobModel) => <JobButtons model={jobModel}/>}}/>
    )
};