import React from "react";
import {observer} from "mobx-react-lite";
import { t } from "@lingui/macro";
import {CheckboxField, FormProps, ModelForm, ModelInput} from "@rx-suite/ui";
import {MachineProcessSettingsTab} from "../../components/machines/form/shared/MachineProcessSettingsTab";
import {Box, Tab, Tabs} from "@material-ui/core";
import {MachineModel} from "../../stores/machine/MachineStore";
import {MachineCapabilitiesSettingsTab} from "../../components/machines/form/shared/MachineCapabilitiesSettingsTab";
import {MachineOtherSettingsTab} from "../../components/machines/form/shared/MachineOtherSettingsTab";
import {MachineStateSettingsTab} from "../../components/machines/form/mes/MachineStateSettingsTab";
import {MachineNameInput} from "../../components/machines/form/shared/MachineNameInput";

export const MachineForm: React.FunctionComponent<FormProps> = observer(({model}) => {
    const [currentTab, setCurrentTab] = React.useState(0);
    const handleChange = (event: any, newValue: React.SetStateAction<number>) => {
        setCurrentTab(newValue);
    };

    const handleCheckMachineGroupBoxChange = (field:string, value:string) => {
        model.nestedAssignment('update_machine_group', value);
    }

    const machine = model as MachineModel;

    return(
        <div>
            <ModelForm model={model} suppressMakeCopy suppressImportExport>
                <MachineNameInput model={machine}/>
                {machine.sn && <ModelInput name={'sn'} disabled={true}/>}
                <Box mt={3}>
                    <Tabs value={currentTab} onChange={handleChange} indicatorColor="primary"  textColor="primary" variant="scrollable">
                        <Tab label={t`Process`} key={0}/>
                        <Tab label={t`Capabilities`} key={1}/>
                        {model.sn && <Tab label={t`Machine States`} key={2}/>}
                        {model.sn && <Tab label={t`Other Settings`} key={3}/>}
                    </Tabs>
                    <MachineProcessSettingsTab model={machine} index={0} value={currentTab}/>
                    <MachineCapabilitiesSettingsTab model={machine} index={1} value={currentTab} />
                    <MachineStateSettingsTab model={machine} index={2} value={currentTab} />
                    <MachineOtherSettingsTab model={machine} index={3} value={currentTab} />
                    {model.sn && <CheckboxField label={t`Update the machine group?`} onChange={handleCheckMachineGroupBoxChange} checked={model.viewModel.update_machine_group}/>}
                </Box>
            </ModelForm>
        </div>
    )
});