import * as React from 'react';
import {BreadModel, makeColumn} from "@rx-suite/ui";
import { t } from "@lingui/macro";
import {MachineModel, MachineStore} from "../../stores/machine/MachineStore";
import {CapabilityStore} from "../../stores/machine/CapabilityStore";
import {MachineForm} from "./MachineForm";
import {Model} from "@rx-suite/data";
import {observer} from "mobx-react-lite";
import {MesSelectMachineState} from "../../components/machines/MesSelectMachineState";
import {OpcuaSelectMachineState} from "../../components/machines/OpcuaSelectMachineState";
import {SettingStore} from "../../stores/SettingStore";
import {useMachineCapabilitiesColumn} from "../../hooks/table_columns/useMachineCapabilitiesColumn";

const colors = {
    ready: 'rgb(11,8,251, .4)',
    setup: 'rgb(255,225,0, .4)',
    waitingforjobs: 'rgb(1,250,4, .4)',
    processing: 'rgb(0,127,0, .4)',
    error: 'rgb(253,11,0, .4)',
    halt: 'rgb(243,166,156, .4)',
    estop: 'rgb(250,5,129, .4)'
}

export const MesMachinesBreadModel = observer(() => {
    const settings = SettingStore.selectedModel;

    const getColor = (state: string) => {
        let white = 'rgb(255,255,255)';
        if(!state) return white
        let newColor = colors[state.toLowerCase()];
        if(newColor) {
            return newColor
        } else {
            return white;
        }
    }

    const columns = React.useMemo(() => {
        const c = [
            makeColumn('sn', t`Serial number`, "string"),
            makeColumn('name', t`Machine name`, "string"),
            {Header: t`Current state`, id: 'last_reported_state', accessor: 'last_reported_state', getProps: (state, rowInfo, column) => {
                if (!rowInfo || !rowInfo.row.last_reported_state) {
                    return {}
                }
                return {
                    style: {
                        background: getColor(rowInfo.row.last_reported_state),
                        //fontWeight: 'bold'
                    }
                }
                }},
            makeColumn('job_process', t`Process`, "string", (jobProcessModel) => {
                if(jobProcessModel)
                    return jobProcessModel.name
                else
                    return ''}),
            useMachineCapabilitiesColumn(),
            {Header: t`Force state`, accessor: d => d, id: 'forced_state', Cell: (cellInfo: {value: Model }) => {
                if(cellInfo.value.sn) {
                    return <MesSelectMachineState model={cellInfo.value}/>
                }
                else {
                    return <OpcuaSelectMachineState model={cellInfo.value}/>
                }
            }}
        ]
        if(settings?.use_inf) {
            //TODO: this will be changed to output lms config name instead of just the id
            c.push(makeColumn('lms_config_id', t`Lms Config Id`, 'string'))
        }
        return c
    }, [CapabilityStore.models]);

    return (
        <BreadModel store={MachineStore} Form={MachineForm} columns={columns} tableProps={
            {
                noLinkColumns: ['forced_state'],
                pageSize: 100
            }
        }/>
    )
});