import * as React from 'react';
import {BreadModel, makeColumn} from "@rx-suite/ui";
import { t } from "@lingui/macro";
import {MachineStore} from "../../stores/machine/MachineStore";
import { CapabilityStore} from "../../stores/machine/CapabilityStore";
import {MachineForm} from "./MachineForm";
import {OpcuaSelectMachineState} from "../../components/machines/OpcuaSelectMachineState";
import {Model} from "@rx-suite/data";
import {observer} from "mobx-react-lite";
import {useMachineCapabilitiesColumn} from "../../hooks/table_columns/useMachineCapabilitiesColumn";

export const OpcuaMachinesBreadModel = observer(() => {
    const columns = React.useMemo(() => {
        return [
            makeColumn('name', t`Machine name`, "string"),
            makeColumn('job_process', t`Process`, "string", (jobProcessModel) => {
                if(jobProcessModel)
                    return jobProcessModel.name
                else
                    return ''}
            ),
            useMachineCapabilitiesColumn(),
            {Header: t`State`, accessor: d => d, id: 'state', Cell: (cellInfo: {value: Model }) => {
                return <OpcuaSelectMachineState model={cellInfo.value}/>
            }}
        ]

    }, [CapabilityStore.models]);

    return (
        <BreadModel store={MachineStore} Form={MachineForm} columns={columns} tableProps={{ noLinkColumns: ['state']}}/>
    )
});