import React, {useEffect, useState} from "react";
import {FormProps} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {LinearProgress} from "@material-ui/core";
import {DeviceStore} from "../../stores/Device/DeviceStore";
import {ConnectorStore} from "../../stores/Device/ConnectorStore";
import {RouteApplication} from "./RouteApplication";
import {BodyWidgetComponent} from "../../react-diagrams-helpers/BodyWidgetComponent";
import {MachineStore} from "../../stores/machine/MachineStore";
import {RoutingGraphStore} from "../../stores/RoutingGraphStore";
import { Prompt } from "react-router-dom";
import { t } from "@lingui/macro";
import {ComponentStore} from "../../stores/ComponentStore";

export const RouteBuilder: React.FunctionComponent<FormProps> = observer(({model}) => {

    const [app, setApp] = useState<any>(null);

    const devices = DeviceStore.getAll();
    const connectors = ConnectorStore.getAll();
    const machines = MachineStore.getAll();
    const routingGraph = RoutingGraphStore.get(1);
    const components = ComponentStore.getAll();

    /*useEffect(() => {
        if (routingGraph) {
            routingGraph.serialized_data = JSON.parse(routingGraph.serialized_data);
        }
    }, [routingGraph])*/

    useEffect(() => {
        setApp(new RouteApplication(routingGraph));
    }, [routingGraph])

    if(DeviceStore.isLoading || MachineStore.isLoading || ConnectorStore.isLoading || !routingGraph || ComponentStore.isLoading || !app) {
        return <LinearProgress/>
    }

    const nodes = [];
    for(let i = 0; i < devices.length; i++){
        const device = devices[i];

        const deviceConnectors = connectors.filter((connector) => connector.component_id === device.component_id);
        const node = {
            id: device.component_id,
            inputs: deviceConnectors.filter((connector) => connector.connector_type === 'input'),
            outputs: deviceConnectors.filter((connector) => connector.connector_type === 'output'),
            type: 'device',
            name: device.name
        }
        nodes.push(node);
    }

    for(let i = 0; i < machines.length; i++) {
        const machine = machines[i];
        const machineConnectors = connectors.filter((connector) => connector.component_id === machine.component_id);
        const node = {
            id: machine.component_id,
            inputs: machineConnectors.filter((connector) => connector.connector_type === 'input'),
            outputs: machineConnectors.filter((connector) => connector.connector_type === 'output'),
            type: 'machine',
            name: machine.name
        }
        nodes.push(node);
    }

    //TODO: still relevant?
    //const app = new RouteApplication(routingGraph);

    /*if(!(routerInfo?.is_offline)) {
        app.getActiveDiagram().setLocked(true);
    }*/

    return(
        <div>
            <Prompt message={t`Unsaved changes will not be saved, really leave?`} when={true}/>
            <BodyWidgetComponent app={app} preProcessedNodes={nodes} routingGraph={routingGraph} /*settings={settings}*//>
        </div>
    )
});