import React from "react";
import {
    FormProps,
    ModelForm,
} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {t} from "@lingui/macro";
import {SettingModel, SettingStore} from "../../stores/SettingStore";
import {
    LinearProgress, Tab, Tabs
} from "@material-ui/core";
import {AdditionalFeaturesTab} from "../../components/settings/AdditionalFeaturesTab";
import {PLCConnectionTab} from "../../components/settings/PLCConectionSettingsTab";
import {JobDataSettingsTab} from "../../components/settings/JobDataSettingsTab";
import {RoutingSettingsTab} from "../../components/settings/RoutingSettingsTab";
import {JobRouterControlStore} from "../../stores/JobRouterControlStore";
import {InfSettingsTab} from "../../components/settings/InfSettingsTab";

export const SettingForm: React.FunctionComponent<FormProps> = observer(() => {
    const [currentTab, setCurrentTab] = React.useState(0);
    const handleChange = (event: any, newValue: React.SetStateAction<number>) => {
        setCurrentTab(newValue);
    };

    const model = SettingStore.selectedModel
    const router = JobRouterControlStore.selectedModel;

    if (!model || !router) {
        return <LinearProgress color={'secondary'}/>
    }

    return (
        <ModelForm model={model} maxWidth={"xl"} readOnly={!router.is_offline} suppressImportExport suppressMakeCopy>
            <Tabs value={currentTab} onChange={handleChange} indicatorColor="primary"  textColor="primary" variant="scrollable">
                <Tab label={t`Job Data`} key={0}/>
                <Tab label={t`PLC Connection`} key={1}/>
                <Tab label={t`Routing`} key={2}/>
                <Tab label={t`Job INF Data`} key={3}/>
                <Tab label={t`Additional Features`} key={4}/>
            </Tabs>
            <JobDataSettingsTab disable={router.is_online} index={0} value={currentTab} />
            <PLCConnectionTab settings={model} disable={router.is_online} index={1} value={currentTab} />
            <RoutingSettingsTab settings={model} disable={router.is_online} index={2} value={currentTab}/>
            <InfSettingsTab disable={router.is_online} index={3} value={currentTab} />
            <AdditionalFeaturesTab settings={model} disable={router.is_online} index={4} value={currentTab} />
        </ModelForm>
    )
});