import {dataStorePermission} from "@rx-suite/ui";
import {
    Settings,
    AssignmentReturned,
    DeviceHub,
    Label,
    ImportExport,
    SlowMotionVideo,
    List,
    Build,
    AddCircle
} from '@material-ui/icons';
import MemoryIcon from '@material-ui/icons/Memory';
import {DeviceTypeStore} from "./stores/Device/DeviceTypeStore";
import {DeviceTypesBreadModel} from "./pages/device_types/DeviceTypesBreadModel";
import {SettingStore} from "./stores/SettingStore";
import {MachinesBreadModel} from "./pages/machines/MachinesBreadModel";
import {MachineStore} from "./stores/machine/MachineStore";
import {DeviceStore} from "./stores/Device/DeviceStore";
import {DevicesBreadModel} from "./pages/devices/DevicesBreadModel";
import {JobProcessesBreadModel} from "./pages/job_processes/JobProcessesBreadModel";
import {CapabilitiesBreadModel} from "./pages/capabilities/CapabilitiesBreadModel";
import {RoutingGraphStore} from "./stores/RoutingGraphStore";
import {ConnectorStore} from "./stores/Device/ConnectorStore";
import {ConnectorsBreadModel} from "./pages/connectors/ConnectorsBreadModel";
import {DeviceTimerStore} from "./stores/Device/DeviceTimerStore";
import {DeviceTimersBreadModel} from "./pages/device_timers/DeviceTimersBreadModel";
import {TagStore} from "./stores/TagStore";
import {TagsBreadModel} from "./pages/tags/TagBreadModel";
import {JobStore} from "./stores/JobStore";
import {JobsBreadModel} from "./pages/jobs/JobsBreadModel";
import {RequiredProcessStore} from "./stores/RequiredProcessStore";
import {RequiredProcessesBreadModel} from "./pages/required_processes/RequiredProcessesBreadModel";
import {SettingForm} from "./pages/settings/SettingForm";
import { t } from "@lingui/macro";
import {RouteBuilder} from "./pages/routes/RouteBuilder";
import {computedFn} from "mobx-utils";
import {FetchedJobForm} from "./pages/fetched_jobs/FetchedJobForm";
import {JobFinderFormEntryPoint} from "./pages/job_finder/JobFinderFormEntryPoint";
import {JobRouterControlStore} from "./stores/JobRouterControlStore";
import React from "react";
import {JobRouterControls} from "./pages/job_router_controls/JobRouterControls";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import {faGlasses} from "@rx-suite/pro-solid-svg-icons/faGlasses";
import {faRandom} from "@rx-suite/pro-solid-svg-icons/faRandom";
import {JobCreateForm} from "./pages/jobs/JobCreateForm";

export const getRoutes = computedFn(() => {
    return [
        {
            to: "/",
            permission: dataStorePermission(JobStore),
            exact: false,
            Component: JobsBreadModel,
        },
        {
            label: t`Command Center`,
            to: "/command_center",
            permission: dataStorePermission(JobRouterControlStore),
            exact: false,
            Icon: SlowMotionVideo,
            Component:  () => <JobRouterControls/>
        },
        {
            label: t`Job Workstation`,
            to: "/job_workstation",
            exact: true,
            permission: {
                target: JobStore.permissionTarget as string,
                action: 'read'
            },
            Icon: () => <FontAwesomeIcon icon={faGlasses} style={{height: '22px', width: '22px'}}/>,
            Component: JobFinderFormEntryPoint,
            children: [
                {
                    label: t`All Jobs`,
                    to: "/jobs",
                    exact: false,
                    permission: dataStorePermission(JobStore),
                    Component: JobsBreadModel,
                    Icon: List
                },
                {
                    label: t`Job Fetcher`,
                    to: "/fetch",
                    exact: false,
                    Icon: ImportExport,
                    Component: FetchedJobForm
                },
                {
                    label: t`Job Create`,
                    to: "/job_create",
                    exact: false,
                    permission: {
                        target: JobStore.permissionTarget,
                        action: 'create'
                    },
                    Icon: AddCircle,
                    Component: JobCreateForm,
                    shouldMount: () => { return SettingStore.selectedModel ? SettingStore.selectedModel?.job_create_workstation_enabled : false }
                }
            ]
        },
        {
            label: t`Devices`,
            to: "/devices",
            exact: false,
            permission: dataStorePermission(DeviceStore),
            Component: DevicesBreadModel,
            Icon: () => <FontAwesomeIcon icon={faRandom} style={{height: '22px', width: '22px'}}/>,
        },
        {
            label: t`Machines`,
            to: "/machines",
            exact: false,
            permission: dataStorePermission(MachineStore),
            Component: MachinesBreadModel,
            Icon: MemoryIcon
        },
        {
            label: t`Settings`,
            to: "/settings",
            exact: true,
            permission: dataStorePermission(SettingStore),
            Component: SettingForm,
            Icon: Settings,
            children: [
                {
                    label: t`Routing Graph`,
                    to: "/routing_graph",
                    exact: false,
                    permission: dataStorePermission(RoutingGraphStore),
                    Component: RouteBuilder,
                    Icon: DeviceHub
                },
                {
                    label: t`Processes`,
                    to: "/job_processes",
                    exact: false,
                    permission: dataStorePermission(MachineStore),
                    Icon: AssignmentReturned,
                    Component: JobProcessesBreadModel,
                    children: [
                        {
                            to: "/capabilities",
                            exact: false,
                            permission: dataStorePermission(MachineStore),
                            Component: CapabilitiesBreadModel
                        }
                    ]
                },
                {
                    label: t`Tags`,
                    to: "/tags",
                    exact: false,
                    permission: dataStorePermission(TagStore),
                    Component: TagsBreadModel,
                    Icon: Label
                },
                {
                    label: t`Device Types`,
                    to: "/device_types",
                    exact: false,
                    permission: dataStorePermission(DeviceTypeStore),
                    Component: DeviceTypesBreadModel,
                    Icon: Build,
                    shouldMount: () => { return SettingStore.selectedModel ? SettingStore.selectedModel.isUsingOPCUA : false }
                }
            ]
        },
        {
            to: "/connectors",
            exact: false,
            permission: dataStorePermission(ConnectorStore),
            Component: ConnectorsBreadModel,
        },
        {
            to: "/device_timers",
            exact: false,
            permission: dataStorePermission(DeviceTimerStore),
            Component: DeviceTimersBreadModel,
        },
        {
            to: "/required_processes",
            exact: false,
            permission: dataStorePermission(RequiredProcessStore),
            Component: RequiredProcessesBreadModel,
        }
    ];
});
