import {attribute, DataStore, Model, model} from '@rx-suite/data';
import * as yup from 'yup';
import { t } from "@lingui/macro"

@model({
    transportLayer: "/api/connectors",
    permissionTarget: "Connector",
    routingInfo: {
        update: '/connectors/:id/edit'
    }
})
export class ConnectorModel extends Model {
    @attribute({
        label: t`Id`,
        validation: yup.number()
    })
    id: number = 0;

    @attribute({
        label: t`Name`,
        validation: yup.string().required()
    })
    name: string = '';

    @attribute({
        label: t`Device Name`,
        validation: yup.string().nullable()
    })
    device_name: string | null = '';

    @attribute({
        label: t`Variable`,
        validation: yup.string().nullable()
    })
    variable: string = '';

    @attribute({
        label: t`State?`,
        validation: yup.string()
    })
    state: string = '';

    @attribute({
        label: t`Priority`,
        validation: yup.number().nullable()
    })
    priority: number = 0;

    @attribute({
        label: t`Path`,
        validation: yup.number().nullable()
    })
    path: string = '0';

    @attribute({
        label: t`All In One`,
        validation: yup.boolean().nullable()
    })
    all_in_one: boolean = false;

    @attribute({
        label: t`Type`,
        validation: yup.string().nullable()
    })
    connector_type: string = '';

    @attribute({
        label: t`Component Id`,
        validation: yup.number().nullable()
    })
    component_id: number | null = null;

    @attribute({
        label: t`Routing Command Id`,
        validation: yup.array()
    })
    device_routing_command_ids: any = [];

    @attribute({
        label: t`Rx-Scanner Reference`,
        validation: yup.number().nullable()
    })
    rx_scanner_reference: number | null = null;

    @attribute({
        label: t`Use OPCUA Node`,
        validation: yup.string().nullable()
    })
    opcua_scanner_reference: string | null = null;

    @attribute({
        label: t`Scanner Name`,
        validation: yup.string().nullable()
    })
    scanner_name: string = "";

    @attribute({
        label: t`Action delay in milliseconds`,
        validation: yup.number().nullable()
    })
    action_delay: number = 0;

    @attribute({
        label: t`Scanner Retry`,
        validation: yup.number().nullable()
    })
    scanner_retry: number = 3;

    @attribute({
        label: t`Control action`,
        validation: yup.string()
    })
    control_action: string = 'none';

    constructor() {
        super();
        super.setup();
    }
}

export const ConnectorStore = ConnectorModel.store as DataStore<ConnectorModel>;
