import {DataStore, Model, attribute, model} from "@rx-suite/data";
import {t} from "@lingui/macro";
import * as yup from "yup";
import {action} from "mobx";

@model({
    transportLayer: "/api/device_routing_command_devices",
    permissionTarget: "Device",
    routingInfo: {
        read: '/device_routing_command_devices/:id/edit',
        update: '/device_routing_command_devices/:id/edit'
    }
})

export class DeviceRoutingCommandDeviceModel extends Model {
    @attribute({label: t`Device`, connects: "DeviceModel"})
    device_id: string | null = null;

    @attribute({label: t`Device Routing Command`, connects: "RoutingCommandModel"})
    device_routing_command_id: string | null = null;

    @attribute({label: t`Enabled?`, validation: yup.string()})
    enabled: boolean = true;

    @action
    async toggle() {
        return await fetch(`${DeviceRoutingCommandDeviceStore.transportLayer.base}/${this.id}/toggle`, {method: "PUT"});
    }

    constructor() {
        super();
        super.setup();
    }
}

export const DeviceRoutingCommandDeviceStore = DeviceRoutingCommandDeviceModel.store as DataStore<DeviceRoutingCommandDeviceModel>;
