import {attribute, DataStore, Model, model} from '@rx-suite/data';
import * as yup from 'yup';
import { t } from "@lingui/macro"

@model({
    transportLayer: '/api/devices',
    permissionTarget: "Device",
    routingInfo: {
        create: '/devices/create',
        update: '/devices/:id/edit'
    }
})
export class DeviceModel extends Model {

    @attribute({
        label: t`Name`,
        validation: yup.string().required(t`Name is required`)
    })
    name: string = '';

    @attribute({
        label: t`Device type`,
        validation: yup.number().nullable()
    })
    device_type_id: number = 0;

    @attribute({
        label: t`Component`,
        validation: yup.number()
    })
    component_id: number = 0;

    @attribute({
        label: t`State`,
        validation: yup.string()
    })
    state: string = '';

    @attribute({
        label: t`Number of scanners`,
        validation: yup.number()
    })
    num_scanners: number = 0;

    @attribute({
        label: t`Routing Retry Delay (seconds)`,
        validation: yup.number().nullable()
    })
    routing_retry_delay: number | null = null;

    @attribute({
        label: t`Delay on Command Complete (milliseconds)`,
        validation: yup.number().nullable()
    })
    delay_on_command_complete: number = 0;

    @attribute({
        label: t`Connector ids`,
        validation: yup.array()
    })
    connector_ids: any = []

    @attribute({
        label: t`Device routing command ids`,
        validation: yup.array()
    })
    device_routing_command_ids: any = []

    @attribute({
        label: t`Extra requirement Ids`,
        validation: yup.array()
    })
    extra_requirement_ids: any = []

    @attribute({
        label: t`Device Timer Ids`,
        validation: yup.array()
    })
    device_timer_ids: any = []

    @attribute({
        label: t`Device Routing Command Device Ids`,
        validation: yup.array()
    })
    device_routing_command_device_ids: any = []

    @attribute({
        label: t`Number of Outputs`,
        validation: yup.number().nullable()
    })
    number_of_outputs: number = 2;

    @attribute({
        label: t`Send Job State as`,
        validation: yup.string().nullable()
    })
    send_job_state_as: string | null = null;

    @attribute({
        label: t`Job State Process`,
        validation: yup.string().nullable()
    })
    job_state_process: string | null = null;

    constructor() {
        super();
        super.setup();
    }
}

export const DeviceStore = DeviceModel.store as DataStore<DeviceModel>;
