import {attribute, DataStore, Model, model} from '@rx-suite/data';
import * as yup from 'yup';
import { t } from "@lingui/macro"

@model({
    transportLayer: '/api/device_types',
    permissionTarget: "DeviceType",
    routingInfo: {
        create: 'device_types/create',
        read: 'device_types/:id/edit',
        update: 'device_types/:id/edit'
    }
})
export class DeviceTypeModel extends Model {

    @attribute({
        label: t`Id`,
        validation: yup.number()
    })
    id: number = 0;

    @attribute({
        label: t`Name`,
        validation: yup.string().required(t`Name is required`)
    })
    name: string = '';

    @attribute({
        label: t`All in one?`,
        validation: yup.boolean().nullable()
    })
    all_in_one: boolean | null = null;

    @attribute({
        label: t`Root node id`,
        validation: yup.string().nullable()
    })
    root_node_id: string = "";

    @attribute({
        label: t`Routing retry delay in seconds`,
        validation: yup.number().nullable()
    })
    routing_retry_delay: number | null = null;

    @attribute({
        label: t`Delay on command complete in milliseconds`,
        validation: yup.number()
    })
    delay_on_command_complete: number = 0;

        @attribute({
        label: t`Device routing command ids`,
        validation: yup.array().nullable()
    })
    device_routing_command_ids: number[] = [];

    @attribute({
        label: t`Device timer ids`,
        validation: yup.array().nullable()
    })
    device_timer_ids: number[] = [];

    @attribute({
        label: t`Connector ids`,
        validation: yup.array().nullable()
    })
    opcua_connector_ids: number[] = [];

    constructor() {
        super();
        super.setup();
    }
}

export const DeviceTypeStore = DeviceTypeModel.store as DataStore<DeviceTypeModel>;
