import {attribute, DataStore, Model, model} from '@rx-suite/data';
import * as yup from 'yup';
import { t } from "@lingui/macro"

@model({
    transportLayer: "/api/extra_requirements",
    permissionTarget: "ExtraRequirement",
    routingInfo: {
        create: '/extra_requirements/create',
    }
})

export class ExtraRequirementModel extends Model {

    @attribute({
        label: t`Id`,
        validation: yup.number()
    })
    id: number = 0;

    @attribute({
        label: t`Device id`,
        validation: yup.number()
    })
    device_id: number = 0;

    @attribute({
        label: t`Value`,
        validation: yup.string()
    })
    value: string = '';

    @attribute({
        label: t`The command on which the extra requirement will trigger`,
        validation: yup.number()
    })
    device_routing_command_id: number = 0;

    @attribute({
        label: t`routing_command_id`,
        validation: yup.string()
    })
    device_routing_command_name: string = '';

    @attribute({
        label: t`Node to check`,
        validation: yup.number()
    })
    node_id: number = 0;

    @attribute({
        label: t`node name`,
        validation: yup.string()
    })
    node_name: string = '';

    @attribute({
        label: t`Connector to check`,
        validation: yup.number()
    })
    connector_id: number = 0;

    @attribute({
        label: t`connector name`,
        validation: yup.string()
    })
    connector_name: string = '';

    @attribute({
        label: t`Only trigger when the next process is`,
        validation: yup.number().nullable()
    })
    job_process_id: number | null = null;

    @attribute({
        label: t`Job process name`,
        validation: yup.string()
    })
    job_process_name: string = '';

    constructor() {
        super();
        super.setup();
    }
}

export const ExtraRequirementStore = ExtraRequirementModel.store as DataStore<ExtraRequirementModel>;
