import {attribute, DataStore, Model, model} from '@rx-suite/data';
import * as yup from 'yup';
import { t } from "@lingui/macro"
import {ConnectorModel} from "./ConnectorStore";

@model({
    transportLayer: "/api/device_routing_commands",
    permissionTarget: "Device",
    routingInfo: {
        create: '/device_routing_commands/create',
        read: '/device_routing_commands/capabilities/:id/edit',
        update: '/device_routing_commands/capabilities/:id/edit'
    }
})
export class RoutingCommandModel extends Model {

     @attribute({
        label: t`Command`,
        validation: yup.string().required(t`A command name is required for the creation of a c`)
    })
    command: string = '';

    @attribute({
        label: t`Parameter`,
        validation: yup.string()
    })
    parameter: string = '';

    @attribute({
        label: t`Input`,
        validation: yup.number().required(t`An input is required for the creation of a routing command`)
    })
    device_input_id: number = 0;

    @attribute({
        label: t`Output`,
        validation: yup.number().required(t`An output is required for the creation of a routing command`)
    })
    device_output_id: number = 0;

    @attribute({
        label: t`Device type`,
        validation: yup.number().nullable()
    })
    device_type_id: number | null = null;

    @attribute({
        label: t`Connectors`,
        validation: yup.array()
    })
    connectors: ConnectorModel[] =[];

    @attribute({
        label: t`Connectors Ids`,
        validation: yup.array()
    })
    opcua_connector_ids: number[] =[];

    @attribute({
        label: t`Connector names (comma separated)`,
        validation: yup.string()
    })
    connector_names: string = "";

    constructor() {
        super();
        super.setup();
    }
}

export const RoutingCommandStore = RoutingCommandModel.store as DataStore<RoutingCommandModel>;
