import {attribute, DataStore, Model, model} from '@rx-suite/data';
import { t } from "@lingui/macro"
import {computed} from "mobx";
import {JobStore} from "./JobStore";

@model({
    transportLayer: "/api/job_router_controls",
    permissionTarget: "JobRouterControl",
    singleton: true,
    eager: true,
    routingInfo: {
        read: '/job_router_controls/:id'
    }
})

export class JobRouterControlModel extends Model {
    @attribute({
        label: t`status`
    })
    status: 'offline' | 'startup' |'ready' | 'standby' = 'offline';

    @attribute({
        label: t`last_server_message?`
    })
    last_server_message: string = '';

    @attribute({
        label: t`Rx_Data Online?`,
    })
    rx_data_online: boolean = false;

    @attribute({
        label: t`Rx_Scanners Online?`,
    })
    rx_scanners_online: boolean = false;

    @attribute({
        label: t`Last Update`,
    })
    updated_at: Date = new Date();

    @computed get is_ready(): boolean {
        return this.status === 'ready';
    };

    @computed get is_standby(): boolean {
        return this.status === 'standby';
    };

    //If the router is in state 'ready' or 'startup', it is online.
    @computed get is_online(): boolean {
        return !this.is_offline
    }

    @computed get is_offline(): boolean {
        return this.status === 'offline';
    };

    @computed get is_startup(): boolean {
        return this.status === 'startup';
    };

    async start(): Promise<Response> {
        return await fetch(`/api/job_router_controls/start`, {
            method: "PUT",
            headers: {'Content-Type': 'application/json'}
        });
    }

    async stop(): Promise<Response> {
        const resp = await fetch(`/api/job_router_controls/stop`, {
            method: "PUT",
            headers: {'Content-Type': 'application/json'}
        });
        // Force the job store to refresh as the backend won't broadcast the job.is_routing false for every job
        JobStore.getTableData(true);
        return resp;
    }

    constructor() {
        super();
        super.setup();
    }
}

export const JobRouterControlStore = JobRouterControlModel.store as DataStore<JobRouterControlModel>;


