import {attribute, DataStore, Model, model, Types} from '@rx-suite/data';
import * as yup from 'yup';
import { t } from "@lingui/macro"
import {action} from "mobx";

@model({
    transportLayer: "/api/jobs",
    permissionTarget: "Job",
    routingInfo: {
        update: 'jobs/:id/edit'
    }
})

export class JobModel extends Model {
    types: Types = {
        required_processes: 'array'
    }
    @attribute({
        label: t`id`,
        validation: yup.number()
    })
    id: number = 0;

    @attribute({
        label: t`Job Number`,
        validation: yup.string()
    })
    number: string = '';

    @attribute({
        label: t`Job Numbers`,
        validation: yup.string()
    })
    job_numbers: string = '';

    @attribute({
        label: t`Last Known Location`,
        validation: yup.string()
    })
    last_known_location: string = '';

    @attribute({
        label: t`Next Expected Location`,
        validation: yup.string()
    })
    next_expected_location: string = '';

    @attribute({
        label: t`Last Known Connector`,
        validation: yup.string()
    })
    last_known_connector: string = '';

    @attribute({
        label: t`Required Processes`,
        validation: yup.array()
    })
    required_process_ids: number[] = [];

    @attribute({
        label: t`Active`,
        validation: yup.boolean()
    })
    active: boolean = true;

    @attribute({
        label: t`Is being routed?`,
        validation: yup.boolean()
    })
    is_routing: boolean = false;

    @attribute({
        label: t`State`,
        validation: yup.string()
    })
    state: string = "";

    @attribute({
        label: t`Reject reason`,
        validation: yup.string().nullable()
    })
    reject_reason: string = "";

    @attribute({
        label: t`Reject description`,
        validation: yup.string().nullable()
    })
    reject_description: string = "";

    @attribute({
        label: t`Rx-Data Job status`,
        validation: yup.string().nullable()
    })
    rx_data_status: string = "";

    @attribute({
        label: t`Inf Target Machine`,
        validation: yup.string().nullable()
    })
    inf_target_machine_id: string = "";

    constructor() {
        super();
        super.setup();
    }

    @action async refreshHistory(filter_ids?: ReadonlyArray<number>) {

        try {

            const response = await fetch(`${JobStore.transportLayer.base}/${this.id}/job_history`, {
                method: "POST",
                headers: {'Content-Type': 'application/json'},
                body: JSON.stringify({filter_ids: filter_ids || null})
            });
            const data = await response.json();
            return data;

        } catch (e) {

            // if the fetch fails, return an error object to the form
            return { error: 'cannotFetchData' };
        }
    };
}

export const JobStore = JobModel.store as DataStore<JobModel>;