import {attribute, DataStore, Model, model} from '@rx-suite/data';
import * as yup from 'yup';
import { t } from "@lingui/macro"
import {CapabilitiesModel} from "./machine/CapabilityStore";

@model({
    transportLayer: "/api/required_processes",
    permissionTarget: "RequiredProcess",
    routingInfo: {
        update: '/required_processes/:id/edit'
    }
})

export class RequiredProcessModel extends Model {
    @attribute({
        label: t`Id`,
        validation: yup.number()
    })
    id: number = 0;

    @attribute({
        label: t`Side`,
        validation: yup.string()
    })
    side: string = '';

    @attribute({
        label: t`State`,
        validation: yup.string()
    })
    state: string = '';

    @attribute({
        label: t`Force to machine`,
        validation: yup.string().nullable()
    })
    force_to_machine: string = '';

    @attribute({
        label: t`Completed?`,
        validation: yup.boolean()
    })
    completed: boolean = false;

    @attribute({
        label: t`Job Id`,
        validation: yup.number()
    })
    job_id: number = 0;

    @attribute({
        label: t`Job Id`,
        validation: yup.array()
    })
    required_process_state_histories: object = [];

    @attribute({
        label: t`Job Process`,
        validation: yup.object()
    })
    job_process: any = {};

    @attribute({
        label: t`Job Process Id`,
        validation: yup.number()
    })
    job_process_id: number = 0;

    @attribute({
        label: t`Capability required processes`,
        validation: yup.object().nullable()
    })
    capability_required_processes: object[] = [];

    @attribute({
        label: t`Capabilities`,
        validation: yup.object().nullable()
    })
    capabilities: CapabilitiesModel[] | null = null;

    @attribute({
        label: t`Capabilities`,
        validation: yup.object().nullable()
    })
    capability_ids: number[] | null = null;

    @attribute({
        label: t`Process On The Opposite Side`,
        validation: yup.object().nullable()
    })
    opposite_process: RequiredProcessModel | null = null

    @attribute({
        label: t`Is rework?`,
        validation: yup.boolean()
    })
    is_rework: boolean = false;

    constructor() {
        super();
        super.setup();
    }
}

export const RequiredProcessStore = RequiredProcessModel.store as DataStore<RequiredProcessModel>;