import {attribute, DataStore, model, Model} from '@rx-suite/data';
import * as yup from 'yup';
import { t } from "@lingui/macro"
import {action} from "mobx";

@model({
    transportLayer: "/api/capability_machines",
    permissionTarget: "CapabilityMachine",
    routingInfo: {
        create: "/capability_machines/create",
        update: "/capability_machines/:id/edit",
        read: "/capability_machines/:id"
    }
})
export class CapabilityMachineModel extends Model {
    @attribute({
        label: t`Capability Id`,
        validation: yup.number()
    })
    capability_id: number = 0;

    @attribute({
        label: t`Capability Name`,
        validation: yup.string()
    })
    capability_name: string = "";

    @attribute({
        label: t`Machine Id`,
        validation: yup.number()
    })
    machine_id: number = 0;

    @attribute({
        label: t`Enabled`,
        validation: yup.boolean()
    })
    enabled: boolean = true;

    @action
    async toggle() {
        return await fetch(`${CapabilityMachineStore.transportLayer.base}/${this.id}/toggle`, {method: "PUT"});
    }

    constructor() {
        super();
        super.setup();
    }
}

export const CapabilityMachineStore = CapabilityMachineModel.store as DataStore<CapabilityMachineModel>;
