import {attribute, DataStore, Model, model} from '@rx-suite/data';
import * as yup from 'yup';
import { t } from "@lingui/macro"
import {JobRouterControlStore} from "../JobRouterControlStore";
import {computed} from "mobx";

@model({
    transportLayer: "/api/job_processes",
    permissionTarget: "Machine",
    routingInfo: {
        create: '/settings/job_processes/create',
        update: '/settings/job_processes/:id/edit'
    }
})
export class JobProcessModel extends Model {
    canDelete(): boolean {
        const routerInfo = JobRouterControlStore.selectedModel;
        if(routerInfo?.is_offline === undefined) {
            return false
        }
        return routerInfo?.is_offline;
    }

    @attribute({
        label: t`Id`,
        validation: yup.number()
    })
    id: number = 0;

    @attribute({
        label: t`Process name`,
        validation: yup.string().required("Field name is required")
    })
    name: string = "";

    @attribute({
        label: t`Display name`,
        validation: yup.string().nullable()
    })
    display_name: string | null = null;

    @attribute({
        label: t`Rank`,
        validation: yup.number().min(0).max(999)
    })
    rank: number = 0

    @attribute({
        label: t`Timer`,
        validation: yup.number()
    })
    force_duration: number = 0;

    @attribute({
        label: t`is_control_process`,
        validation: yup.boolean()
    })
    is_control_process: boolean = false;

    @attribute({
        label: t`Capabilities`,
        validation: yup.array().nullable()
    })
    capability_ids: number[] = [];

    @attribute({
        label: t`Condition`,
    })
    condition: any = null;

    @attribute({
        label: t`INF Target Tag`,
        validation: yup.string().nullable()
    })
    inf_target_tag: string | null = null;

    @attribute({
        label: t`Do Not Reject This Process In Started`,
        validation: yup.boolean()
    })
    do_not_reject_started: boolean = false;

    @attribute({
        label: t`Resolve Capabilities`,
        validation: yup.string()
    })
    capability_resolve_mode: 'require_all' | 'highest_rank' = 'require_all';

    @computed
    get requireCapabilityRank(): boolean {
        return this.viewModel.capability_resolve_mode === 'highest_rank';
    }

    @computed
    get resolvedName() {
        if(this.display_name){
            return this.display_name;
        }
        return this.name;
    }

    constructor() {
        super();
        super.setup();
    }
}

export const JobProcessStore = JobProcessModel.store as DataStore<JobProcessModel>;
