import {attribute, DataStore, Model, model} from '@rx-suite/data';
import * as yup from 'yup';
import { t } from "@lingui/macro"
import {CapabilitiesModel} from "./CapabilityStore";
import {CapabilityMachineModel} from "./CapabilityMachineStore";
import {action} from "mobx";
import {JobProcessModel} from "./JobProcessStore";

@model({
    transportLayer: '/api/machines',
    permissionTarget: "Machine",
    routingInfo: {
        create: '/machines/create',
        update: '/machines/:id/edit'
    }
})

export class MachineModel extends Model {
    @attribute({
        label: t`Id`,
        validation: yup.number()
    })
    id: number = 0;

    @attribute({
        label: t`Machine Name`,
        validation: yup.string().required("Field name is required")
    })
    name: string = "";

    @attribute({
        label: t`Force duration`,
        validation: yup.number().nullable()
    })
    force_duration: number = 0;

    @attribute({
        label: t`Process`,
        validation: yup.number().nullable()
    })
    job_process_id: number = 0;

    @attribute({
        label: t`Process`
    })
    job_process: JobProcessModel | null = null;

    @attribute({
        label: t`Capabilities`,
        validation: yup.array()
    })
    capabilities: CapabilitiesModel[] = []

    @attribute({
        label: t`Capabilities`,
        validation: yup.array()
    })
    capability_ids: number[] = []

    @attribute({
        label: t`Component`,
        validation: yup.number()
    })
    component_id: number = 0;

    //OPCUA

     @attribute({
        label: t`State`,
        validation: yup.string()
    })
    state: string = '';

    //MES

    @attribute({
        label: t`Forced state`,
        validation: yup.string().nullable()
    })
    forced_state: string = '';

    @attribute({
        label: t`Update machine group?`,
        validation: yup.boolean()
    })
    update_machine_group: boolean = false;

    @attribute({
        label: t`Serial Number`,
        validation: yup.string().nullable()
    })
    sn: string = '';

    @attribute({
        label: t`Current state`,
        validation: yup.string().nullable()
    })
    last_reported_state: string = '';

    @attribute({
        label: t`Mes machine state ids`,
        validation: yup.array()
    })
    mes_machine_state_ids: object = [];

    @attribute({
        label: t`Ignore state?`,
        validation: yup.boolean().nullable()
    })
    ignore_state: boolean = false;

    @attribute({
        label: t`Virtual`,
        validation: yup.boolean().nullable()
    })
    virtual: boolean = false;

    @attribute({
        label: t`Send Aborted Jobs To`,
        validation: yup.string().nullable()
    })
    selected_reject: string = '';

    @attribute({
        label: t`Apply process change when?`,
        validation: yup.string().nullable()
    })
    apply_process_change_on : string = '';

    @attribute({
        label: t`Machine Capabilities`,
        validation: yup.array().nullable()
    })
    capability_machines : CapabilityMachineModel[] = [];

    @attribute({
        label: t`Allow Job Start?`,
        validation: yup.boolean()
    })
    allow_job_start: boolean = false;

    @attribute({
        label: t`Restart Job?`,
        validation: yup.boolean()
    })
    restart_jobs: boolean = false;

    @attribute({
        label: t`INF Lms Config`,
        validation: yup.number().nullable()
    })
    lms_config_id: number | null = 0;

    @action
    has_capability(capabilityId: number) {
        return this.capability_machines.some((capability_machine) => capability_machine.capability_id === capabilityId && capability_machine.enabled);
    }

    constructor() {
        super();
        super.setup();
    }
}

export const MachineStore = MachineModel.store as DataStore<MachineModel>;
