class JobSetRejectJob < ApplicationJob
  queue_as :router_job_processes

  def perform(data)
    timestamp = data[:timestamp]
    job = Job.job_message_target(data)
    reject_data = Job.extract_job_reject_data(data)

    unless job.nil? || !job.latest_reject?(timestamp)
      # When a job is rejected/un-rejected by the router, clear its INF target
      job.remove_from_inf_queue

      if reject_data.nil?
        job.un_reject(false, timestamp: timestamp)
      else
        job.set_reject({key: reject_data[:reason], description: reject_data[:description]}, timestamp: timestamp)
      end
      WorkerBroadcast.broadcast_model(job, WorkerBroadcast.action[:update])
    end
  end
end