class JobUpdateProcessJob < ApplicationJob
  queue_as :router_job_processes

  def perform(data)
    @job = Job.job_message_target(data)
    processes = data['processes']

    return if @job.nil? || processes.nil?

    processes.each do |process_data|
      apply_process(process_data)
    end
  end

  def apply_process(process_data)
    job_process = JobProcess.find_by_name(process_data[:process])

    return if job_process.nil?

    component = if process_data[:machine].nil?
                  nil
                else
                  Component.find_by_name(process_data[:machine])
                end

    process_data[:lensData].each do |lens_data|
      data = extract_lens_data(lens_data, component)

      required_process = @job.required_processes.where(job_process_id: job_process.id, side: data[:side]).first

      next if required_process.nil?

      # Only create a job history entry if none will be coming from rx-data (auto-finish or VM)
      unless component.nil?
        unless component.machine.is_sending_job_states?
          required_process.required_process_state_histories.build(state: data[:state], source: data[:source_name], job_state_timestamp: Time.at(data[:last_state_change_timestamp]))
        end
      end

      # Note: This does not leverage RequiredProcess#set_state due to the router_server already handling all validation (assume data is good)
      if required_process.update_with_external(data[:state], data[:last_state_change_timestamp], data[:last_comment], process_data[:machine], true, data[:is_rework])
        # TODO: see how we could leverage a single broadcast for all process changes?
        WorkerBroadcast.broadcast_model(required_process, WorkerBroadcast.action[:update])
      end
    end
  end

  def extract_lens_data(lens_data, component)
    source_name = if component.nil?
                    "(AUTO)"
                  else
                    if lens_data['isFromAuto'] || !component.machine.is_sending_job_states?
                      "#{component.name} (AUTO)"
                    else
                      "#{component.name}"
                    end
                  end

    {
      side: lens_data['side'],
      state: lens_data['state'],
      last_state_change_timestamp: lens_data['lastStateChangeTimestamp'],
      last_comment: lens_data['lastComment'],
      source_name: source_name,
      is_rework: lens_data['isRework']
    }
  end
end
