class JobRequest
  def self.data_for_job_number(job_number, request_type, stashed_processes = [])
    Rails::logger.info "Requesting data for job #{job_number} (request type #{request_type})"

    if request_job_as_new?(job_number, request_type)
      return request_new(job_number, stashed_processes)
    else
      return request_existing(job_number)
    end
  end

  def self.complete_job_fetch(job)
    job.update(is_routing: true)
    job
  end

  def self.request_new(job_number, stashed_processes = [])
    job = Job.create_new(job_number)
    job.stashed_process_changes << stashed_processes if stashed_processes.length
    begin
      process_request = ProcessFetcher.fetch_for_job_number(job_number, Setting.first.post_job_data?)

      if Setting.rx_data_tag_source? && !process_request.job_active
        handle_reject_job(job, "Job is inactive in Rx-Data.")
      else
        job.rx_data_job_id = process_request.rx_data_id
        job.job_numbers = process_request&.lens_numbers_json
        job.set_required_processes(process_request.processes)
        job.apply_stashed_processes
        job.save!
      end
    rescue ProcessRequest::JobDoesNotExist
      handle_reject_job(job, "Job does not exist in the data source (#{Setting.rx_data_tag_source? ? 'Rx-Data' : 'LMS' }).");
    rescue
      handle_reject_job(job)
    end
    complete_job_fetch(job)
    job
  end

  def self.request_existing(job_number)
    job = Job.find_by_number(job_number)

    # If the job is going to be a reject, complete the request here
    if job.nil?
      job = Job.create_new(job_number)
      job.set_reject(Job.reject_data[:noProcessesAtNonStart])
      complete_job_fetch(job)
      return job
    end

    job.verify_before_send_to_router
    if Setting.use_rx_data_jobs?
      # If we have to synchronize using Rx-Data, let the delayed job handle the return to the router
      job.synchronize_external_data
    end

    # If there's no additional synchronization to do, send the job data now.
    complete_job_fetch(job)
    job
  end

  def self.request_job_as_new?(job_number, request_type)
    return true if request_type == 'new'
    return false if request_type == 'existing'

    # If the request type is 'new_or_existing', request the job has new only if it doesn't exist
    job = Job.find_by_number(job_number)
    job.nil?
  end

  def self.handle_reject_job(job, force_description=nil)
    if ProcessFetcher.use_default_on_fail
      ProcessFetcher.use_default_data_for_job(job)
    else
      unless job.is_rejected?
        job.set_reject(Job.reject_data[:failFetchProcesses], force_description)
      end
    end
  end
end
