module ProcessRequests
  class Inf < ProcessRequests::Lms
    def initialize(job_number, lms_config)
      @lms_config = lms_config
      # Never post INF tags to rx-data
      super(job_number, false)
    end

    def get_lms
      [@lms_config]
    end

    def get_max_fetch_attempts
      retries = Setting.first.inf_max_attempts
      return 3 unless retries
      retries
    end

    def extract_tags(tag_values, d)
      tag_name = d[0]
      if tag_values.has_key?(tag_name)
        if tag_values[tag_name].class != Array
          tag_values[tag_name] = [tag_values[tag_name]]
        end
        tag_values[tag_name].push(d[1])
      else
        tag_values[tag_name] = d[1]
      end
    end

    def get_inf_processes
      process_data = {}
      return {} if @tag_raw_data["JOBRTE"].nil?

      # If there's only one JOBRTE tag, make it into an array
      @tag_raw_data["JOBRTE"] = [@tag_raw_data["JOBRTE"]] if @tag_raw_data["JOBRTE"].is_a? String

      @tag_raw_data["JOBRTE"].each do |raw_data|
        split_data = raw_data.split(';')
        process = split_data[1]
        side = split_data[0]

        if side == 'B'
          %w[R L].each do |s|
            process_data[process] ||= {}
            process_data[process][s] ||= {}
            process_data[process][s]["machine"] = split_data[5]
            process_data[process][s]["timestamp"] = split_data[6]
          end
        else
          process_data[process] ||= {}
          process_data[process][side] ||= {}
          process_data[process][side]["machine"] = split_data[5]
          process_data[process][side]["timestamp"] = split_data[6]
        end
      end
      process_data
    end

    def inf_process_data
      @inf_process_data
    end

    def fetch
      @tag_raw_data = get_tags

      ensure_response_is_valid

      @inf_process_data = get_inf_processes
      @tags = split_tags_for_lenside
    end

    def set_tags_for_request(lms)
      lms[:client].set_tags(["JOBRTE"])
    end
  end
end