module ProcessRequests
  class Lms < ProcessRequest
    class DcsConnectionNotConfigured < StandardError; end

    attr_accessor :source

    def initialize(job_number, post_to_data=false)
      super(job_number)
      @source = nil
      fetch

      if post_to_data
        job_data = Job.post_to_rx_data(@job_number, @tags, @processes)
        @rx_data_id = job_data[:job_id]
      end
    end

    def fetch
      Rails::logger.info "Starting LMS tag request for job #{job_number}."

      get_data

      @lens_numbers = lens_numbers_from_tag_data

      @processes = JobProcessCalculator.instance.get_required_processes_from_tags(@tags, required_sides)

      raise NoProcesses unless @processes.length > 0
    end

    private

    def get_data
      lms_configs = LmsConfig.find_lms_configs_for_job_number(@job_number)

      tags_to_fetch = Tag.all.map(&:tag)

      lms_configs.each_with_index do |lms_config, index|
        raise DcsConnectionNotConfigured if lms_config.external_dcs_id.nil?

        resp = RxModule::Communicator.call_module_method_as_module("rx_link", "#{lms_config.external_url}/job_call", :post, {
          job_call: {
            job: @job_number,
            tags: tags_to_fetch
          }
        })

        if resp[:error]
          if index == (lms_configs.length-1) # Is last config, error out
            raise JobDoesNotExist if resp[:error][:jobDoesNotExist]
            raise TimeoutWhileFetchingFromSource if resp[:error][:timeout]
            raise FailedToFetchFromSource
          end
        else
          @source = resp[:source]
          @tags = resp[:tags]
          break # Job found, end here
        end
      end
    end

    def lens_numbers_from_tag_data
      job_numbers = []
      job_numbers << {jobNumber: @job_number, lens: 'right'}.stringify_keys if do_right?
      job_numbers << {jobNumber: @job_number, lens: 'left'}.stringify_keys if do_left?
      job_numbers
    end
  end
end
