class Device < ApplicationRecord
  belongs_to :component, dependent: :destroy, required: true
  has_many :extra_requirements

  validates_associated :component, message: "'s name is already taken"

  def device_state
    if component.connectors.where.not(connector_type: "other").any? {|connector| connector.state == 'online'}
      'online'
    elsif component.connectors.where.not(connector_type: "other").any? {|connector| connector.state == 'standby'}
      'standby'
    else
      'offline'
    end
  end

  def scanner_count
    component.connectors.where.not(rx_scanner_reference: nil).or(component.connectors.where.not(opcua_scanner_reference: nil)).count
  end

  def update_client_payload
    {
        device: self.component.name,
        delayOnCommandComplete: self.delay_on_command_complete,
        routingRetryDelay: self.routing_retry_delay
    }
  end

  after_create do |model|
    ActionCable.server.broadcast "everything", {
        model: JSON.parse(render_jbuilder_partial),
        class: Device.name,
        action: :create
    }
  end

  after_update do |model|
    ActionCable.server.broadcast "everything", {
        model: JSON.parse(render_jbuilder_partial),
        class: Device.name,
        action: :update
    }
  end

  after_destroy do |model|
    ActionCable.server.broadcast "everything", {
        model: JSON.parse(render_jbuilder_partial),
        class: Device.name,
        action: :destroy
    }
  end

  def should_broadcast?
    false
  end
end
