class DeviceType < ApplicationRecord
  has_many :device_routing_commands
  has_many :opcua_connectors, through: :device_routing_commands
  has_many :opcua_devices
  has_many :device_timers

  def get_json
    {
      deviceType: self[:name],
      connectors: self.get_unique_opcua_connectors.map do |connector|
        {
            name: connector[:name],
            variable: connector[:variable],
            type: connector[:connector_type]
        }
      end,
      routingCommands: self.device_routing_commands.map do |command|
        connector_commands = command.connector_commands.sort_by { |connector_command| connector_command[:rank] }
        {
          command: command[:command],
          param: command[:parameter],
          path: connector_commands.map do |connector_command|
            connector_command.opcua_connector[:name]
          end
        }
      end,
      rootNodeId: self[:root_node_id]
    }
  end

  def get_unique_opcua_connectors
    self.opcua_connectors.uniq
  end

  after_update do |model|
    ActionCable.server.broadcast "everything", {
        model: JSON.parse(render_jbuilder_partial),
        class: model.class.name,
        action: :update
    }
  end

  def should_broadcast?
    false
  end
end