class ExtraRequirement < ApplicationRecord
  belongs_to :device_routing_command
  belongs_to :device

  def device_routing_command_name
    self.device_routing_command[:command] + ' ' + self.device_routing_command[:parameter]
  end

  def node_name
    Device.find(self[:node_id]).component[:name]
  end

  def connector_name
    Connector.find(self[:connector_id])[:name]
  end

  def job_process_name
    if self[:job_process_id].nil?
      nil
    else
      JobProcess.find(self[:job_process_id])[:name]
    end
  end

  after_create do |model|
    ActionCable.server.broadcast "everything", {
        model: JSON.parse(render_jbuilder_partial),
        class: model.class.name,
        action: :create
    }
  end

  after_update do |model|
    ActionCable.server.broadcast "everything", {
      model: JSON.parse(render_jbuilder_partial),
      class: model.class.name,
      action: :update
    }
  end

  after_destroy do |model|
    ActionCable.server.broadcast "everything", {
        model: JSON.parse(render_jbuilder_partial),
        class: model.class.name,
        action: :destroy
    }
  end

  def should_broadcast?
    false
  end
end
