class JobProcess < ApplicationRecord
  has_many :machines
  has_many :capabilities, dependent: :destroy
  has_many :required_processes, dependent: :destroy
  has_one :tag_condition

  enum capability_resolve_mode: [:require_all, :highest_rank]

  class << self
    def seed
      JobProcess.new(name: 'start', rank: 0, is_control_process: true).save if JobProcess.find_by_name('start').nil?

      if JobProcess.find_by_name('processed').nil?
        processed_process = JobProcess.new(name: 'processed', rank: 999, is_control_process: true )
        processed_process.capabilities << Capability.new(name: 'accepted')
        processed_process.capabilities << Capability.new(name: 'rejected')
        processed_process.save
      end
    end
  end

  def has_condition?
    return false if self.tag_condition.nil?
    true
  end

  def is_control_process?
    self.is_control_process
  end

  def get_json
    {
      name: name,
      rank: rank,
      doNotRejectInStarted: do_not_reject_started
    }
  end

  after_create do |model|
    ActionCable.server.broadcast "everything", {
        model: JSON.parse(render_jbuilder_partial),
        class: model.class.name,
        action: :create
    }
  end

  after_update do |model|
    ActionCable.server.broadcast "everything", {
        model: JSON.parse(render_jbuilder_partial),
        class: model.class.name,
        action: :update
    }
  end

  after_destroy do |model|
    ActionCable.server.broadcast "everything", {
        model: JSON.parse(render_jbuilder_partial),
        class: model.class.name,
        action: :destroy
    }
  end

  def should_broadcast?
    false
  end
end
