class JobRouterControl < ApplicationRecord
  class << self
    def instance
      JobRouterControl.first_or_create!
    end

    def vitals_online?
      router_info = instance

      LmsConfig.ping_all_job_lms if Setting.lms_tag_source?

      lms_ok = if Setting.lms_tag_source?
                 LmsConfig.all_job_lms_online?
               else
                 true
               end

      rx_data_ok = if Setting.use_rx_data?
                     router_info.rx_data_online = ping_module('rx_data')
                   else
                     true
                   end

      rx_scanners_ok = if Setting.use_rx_scanners?
                         router_info.rx_scanners_online = ping_module('rx_scanners')
                       else
                         true
                       end

      # For some reason, the timestamp doesn't get updated if no other field change
      router_info.updated_at = Time.now
      router_info.save

      lms_ok & rx_data_ok & rx_scanners_ok
    end

    private

    def ping_module(module_name)
      RxModule::Communicator.call_module_method(module_name, '/api/rx_module/info', :get,nil,nil, ping_connection)
      true
    rescue => err
      Rails::logger.warn "Failed to ping module #{module_name} - err: #{err}"
      false
    end

    def ping_connection
      client = Faraday.new
      client.options.timeout = 5
      client
    end
  end

  def self.seed
    JobRouterControl.create if JobRouterControl.count == 0
  end
end
