class MesMachine < Machine
  has_many :mes_machine_states, dependent: :destroy

  def get_json
    {
        identifier: self.component[:name],
        isMESMachine: self.sn.nil? ? false : true,
        serialNumber: self.sn,
        processingDuration: self.force_duration,
        initialState: self.last_reported_state,
        forcedState: self.sn ? self.forced_state : self.machine_state,
        applyProcessChangeOn: self.apply_process_change_on,
        onlineStates: self.mes_machine_states.where(online: true).map do |state|
          state[:name]
        end,
        sendRejectsTo: self.selected_reject ? Machine.find(self.selected_reject).component[:name] : nil,
        process: self.job_process ? {
          name: self.job_process.name,
          capabilities: self.capability_machines.where(enabled: true).map {|capability_machine| capability_machine.capability.name}
        } : nil,
        connectors: self.component.connectors.map do |connector|
          {
              name: connector[:name],
              state: connector[:state],
              type: connector[:connector_type]
          }
        end,
        infEnabled: inf_enabled?
    }
  end

  def self.update_machine_states
    begin
      resp = RxModule::Communicator.call_module_method('rx_data', '/connector/satisloh/reportqueries/resources/status/1.0/last', :get)[:resourceStatusLastList]
      MesMachine.transaction do
        resp.each do |state|
          machine = MesMachine.find_by_sn(state[:sn])
          if machine.nil?
            next
          end
          machine[:last_reported_state] = state[:state].nil? ? 'WAITINGFORJOBS' : state[:state]
          machine.save
        end
      end
    rescue => err
      puts err
      false
    end
  end

  def controller_name
    "MachinesController"
  end

  def on_machine_state_update
    ActionCable.server.broadcast "everything", {
        model: JSON.parse(render_jbuilder_partial),
        class: Machine.name,
        action: :update
    }
  end

  after_create do |model|
    ActionCable.server.broadcast "everything", {
        model: JSON.parse(render_jbuilder_partial),
        class: Machine.name,
        action: :create
    }
  end

  after_update do |model|
    ActionCable.server.broadcast "everything", {
        model: JSON.parse(render_jbuilder_partial),
        class: Machine.name,
        action: :update
    }
  end

  after_destroy do |model|
    ActionCable.server.broadcast "everything", {
        model: JSON.parse(render_jbuilder_partial),
        class: Machine.name,
        action: :destroy
    }
  end

  def should_broadcast?
    false
  end
end

