class OpcuaDevice < Device
  belongs_to :device_type, optional: true
  has_many :device_routing_command_devices, :dependent => :destroy
  has_many :device_routing_commands, :through => :device_routing_command_devices

  def controller_name
    "DevicesController"
  end

  def get_json
    {
      identifier: component.name,
      emulateJobStateSettings: send_job_state_as.nil? ? nil : {
        sendAs: send_job_state_as,
        process: job_state_process,
      },
      type: device_type.name,
      routingRetryDelay: routing_retry_delay,
      delayOnCommandComplete: delay_on_command_complete,
      connectors: connectors_json,
      opcuaConstants: timers_json,
      routingCommands: routing_commands_json,
      routingCommandsExtraRequirements: extra_routing_req_json
    }
  end

  private

  def connectors_json
    self.component.connectors.all.map do |connector|
      connector.as_opcua_json
    end
  end

  def timers_json
    self.component.device_timers.map do |timer|
      {
        variable: timer[:variable],
        value: timer[:time]
      }
    end
  end

  def routing_commands_json
    device_routing_command_devices.map do |drcd|
      device_routing_command = drcd.device_routing_command
      connector_commands = device_routing_command.connector_commands.sort_by { |connector_command| connector_command[:rank] }
      {
        command: device_routing_command.command,
        param: device_routing_command.parameter,
        enabled: drcd.enabled,
        path: connector_commands.map do |connector_command|
          connector_command.opcua_connector[:name]
        end
      }
    end
  end

  def extra_routing_req_json
    requirements_hash = {}
    self.extra_requirements.each do |extra_requirement|
      key = extra_requirement.device_routing_command[:command] + '/' + extra_requirement.device_routing_command[:parameter]
      unless requirements_hash.has_key? key
        requirements_hash[key] = {
          command: {
            command: extra_requirement.device_routing_command[:command],
            param: extra_requirement.device_routing_command[:parameter],
          },
          requirements: []
        }
      end
      device = Device.find(extra_requirement[:node_id])
      connector = Connector.find(extra_requirement[:connector_id])
      hash = {type: 'connector', data: {node: device.component[:name], connector: connector[:name]}}
      unless extra_requirement[:job_process_id].nil?
        job_process = JobProcess.find(extra_requirement[:job_process_id])
        hash[:applyIfJobNextProcessIs] = job_process[:name]
      end
      requirements_hash[key][:requirements].push(hash)
    end
    requirements_hash.map do |k, requirement_hash|
      requirement_hash
    end
  end
end