module OpcuaDeviceDefinitions
  class OpcuaDeviceDefinition
    class << self
      def instantiate
        return puts "Device #{name} already seeded - skipping definition." unless DeviceType.find_by_name(name).nil?

        puts "Seeding device type #{name}"

        device = DeviceType.new(name: name, opcua_type: OpcuaDeviceDefinitions::Modular::ModularDevice.type, all_in_one: all_in_one, routing_retry_delay: routing_retry_delay, delay_on_command_complete: delay_command_complete)

        constants.each do |k, v|
          device.device_timers.new(variable: k, time: v)
        end

        connector_instances = {}
        connectors.each do |k, v|
          connector_instances[k] = OpcuaConnector.new(name: k, variable: v[:variable], connector_type: v[:type], priority: v[:priority], action_delay: v[:action_delay])
        end

        commands.each do |c|
          command = device.device_routing_commands.new(command: c[:command], parameter: c[:parameter])
          c[:path].each_with_index do |n, i|
            con_com = command.connector_commands.new(rank: i)
            con_com.opcua_connector = connector_instances[n]
          end
        end

        device.save!
      end

      def type
        raise NotImplementedError
      end

      def name
        raise NotImplementedError
      end

      def all_in_one
        false
      end

      def delay_command_complete
        500
      end

      def routing_retry_delay
        4
      end

      def constants
        raise NotImplementedError
      end

      def constants_default_value
        250
      end

      def connectors
        raise NotImplementedError
      end

      def commands
        raise NotImplementedError
      end
    end
  end
end
