class RoutingGraph < ApplicationRecord

  class << self
    def seed
      RoutingGraph.create if RoutingGraph.count == 0
    end
  end

  def remove_node(node_id)
    data, diagram_nodes, diagram_links = get_graph_info
    Rails::logger.info "Attempting the remove node #{node_id} from the graph"
    node_key = nil
    diagram_nodes['models'].reject! { |key, node|
      if node['id'] == node_id
        node_key = key
      end
      node['id'] == node_id
    }
    unless node_key.nil?
      diagram_links['models'].reject! {|key, link| link['target'] == node_key || link['source'] == node_key}
    end
    self.serialized_data=data.to_json
    self.save
  end

  def clean_graph
    if self.serialized_data.nil?
      return
    end
    data, diagram_nodes, diagram_links = get_graph_info
    node_keys = []
    diagram_nodes['models'].reject! do |key,node|
      rejected = false
      component = Component.find_by(id: node['id'])
      unless component
        node_keys.push(node['id'])
        rejected = true
      end
      if rejected == false
        inputs = component.connectors.where(connector_type: 'input')
        outputs = component.connectors.where(connector_type: 'output')
        con_length = inputs.length + outputs.length
        unless con_length == node['ports'].length
          node_keys.push(node['id'])
          rejected = true
        end
      end
      if rejected == false
        node['ports'].each do |port|
          unless component.connectors.find_by(name: port['name'])
            node_keys.push(node['id'])
            rejected = true
          end
        end
      end
      #Used to change color of nodes in graph when creating line
      if rejected == false
        if component.machine
          node["color"] = "rgb(20,110,180)"
        elsif component.device
          node["color"] = "rgb(255,153,0)"
        end
      end
      rejected == true
    end
    node_keys.each do |node_key|
      diagram_links['models'].reject! {|key, link| link['target'] == node_key || link['source'] == node_key}
    end
    self.serialized_data=data.to_json
    self.save
  end

  def set_node_colors
    data, diagram_nodes, diagram_links = get_graph_info
    diagram_nodes['models'].each do |key,node|
      component = Component.find_by(id: node['id'])
      if component.nil?
        next
      end
      if component.machine
        node["color"] = "rgb(20,110,180)"
      elsif component.device
        node["color"] = "rgb(255,153,0)"
      end
    end
    self.serialized_data=data.to_json
    self.save
  end

  def get_json
    data, diagram_nodes, diagram_links = get_graph_info
    model_hash = {}
    diagram_nodes['models'].each do |key, node|
      all_in_one_flag = false
      component = Component.find_by(id: node['id'])
      if !component.device.nil? && Setting.first[:connection_type] == 'OPCUA'
        if component.device.device_type[:all_in_one]
          all_in_one_flag = true
        end
      end
      ports = {}
      if all_in_one_flag
        port_in = node['ports'][0]
        ports[port_in['id']] = component.connectors.find_by(name: port_in['name'])
        port_out = node['ports'][1]
        ports[port_out['id']] = ports[port_in['id']]
      else
        node['ports'].each do |port|
          ports[port['id']] = component.connectors.find_by(name: port['name'])
        end
      end
      model_hash[node['id']] = {
          component: component,
          ports: ports
      }
    end
    routes = []
    diagram_links['models'].each do |key, link|
      source_model = model_hash[link['source']]
      source_component = source_model[:component]
      source_port = source_model[:ports][link['sourcePort']]
      target_model = model_hash[link['target']]
      target_component = target_model[:component]
      target_port = target_model[:ports][link['targetPort']]
      if target_port[:connector_type] == 'output' && source_port[:connector_type] == 'input'
        source_component, target_component = target_component, source_component
        source_port, target_port = target_port, source_port
      end
      route = {
          source: {
              node: source_component[:name],
              connector: source_port[:name]
          },
          target: {
              node: target_component[:name],
              connector: target_port[:name]
          }
      }
      routes.push(route)
    end
    routes
  end

  def name_to_id
    data, diagram_nodes, diagram_links = get_graph_info
    conversion_hash = {}
    diagram_nodes['models'].each do |key,node|
      component = Component.find_by(name: node['name'])
      if component.nil?
        next
      end
      node.delete('name')
      conversion_hash[node['id']] = component.id
      node['id'] = component.id
    end
    diagram_links['models'].each do |key, link|
      if conversion_hash.has_key? link['source']
        link['source'] = conversion_hash[link['source']]
      end
      if conversion_hash.has_key? link['target']
        link['target'] = conversion_hash[link['target']]
      end
    end
    self.serialized_data=data.to_json
    self.save
  end

  def routing_machines
    data, diagram_nodes, diagram_links = get_graph_info
    routing_machines = []
    diagram_nodes['models'].each do |key, node|
      component = Component.find_by(id: node['id'])
      if component.machine.nil?
        next
      else
        routing_machines.push(component.machine)
      end
    end
    routing_machines
  end

  def processes_offered
    machines = routing_machines
    machines.map do |machine|
      if machine.job_process
        machine.job_process
      end
    end.uniq
  end

  def process_ids_offered
    processes_offered.map {|p| p.id}
  end

  def should_broadcast?
    false
  end


  private

  def get_graph_info
    data = JSON.parse(self.serialized_data.gsub('=>', ':'))
    diagram_nodes = data['layers'].detect {|layer| layer['type'] === 'diagram-nodes'}
    diagram_links = data['layers'].detect {|layer| layer['type'] === 'diagram-links'}
    return data, diagram_nodes, diagram_links
  end
end