class WorkerFrontEndBroadcast < ApplicationRecord
  # Some models are updated in a worker process and require to broadcast a change to an
  # in memory resource of the main application (ex: send a message to the router client).
  # This acts as an update queue that the main thread will process.

  def broadcast
    model_global_id = nil
    begin
      model_global_id = self.model_global_id.to_s
      model = GlobalID::Locator.locate_signed(model_global_id)

      if model.nil?
        Rails::logger.warn "Unable to broadcast #{self.action} to router server. Model with global id #{model_global_id} not found."
      else
        WorkerFrontEndBroadcast.broadcast_to_ui(model, action.to_sym)
      end
    rescue => err
      Rails::logger.warn "Unable to broadcast model #{model_global_id} - #{self.action} to router server. Error: #{err}"
    end
    self.destroy!
  end

  def should_broadcast?
    false
  end

  private

  def self.broadcast_to_ui(model, action)
    ActionCable.server.broadcast "everything", {
        model: JSON.parse(model.render_jbuilder_partial),
        class: model.class.name,
        action: action
    }
  end
end
