class LmsJobInfRequestQueue < RxModule::Routine
  class << self
    def frequency
      '2s'
    end

    def work
      InfRequest.where(InfRequest.arel_table[:retry_at].lt(Time.now).or(InfRequest.arel_table[:retry_at].eq(nil))).find_each do |request|
        request.update(attempt: request.attempt + 1)

        completed = request.attempt_inf

        # Only send the INF information if the INF request completed
        if completed
          request.complete
        else
          attempt_retry(request)
        end
      end
    end

    def attempt_retry(request)
      unless request.can_retry?
        return request.complete
      end

      request.retry_at = Time.now + Setting.first.inf_time_between_attempts.seconds
      request.save

      Rails::logger.info "[INF Request - Job #{request.job.number}] No Data Available. Retrying at #{request.retry_at}."
    end
  end
end
