Rails.application.routes.draw do
  scope :api do
    resources :devices do
      post "/update_state" => "devices#update_state"
      get "/force_reset" => "devices#force_reset"
    end
    resources :device_types
    resources :device_routing_commands
    resources :extra_requirements
    resources :machines do
      collection do
        get "reject_stations"
        post "change_from_external"
        post "state_from_external"
        post :capability_update
      end
      post "/update_state" => "machines#update_state"
    end
    resources :mes_machine_states
    resources :capability_machines, only: [:index, :show] do
      member do
        put "toggle"
      end
    end
    resources :device_routing_command_devices, only: [:index, :show] do
      member do
        put "toggle"
      end
    end
    resources :job_processes
    resources :capabilities
    resources :routing_graphs
    resources :connectors
    resources :connectors do
      post "/update_state" => "connectors#update_state"
      post "/control_action" => "connectors#control_action"
    end
    resources :components
    resources :scanners
    resources :device_timers
    resources :tags
    resources :tag_conditions
    resources :jobs do
      member do
        post "/update_required_processes" => "jobs#update_required_processes"
        post "/finish" => "jobs#finish"
        post "/reset" => "jobs#reset"
        post :job_history
      end
      collection do
        get :scan, to: "customer_endpoints#lmacrodlp_scan"
        get "search/:job_number" => "jobs#search"
      end
      get "/fetch_job_status" => "jobs#fetch_job_status"
      post "/reject" => "jobs#reject"
      patch "revive" => "jobs#revive"

    end
    resources :required_processes do
      member do
        post "/complete" => "required_processes#complete"
        post "/reset" => "required_processes#reset"
        post "/complete_both" => "required_processes#complete_both"
        post "/reset_down_to" => "required_processes#reset_down_to"
        post "/finish_up_to" => "required_processes#finish_up_to"
        post :rework_up_to
      end
    end
    resources :required_process_state_histories, only: [:show, :index]
    resources :settings
    resources :lms_configs do
      member do
        post "/reinitialize" => "lms_configs#reinitialize"
      end
    end
    resources :errors
    resources :job_router_controls, only: [:show, :index] do
      collection do
        put "start"
        put "stop"
      end
    end
    resources :delayed_jobs_queue

    get "/connect" => "job_router_controls#connect"

    get "/fetched_jobs/search/:id" => "fetched_jobs#search"
    get "/active_record_connection_pools" => "settings#active_record_connection_pools"

    #post "machines/create_or_delete_from_external" => "machines#create_or_delete_from_external"
    post "jobs/rx_data_update" => "jobs#rx_data_update"
    post "jobs/job_create_rx_data_update" => "jobs#job_create_rx_data_update"
  end

  scope :router, defaults: {format: :json} do
    get "status" => "router_server#status"
    put "state" => "router_server#state"
    post "event" => "router_server#event"

    scope :startup do
      get "base_settings" => "router_server#base_settings"
      get "plc_settings" => "router_server#plc_settings"
      get "device_definitions" => "router_server#device_definitions"
      get "devices" => "router_server#devices"
      get "machines" => "router_server#machines"
      get "processes" => "router_server#processes"
      get "scanner_settings" => "router_server#scanner_settings"
      get "routes" => "router_server#routes"
      get "default_job_processes" => "router_server#default_job_processes"
    end

    resources :jobs, only: [] do
      # Note: these methods are not member methods as it is called by the router which does not have the job id
      collection do
        post :fetch
        put :set_inf
        put :execute_inf
        put :update_process
        put :update_location
        put :update_reject
        put :complete
        put :schedule_process_state_change
        post :post_job_states_to_rx_data
      end
    end
  end

  mount RxModule::Engine => "/api/rx_module"
  root '/', controller: :index, action: :show, as: :index_show
  match '*path' => 'index#show', via: :all
end
