class InvalidPLCControl < StandardError; end
class InvalidOPCUAVariant < StandardError; end
class InvalidRouterLevel < StandardError; end

# Validate PLC control settings
plc_control = ENV['PLC_CONTROL']
raise InvalidPLCControl if plc_control.nil?
plc_control = plc_control.upcase
raise InvalidPLCControl unless ["MES", "OPCUA"].include? plc_control

is_opcua_plc = ENV['PLC_CONTROL'] == "OPCUA"

# Validate OPC UA settings
opcua_variant = ENV['OPCUA_VARIANT']
if is_opcua_plc
  raise InvalidOPCUAVariant if opcua_variant.nil?
  opcua_variant = opcua_variant.downcase
  raise InvalidOPCUAVariant unless ["ncc", "modular"].include? opcua_variant
end

# Validate Routing Level
router_level = ENV['RX_ROUTER_LEVEL']
raise InvalidRouterLevel if router_level.nil?
router_level = router_level.downcase
raise InvalidRouterLevel unless  ["basic", "easy", "mes"].include? router_level

Setting.seed(router_level, plc_control, opcua_variant)
JobRouterControl.seed
RoutingGraph.seed
JobProcess.seed
Tag.seed

if is_opcua_plc
  if opcua_variant == "ncc"
    OpcuaDeviceDefinitions::Ncc::NccDevice.instantiate_all
  elsif opcua_variant == "modular"
    OpcuaDeviceDefinitions::Modular::ModularDevice.instantiate_all
  else
    raise InvalidOPCUAVariant
  end
end

LmsConfig.migrate_legacy_connections
