class ProcessFetcher
  class ProcessFetcherDisabled < StandardError; end

  def self.use_default_on_fail
    use_default = Setting.first.use_default_processes_on_fail_fetch
    return false if use_default.nil?
    use_default
  end

  # Make a synchronous request for a job's process data.
  # Note: This method only fetches the data, it's the responsibility of the caller to do something with the data
  def self.fetch_for_job_number(job_number, post_job_data = false)
    if Setting.rx_data_tag_source?
      return ProcessRequests::RxData.new(job_number)
    elsif Setting.lms_tag_source?
      return ProcessRequests::Lms.new(job_number, post_job_data)
    else
      raise ProcessFetcherDisabled
    end
  end

  def self.use_default_data_for_job(job)
    processes = JobProcessCalculator.instance.default_processes
    job.set_required_processes(processes)
    job.save!
  end

  def self.default_processes_json
    processes = JobProcessCalculator.instance.default_processes
    process_hash = {}
    processes.each do |process|
      unless process_hash.has_key?(process[:name])
        process_hash[process[:name]] = {
          name: process[:name],
          rank: process[:rank],
          forceToMachine: process[:force_to_machine],
          lensData: {}
        }
      end
      process_hash[process[:name]][:lensData][process[:side]] = {
        state: process[:state],
        requiredCapabilities: process[:capabilities],
        lastLocationReceivedAt: nil,
        lastStateChangeTimestamp: Time.now.in_time_zone(ENV['TZ']).to_i,
        lastComment: nil
      }
    end
    process_hash.map do |key, process|
      process
    end
  end
end