namespace :jobs do
  desc "Delete ALL jobs from the database"
  task :delete_all => :environment do
    if Job.count > 0
      Job.destroy_all
      puts "Deleted all jobs"
    else
      puts "No jobs to delete"
    end
  end

  desc "Delete all INACTIVE jobs from the database"
  task :delete_all_inactive => :environment do
    if Job.count > 0
      jobs = Job.where(:active == false)
      if jobs.count > 0
        jobs.destroy_all
        puts "Deleted all inactive jobs"
      end
      puts "No jobs to delete"
    else
      puts "No jobs to delete"
    end
  end

  desc "Mapping all snake case reject_reason to camelCase reject_reasons"
  task :remap_reject_reasons => :environment do
    hash = {
        no_valid_path: 'noValidPath',
        routed_while_waiting_other_process: 'routedWhileWaitingOtherProcess',
        fail_to_scan: 'failToScan',
        fail_fetch_processes: 'failFetchProcesses',
        marked_dead: 'markedDead',
        no_processes: 'noProcesses',
        received_process_in_complete_state: 'receivedProcessInCompleteState',
        received_process_while_waiting_other_complete: 'receivedProcessWhileWaitingOtherProcessComplete',
        received_invalid_process: 'receivedInvalidProcess',
        received_start_in_reject: 'receivedStartInReject',
        no_processes_at_non_start: 'noProcessesAtNonStart',
        completed_invalid_process_in_default: 'completedInvalidProcessInDefault',
        manual_reject: 'manualReject',
        process_aborted: 'processAborted',
        failed_to_synchronize: 'rxFailedToSynchronize',
        invalid_completed_processes: 'rxInvalidCompletedProcesses'
    }.stringify_keys
    Job.transaction do
      Job.where.not(reject_reason: nil).each do |job|
        if hash.has_key?(job.reject_reason)
          job.reject_reason = hash[job.reject_reason]
          job.save
        end
      end
    end
  end

  desc "Check how many stale job exists"
  task :stale_job_count => :environment do
    counter = 0
    Job.find_each do |job|
      if job.is_stale?
        counter += 1
      end
    end
    puts "There's #{counter} stale jobs in the system"
  end

  desc "Create job 153844"
  task :create_job_basic1 => :environment do
    job = Job.find_by_number(153844)
    if job.nil?
      job = Job.create(number: 153844, location: 'SW001', connector: 'input-0', active: true)
      job.job_histories.create(event_type: 'job_create', location: 'SW001', connector: 'input-0', active: true, processes: job.process_snapshot, is_estimated: false)
    end
    unless job.required_processes.exists?
      generated = JobProcess.find_by_name('generated')
      unless generated.nil?
        left_gen_required_process = RequiredProcess.create(side: 'left', state: 'STARTED')
        left_gen_required_process.required_process_state_histories << RequiredProcessStateHistory.create(state: 'NOTSTARTED', source: 'machine')
        left_gen_required_process.required_process_state_histories << RequiredProcessStateHistory.create(state: 'STARTED', source: 'machine')
        left_gen_required_process.job_process = generated
        job.required_processes << left_gen_required_process

        right_gen_required_process = RequiredProcess.create(side: 'right', state: 'STARTED')
        right_gen_required_process.required_process_state_histories << RequiredProcessStateHistory.create(state: 'NOTSTARTED', source: 'machine')
        right_gen_required_process.required_process_state_histories << RequiredProcessStateHistory.create(state: 'STARTED', source: 'machine')
        right_gen_required_process.job_process = generated
        job.required_processes << right_gen_required_process
      end

      polished = JobProcess.find_by_name('polished')
      unless polished.nil?
        left_polished_required_process = RequiredProcess.create(side: 'left', state: 'NOTSTARTED')
        left_polished_required_process.required_process_state_histories << RequiredProcessStateHistory.create(state: 'NOTSTARTED', source: 'machine')
        left_polished_required_process.job_process = polished
        job.required_processes << left_polished_required_process
      end
    end
    job.save
  end

  desc "Create job 153844"
  task :create_job_nc => :environment do
    job = Job.find_by_number(153844)
    if job.nil?
      job = Job.create(number: 153844, location: 'SW101', connector: 'input-0', active: true)
      job.job_histories.create(event_type: 'job_create', location: 'SW001', connector: 'input-0', active: true, processes: job.process_snapshot, is_estimated: false)
    end
    unless job.required_processes.exists?
      process = JobProcess.find_by_name('blocked')
      left_required_process = RequiredProcess.create(side: 'left', state: 'STARTED')
      left_required_process.required_process_state_histories << RequiredProcessStateHistory.create(state: 'NOTSTARTED', source: 'router')
      left_required_process.required_process_state_histories << RequiredProcessStateHistory.create(state: 'STARTED', source: 'BLK001SN-BLK001')
      left_required_process.job_process = process
      job.required_processes << left_required_process

      right_required_process = RequiredProcess.create(side: 'right', state: 'STARTED')
      right_required_process.required_process_state_histories << RequiredProcessStateHistory.create(state: 'NOTSTARTED', source: 'router')
      right_required_process.required_process_state_histories << RequiredProcessStateHistory.create(state: 'STARTED', source: 'BLK001SN-BLK001')
      right_required_process.job_process = process
      job.required_processes << right_required_process

      process = JobProcess.find_by_name('generated')
      left_required_process = RequiredProcess.create(side: 'left', state: 'NOTSTARTED')
      left_required_process.required_process_state_histories << RequiredProcessStateHistory.create(state: 'NOTSTARTED', source: 'router')
      left_required_process.job_process = process
      job.required_processes << left_required_process

      right_required_process = RequiredProcess.create(side: 'right', state: 'STARTED')
      right_required_process.required_process_state_histories << RequiredProcessStateHistory.create(state: 'NOTSTARTED', source: 'router')
      right_required_process.required_process_state_histories << RequiredProcessStateHistory.create(state: 'STARTED', source: 'GEN001SN-GEN001')
      right_required_process.job_process = process
      job.required_processes << right_required_process

      process = JobProcess.find_by_name('polished')
      left_required_process = RequiredProcess.create(side: 'left', state: 'NOTSTARTED')
      left_required_process.required_process_state_histories << RequiredProcessStateHistory.create(state: 'NOTSTARTED', source: 'router')
      left_required_process.job_process = process
      job.required_processes << left_required_process

      right_required_process = RequiredProcess.create(side: 'right', state: 'ABORTED')
      right_required_process.required_process_state_histories << RequiredProcessStateHistory.create(state: 'NOTSTARTED', source: 'router')
      right_required_process.required_process_state_histories << RequiredProcessStateHistory.create(state: 'STARTED', source: 'POL001SN-POL001')
      right_required_process.required_process_state_histories << RequiredProcessStateHistory.create(state: 'ABORTED', source: 'POL001SN-POL001')
      right_required_process.job_process = process
      job.required_processes << right_required_process

      process = JobProcess.find_by_name('engraved')
      left_required_process = RequiredProcess.create(side: 'left', state: 'NOTSTARTED')
      left_required_process.required_process_state_histories << RequiredProcessStateHistory.create(state: 'NOTSTARTED', source: 'router')
      left_required_process.job_process = process
      job.required_processes << left_required_process

      right_required_process = RequiredProcess.create(side: 'right', state: 'STARTED')
      right_required_process.required_process_state_histories << RequiredProcessStateHistory.create(state: 'NOTSTARTED', source: 'router')
      right_required_process.required_process_state_histories << RequiredProcessStateHistory.create(state: 'STARTED', source: 'ENG001SN-END001')
      right_required_process.job_process = process
      job.required_processes << right_required_process

      process = JobProcess.find_by_name('hardcoated')
      left_required_process = RequiredProcess.create(side: 'left', state: 'NOTSTARTED')
      left_required_process.required_process_state_histories << RequiredProcessStateHistory.create(state: 'NOTSTARTED', source: 'router')
      left_required_process.job_process = process
      job.required_processes << left_required_process

      right_required_process = RequiredProcess.create(side: 'right', state: 'ABORTED')
      right_required_process.required_process_state_histories << RequiredProcessStateHistory.create(state: 'NOTSTARTED', source: 'router')
      right_required_process.required_process_state_histories << RequiredProcessStateHistory.create(state: 'STARTED', source: 'HAC001SN-HAC001')
      right_required_process.required_process_state_histories << RequiredProcessStateHistory.create(state: 'ABORTED', source: 'HAC001SN-HAC001')
      right_required_process.job_process = process
      job.required_processes << right_required_process

      process = JobProcess.find_by_name('deblocked')
      left_required_process = RequiredProcess.create(side: 'left', state: 'NOTSTARTED')
      left_required_process.required_process_state_histories << RequiredProcessStateHistory.create(state: 'NOTSTARTED', source: 'router')
      left_required_process.job_process = process
      job.required_processes << left_required_process

      right_required_process = RequiredProcess.create(side: 'right', state: 'STARTED')
      right_required_process.required_process_state_histories << RequiredProcessStateHistory.create(state: 'NOTSTARTED', source: 'router')
      right_required_process.required_process_state_histories << RequiredProcessStateHistory.create(state: 'STARTED', source: 'DBL001SN-DBL001')
      right_required_process.job_process = process
      job.required_processes << right_required_process

      process = JobProcess.find_by_name('cleaned')
      left_required_process = RequiredProcess.create(side: 'left', state: 'NOTSTARTED')
      left_required_process.required_process_state_histories << RequiredProcessStateHistory.create(state: 'NOTSTARTED', source: 'router')
      left_required_process.job_process = process
      job.required_processes << left_required_process

      right_required_process = RequiredProcess.create(side: 'right', state: 'FINISHED')
      right_required_process.required_process_state_histories << RequiredProcessStateHistory.create(state: 'NOTSTARTED', source: 'router')
      right_required_process.required_process_state_histories << RequiredProcessStateHistory.create(state: 'STARTED', source: 'CLN001SN-CLN001')
      right_required_process.required_process_state_histories << RequiredProcessStateHistory.create(state: 'FINISHED', source: 'CLN001SN-CLN001')
      right_required_process.job_process = process
      job.required_processes << right_required_process

      process = JobProcess.find_by_name('brushed')
      left_required_process = RequiredProcess.create(side: 'left', state: 'NOTSTARTED')
      left_required_process.required_process_state_histories << RequiredProcessStateHistory.create(state: 'NOTSTARTED', source: 'router')
      left_required_process.job_process = process
      job.required_processes << left_required_process

      right_required_process = RequiredProcess.create(side: 'right', state: 'STARTED')
      right_required_process.required_process_state_histories << RequiredProcessStateHistory.create(state: 'NOTSTARTED', source: 'router')
      right_required_process.required_process_state_histories << RequiredProcessStateHistory.create(state: 'STARTED', source: 'BRU001SN-BRU001')
      right_required_process.job_process = process
      job.required_processes << right_required_process

      process = JobProcess.find_by_name('inspected')
      left_required_process = RequiredProcess.create(side: 'left', state: 'NOTSTARTED')
      left_required_process.required_process_state_histories << RequiredProcessStateHistory.create(state: 'NOTSTARTED', source: 'router')
      left_required_process.job_process = process
      job.required_processes << left_required_process

      right_required_process = RequiredProcess.create(side: 'right', state: 'FINISHED')
      right_required_process.required_process_state_histories << RequiredProcessStateHistory.create(state: 'NOTSTARTED', source: 'router')
      right_required_process.required_process_state_histories << RequiredProcessStateHistory.create(state: 'STARTED', source: 'INS001SN-INS001')
      right_required_process.required_process_state_histories << RequiredProcessStateHistory.create(state: 'FINISHED', source: 'INS001SN-INS001')
      right_required_process.job_process = process
      job.required_processes << right_required_process
    end
    job.save
  end
end